@@ -1,38 +1,19 @@
 OC.L10N.register(
     "circles",
     {
-    "Circles" : "Кругови",
-    "Circles' files" : "Фајлови од круга",
-    "Select circles to filter by" : "Одаберите кругове по којима да се филтрира",
-    "No circles found" : "Није нађен ниједан круг",
-    "Please select circles to filter by" : "Молимо одаберите кругове по којима да се филтрира",
-    "No files found for the selected circles" : "Ниједан фајл није нађен за одабране кругове",
-    "You created the circle {circle}" : "Направили сте круг {circle}",
-    "{author} created the circle {circle}" : "{author} је направио круг {circle}",
+    "Teams" : "Тимови",
+    "You created the team {circle}" : "Направили сте тим {circle}",
+    "{author} created the team {circle}" : "{author} је направио тим {circle}",
     "You deleted {circle}" : "Обрисали сте круг {circle}",
     "{author} deleted {circle}" : "{author} је обрисао круг {circle}",
-    "You linked {group} to {circle}" : "Везали сте групу {group} на круг {circle}",
-    "{group} has been linked to {circle} by {author}" : "{author} је повезао групу {group} са кругом {circle}",
-    "You unlinked {group} from {circle}" : "Одвезали сте групу {group} од круга {circle}",
-    "{group} has been unlinked from {circle} by {author}" : "{author} је одвезао групу {group} од круга {circle}",
-    "You changed the level of the linked group {group} in {circle} to %1$s" : "Променили сте ниво везе групе {group} у кругу {circle} на %1$s",
-    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} је променио ниво везе групе {group} у кругу {circle} на %1$s",
-    "You sent a request to link {circle} with {remote}" : "Послали сте захтев да вежете круг {circle} са {remote}",
-    "{author} sent a request to link {circle} with {remote}" : "{author} је послао захтев да веже круг {circle} са {remote}",
-    "{remote} requested a link with {circle}" : "{remote} је захтевао везивање са кругом {circle}",
-    "The request to link {circle} with {remote} has been rejected" : "Захтев за везивањем круга {circle} са {remote} је одбијен",
-    "The request to link {remote} with {circle} has been canceled remotely" : "Захтев за везивањем круга {circle} са {remote} је поништен са друге стране",
-    "The request to link {circle} with {remote} has been accepted" : "Захтев за везивањем круга {circle} са {remote} је прихваћен",
-    "You dismissed the request to link {remote} with {circle}" : "Одбацили сте захтев за везивањем {remote} са кругом {circle}",
-    "{author} dismissed the request to link {remote} with {circle}" : "{author} је одбацио захтев за везивање {remote} са кругом {circle}",
-    "You canceled the request to link {circle} with {remote}" : "Поништили сте захтев за везивањем круга {circle} саwith {remote}",
-    "{author} canceled the request to link {circle} with {remote}" : "{author} је поништио захтев за везивањем круга {circle} са {remote}",
-    "You accepted the request to link {remote} with {circle}" : "Прихватили сте захтев за везивањем {remote} са кругом {circle}",
-    "{author} accepted the request to link {remote} with {circle}" : "{author} је прихватио захтев за везивањем {remote} са кругом {circle}",
-    "A link between {circle} and {remote} is now up and running" : "Веза између круга  {circle} и {remote} је успостављена и ради",
-    "The link between {circle} and {remote} has been shutdown remotely" : "Веза између круга  {circle} и {remote} је угашена са друге стране",
-    "You closed the link between {circle} and {remote}" : "Затворили сте везу између круга {circle} и {remote}",
-    "{author} closed the link between {circle} and {remote}" : "{author} је затворио везу између круга {circle} и {remote}",
+    "You made {member} join {circle}" : "Учинили сте да се {member} придружи кругу {circle}",
+    "{author} made {member} join {circle}" : "{author} је учинио да се {member} придружи кругу {circle}",
+    "You added team {member} as member to {circle}" : "Додали сте тим {member} као члана у {circle}",
+    "{author} added team {member} as member to {circle}" : "{author} је додао тим {member} као члана {circle}",
+    "You made {member} leave {circle}" : "Учинили сте да {member} напусти круг {circle}",
+    "{author} made {member} leave {circle}" : "{author} је учинио да {member} напусти круг {circle}",
+    "You removed {member} from {circle}" : "Уклонили сте корисника {member} из круга {circle}",
+    "{author} removed {member} from {circle}" : "{author} је уклонио {member} из {circle}",
     "You joined {circle}" : "Придружили сте се кругу {circle}",
     "{member} joined {circle}" : "{member} се придружио кругу {circle}",
     "You accepted the invitation to join {circle}" : "Прихватили сте позив да се придружите кругу {circle}",
@@ -50,8 +31,7 @@ OC.L10N.register(
     "You declined the invitation to join {circle}" : "Одбили сте позивницу да се придружите кругу {circle}",
     "{member} declined an invitation to join {circle}" : "{member} је одбио позивницу да се придружи кругу {circle}",
     "You cancelled your request to join {circle}" : "Отказали сте захтев да се придружите кругу {circle}",
-    "{member} cancelled his request to join {circle}" : "{member} је отказао захтев да се придружи кругу {circle}",
-    "You removed {member} from {circle}" : "Уклонили сте корисника {member} из круга {circle}",
+    "{member} cancelled a request to join {circle}" : "{member} је отказао захтев да се придружи кругу {circle}",
     "You have been removed from {circle} by {author}" : "{author} Вас је уклонио из круга {circle}",
     "{member} has been removed from {circle} by {author}" : "{author} је уклонио корисника {member} из круга {circle}",
     "You removed {external} from {circle}" : "Уклонили сте {external} из круга {circle}",
@@ -72,49 +52,77 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} је послао захтев да се придружи кругу {circle}",
     "You are the new owner of {circle}" : "Ви сте нови власник круга {circle}",
     "{member} is the new owner of {circle}" : "{member} је нови власник круга {circle}",
-    "On events happening in a <strong>Circle</strong> of which you are a member" : "На догађаје који се дешавају у <strong>Кругу</strong> чији сте члан",
-    "Any important event in a <strong>Circle</strong> you are moderating" : "Било који битан догађај у <strong>Кругу</strong> који модеришете",
-    "On global events happening in any <strong>Circle</strong>" : "На јавне догађаје који се дешавају и било ком <strong>кругу</strong>",
+    "On events happening in a <strong>team</strong> of which you are a member" : "На догађаје који се дешавају у <strong>тиму</strong> чији сте члан",
+    "Any important event in a <strong>team</strong> you are moderating" : "Било који битан догађај у <strong>тиму</strong> који модеришете",
+    "On global events happening in any <strong>team</strong>" : "На глобалне догађаје који се дешавају и било ком <strong>тиму</strong>",
+    "Shared to Circles" : "Дељено на Кругове",
+    "Single" : "Сам",
     "Personal" : "Лични",
     "System" : "Систем",
     "Visible" : "Видљив",
     "Open" : "Отвори",
+    "Invite" : "Позив",
+    "Join request" : "Захтев за приступање",
+    "Friends" : "Пријатељи",
+    "Password protected" : "Заштићено лозинком",
+    "No Owner" : "Без власника",
     "Hidden" : "Сакривен",
+    "Backend" : "Позадински систем",
     "Local" : "Локално",
     "Root" : "Корен",
+    "Team invite" : "Позивница тима",
     "Federated" : "Здружено",
+    "Mount point" : "Тачка монтирања",
+    "Nextcloud Account" : "Nextcloud налог",
+    "Nextcloud Group" : "Nextcloud група",
+    "Email address" : "Адреса е-поште",
     "Contact" : "Контакт",
     "Circle" : "Круг",
+    "Nextcloud App" : "Nextcloud апликација",
     "Member" : "Члан",
     "Moderator" : "Модератор",
     "Admin" : "Администратор",
     "Owner" : "Власник",
     "%s shared »%s« with you." : "%s је поделио »%s« са Вама.",
+    "%s shared »%s« with \"%s\"." : "%s је поделио »%s« са „%s.",
     "%s on %s" : "%s на %s",
+    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s је са вама поделио »%2$s«.\nТребало би да сте већ примили посебан и-мејл са линком за приступ.\n",
+    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s је са вама поделио »%2$s«. Требало би да сте већ примили посебан и-мејл са линком за приступ.",
     "Password to access »%1$s« shared to you by %2$s" : "%2$s Вам је поделио/ла лозинку за приступ „%1$s“",
     "Password to access »%s«" : "Лозинка за приступ „%s“",
     "It is protected with the following password:" : "Заштићена је следећом лозинком:",
     "%1$s via %2$s" : "%1$s преко %2$s",
     "Click the button below to open it." : "Кликните дугме испод да га отворите.",
     "Open »%s«" : "Отвори »%s«",
+    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s је са вама поделио више фајлова.\nТребало би да сте већ примили посебан и-мејл са линком за приступ.\n",
+    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s је са вама поделио више фајлова. Требало би да сте већ примили посебан и-мејл са линком за приступ.",
     "Password to access files shared to you by %1$s" : "Лозинка да приступите фајлова које Вам је поделио %1$s",
     "Password to access files" : "Лозинка за приступ фајловима",
+    "%s shared multiple files with \"%s\"." : "%s је поделио више фајлова са „%s.",
     "%s shared multiple files with you." : "%s је поделио више фајлова са Вама.",
-    "Circle not found" : "Круг није нађен",
-    "Circle not found " : "Криг није нађен",
-    "A circle with that name exists" : "Круг са тим именом постоји",
-    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Не можете користити апликацију Кругови док администратор не дозволи бар један тип кругова",
-    "This member does not exist" : "Члан не постоји",
-    "Federated link not found" : "Здружена веза није нађена",
+    "Boot up" : "Подизање система",
+    "Nextcloud Initialization" : "Nextcloud иницијализација",
+    "Circles App Initialization" : "Иницијализација апликације Кругови",
+    "Fresh installation status" : "Статус свеже инсталације",
+    "Building Local Database" : "Изградња локалне базе података",
+    "Testing Basic Circle Creation" : "Тестирање креирања основног круга",
+    "Adding local users and moderators" : "Додавање локалних корисника и модератора",
+    "Show all teams" : "Прикажи све тимове",
+    "Create a new team" : "Креирај нови тим",
+    "Files" : "Фајлови",
     "This feature is not available for personal circles" : "Ова функционалност није доступна за личне кругове",
-    "The circle is not federated" : "Круг није здружен",
-    "You cannot join this circle" : "Не можете се придружити кругу",
+    "The team is not federated" : "Круг није федерисан",
+    "You cannot join this team" : "Не можете да се придружите овом тиму",
     "This member is not a moderator" : "Овај члан није модератор",
     "Insufficient privileges" : "Недовољне дозволе",
-    "This member is the owner of the circle" : "Овај члан је власник круга",
+    "This member does not exist" : "Члан не постоји",
+    "This member is the owner of the team" : "Овај члан је власник тима",
     "Level cannot be changed for this type of member" : "Ниво не може да се промени за овај тип члана",
     "You are already a member of this circle" : "Већ сте члан овог круга",
     "You have been blocked from this circle" : "Блокирани сте у овом кругу",
+    "The account is already a member of this circle" : "Овај налог је већ члан овог круга",
+    "The account has already been invited into this circle" : "Налог је већ раније позван у овај круг",
+    "%s (Team owned by %s)" : "%s (Власник тима је %s)",
     "You are now a member of the Circle \"%2$s\"" : "Сада сте члан круга „%2$s“",
     "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s Вас је позвао/ла у круг „%2$s“",
     "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s је послао захтев да буде члан круга „%2$s“",
@@ -122,8 +130,52 @@ OC.L10N.register(
     "Refuse" : "Одбиј",
     "Leave the circle" : "Напусти круг",
     "%s" : "%s",
+    "Personal team" : "Лични тим",
+    "%s owned by %s" : "%s поседује %s",
+    "You have no permission to create a new team" : "Немате дозволу да креирате нови тим",
+    "%s shared a file with \"%s\"." : "%s је поделио фајл са „%s.",
+    "%s shared a file with you." : "%s је са вама поделио фајл.",
+    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s је са вама поделио неки садржај.\nТребало би да сте већ примили посебан и-мејл са линком за приступ.\n",
+    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s је поделио са вама неки садржај. Требало би да сте већ примили посебан и-мејл са линком за приступ.",
+    "Password to access content shared with you by %1$s" : "%1$s је са вама поделио лозинку за приступ садржају",
+    "Password to access content" : "Лозинка за приступ садржају",
+    "This item is already shared with this team" : "Ова ставка је већ подељена овом тиму",
+    "Bring cloud-users closer together." : "Приближимо клауд кориснике.",
+    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Тимови омогућава људима да креирају своје сопствене групе људи/колега/пријатеља.\nБило која друга апликација затим може за дељење да користи те групе људи.",
+    "No files in here" : "Овде нема фајлова",
+    "No entries found in this folder" : "Нема резултата у овој фасцикли",
+    "Name" : "Назив",
+    "Size" : "Величина",
+    "Modified" : "Измењен",
+    "Circles" : "Кругови",
+    "Circles' files" : "Фајлови од круга",
+    "Select circles to filter by" : "Одаберите кругове по којима да се филтрира",
+    "No circles found" : "Није нађен ниједан круг",
+    "Please select circles to filter by" : "Молимо одаберите кругове по којима да се филтрира",
+    "No files found for the selected circles" : "Ниједан фајл није нађен за одабране кругове",
+    "You created the circle {circle}" : "Направили сте круг {circle}",
+    "{author} created the circle {circle}" : "{author} је направио круг {circle}",
+    "You added circle {member} as member to {circle}" : "Додали сте круг {member} као члана {circle}",
+    "{author} added circle {member} has been added as member to {circle}" : "{author} је додао круг {member} као члана {circle}",
+    "You removed {member} leave {circle}" : "Уклонили сте корисника {member} из круга {circle}",
+    "On events happening in a <strong>Circle</strong> of which you are a member" : "На догађаје који се дешавају у <strong>Кругу</strong> чији сте члан",
+    "Any important event in a <strong>Circle</strong> you are moderating" : "Било који битан догађај у <strong>Кругу</strong> који модеришете",
+    "On global events happening in any <strong>Circle</strong>" : "На јавне догађаје који се дешавају и било ком <strong>кругу</strong>",
+    "Join Request" : "Захтев за приступање",
+    "Password Protected" : "Заштићено лозинком",
+    "Circle Invite" : "Позив у круг",
+    "Email Address" : "И-мејл адреса",
+    "Circle not found" : "Круг није нађен",
+    "Circle not found " : "Криг није нађен",
+    "This account is already a member of the circle" : "Овај налог је већ члан круга",
+    "Federated link not found" : "Здружена веза није нађена",
+    "The circle is not federated" : "Круг није здружен",
+    "You cannot join this circle" : "Не можете се придружити кругу",
+    "This member is the owner of the circle" : "Овај члан је власник круга",
+    "%s (Circle owned by %s)" : "%s (Власник круга је %s)",
     "Personal Circle" : "Лични круг",
     "You need a specify a type of circle" : "Морате навести тип круга",
+    "A circle with that name exists" : "Круг са тим именом постоји",
     "This member is not the owner of the circle" : "Овај члан није власник круга",
     "This member is not an admin of the circle" : "Овај члан није администратор круга",
     "Group contains too many members" : "Група садржи превише чланова",
@@ -132,18 +184,17 @@ OC.L10N.register(
     "You cannot edit level in a personal circle" : "Не можете мењати ниво у личним круговима",
     "Group cannot be set as owner of a circle" : "Не можете да поставите групу као власника круга",
     "now" : "сада",
+    "This account does not exist" : "Овај налог не постоји",
     "Email format is not valid" : "Формат адресе е-поште није исправан",
     "This contact is not available" : "Овај контакт није доступан",
-    "Could not find share" : "Не могу да нађем дељење",
-    "Bring cloud-users closer together." : "Приближимо клауд кориснике.",
-    "No files in here" : "Овде нема фајлова",
-    "No entries found in this folder" : "Нема резултата у овој фасцикли",
-    "Name" : "Назив",
-    "Size" : "Величина",
-    "Modified" : "Измењен",
-    "This user is already a member of the circle" : "Корисник је већ члан круга",
-    "The user is already a member of this circle" : "Корисник је већ члан круга",
-    "The user has already been invited into this circle" : "Корисник је већ позван у овај круг",
-    "This user does not exist" : "Овај корисник не постоји"
+    "You have no permission to create a new circle" : "Немате дозволу да креирате нови круг",
+    "This item is already shared with this circle" : "Ова ставка је већ подељена овом кругу",
+    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Кругови омогућава људима да креирају своје сопствене групе људи/колега/пријатеља.\nБило која друга апликација затим може за дељење да користи те групе људи (или „кругове”).",
+    "Teams' files" : "Фајлови тимова",
+    "Select team to filter by" : "Изаберите тим по којем се филтрира",
+    "No teams found" : "Није пронађен ниједан тим",
+    "Please select teams to filter by" : "Молимо васд да изаберите тимове по којима се филтрира",
+    "No files found for the selected teams" : "Није пронађен ниједан фајл за изабране тимове",
+    "{author} added team {member} has been added as member to {circle}" : "{author} је додао тим {member} као члана {circle}"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
