@@ -57,6 +57,7 @@ use OCA\Circles\Model\FederatedUser;
 use OCA\Circles\Model\Member;
 use OCA\Circles\Model\Membership;
 use OCA\Circles\Model\Probes\CircleProbe;
+use OCA\Circles\Model\Probes\DataProbe;
 use OCA\Circles\Service\CircleService;
 use OCA\Circles\Service\ConfigService;
 use OCA\Circles\Service\FederatedUserService;
@@ -248,9 +249,15 @@ class CirclesManager {
 
 	/**
 	 * @return IFederatedUser
+	 * @throws FederatedUserNotFoundException
 	 */
 	public function getCurrentFederatedUser(): IFederatedUser {
-		return $this->federatedUserService->getCurrentUser();
+		$current = $this->federatedUserService->getCurrentUser();
+		if (is_null($current)) {
+			throw new FederatedUserNotFoundException();
+		}
+
+		return $current;
 	}
 
 
@@ -316,20 +323,27 @@ class CirclesManager {
 
 
 	/**
-	 * returns Circles available, based on current session
+	 * WARNING: This method is not using Cached Memberships meaning that the request can be heavy and should
+	 * only be used if probeCircles() does not fit your need.
+	 *
+	 * Always prefer probeCircles();
+	 *
+	 * returns available Circles to the current session.
+	 *
+	 * @see probeCircles()
 	 *
 	 * @return Circle[]
 	 * @throws InitiatorNotFoundException
 	 * @throws RequestBuilderException
 	 */
-	public function getCircles(?CircleProbe $probe = null): array {
+	public function getCircles(?CircleProbe $probe = null, bool $refreshCache = false): array {
 		if (is_null($probe)) {
 			$probe = new CircleProbe();
 			$probe->filterHiddenCircles()
 				  ->filterBackendCircles();
 		}
 
-		return $this->circleService->getCircles($probe, true);
+		return $this->circleService->getCircles($probe, !$refreshCache);
 	}
 
 
@@ -509,6 +523,31 @@ class CirclesManager {
 	}
 
 
+	/**
+	 * Returns data about Circles based on cached Memberships.
+	 * Meaning that only Circles the current user is a member will be returned.
+	 *
+	 * CircleProbe is used to filter Circles to be returned by the method.
+	 * DataProbe is used to add details to returned Circles.
+	 *
+	 * @param CircleProbe|null $circleProbe
+	 * @param DataProbe|null $dataProbe
+	 *
+	 * @return array
+	 * @throws InitiatorNotFoundException
+	 * @throws RequestBuilderException
+	 */
+	public function probeCircles(?CircleProbe $circleProbe = null, ?DataProbe $dataProbe = null): array {
+		if (is_null($circleProbe)) {
+			$circleProbe = new CircleProbe();
+			$circleProbe->filterHiddenCircles()
+						->filterBackendCircles();
+		}
+
+		return $this->circleService->probeCircles($circleProbe, $dataProbe);
+	}
+
+
 	/**
 	 * WIP
 	 *
@@ -520,10 +559,10 @@ class CirclesManager {
 	 * @throws MemberNotFoundException
 	 * @throws RequestBuilderException
 	 */
-//	public function getMember(string $circleId, string $singleId): Member {
-//		$this->federatedUserService->bypassCurrentUserCondition(true);
-//		$this->memberService->getMemberById($circleId, $singleId);
-//	}
+	//	public function getMember(string $circleId, string $singleId): Member {
+	//		$this->federatedUserService->bypassCurrentUserCondition(true);
+	//		$this->memberService->getMemberById($circleId, $singleId);
+	//	}
 
 
 	/**
@@ -533,5 +572,5 @@ class CirclesManager {
 	 *
 	 * @return Member
 	 */
-//	public function getMemberById(string $memberId): Member {
+	//	public function getMemberById(string $memberId): Member {
 }
