@@ -72,6 +72,53 @@ OC.L10N.register(
     "Description: %s" : "Description: %s",
     "Where: %s" : "Where: %s",
     "%1$s via %2$s" : "%1$s via %2$s",
+    "In a %1$s on %2$s for the entire day" : "In a %1$s on %2$s for the entire day",
+    "In a %1$s on %2$s between %3$s - %4$s" : "In a %1$s on %2$s between %3$s - %4$s",
+    "In %1$s %2$s on %3$s for the entire day" : "In %1$s %2$s on %3$s for the entire day",
+    "In %1$s %2$s on %3$s between %4$s - %5$s" : "In %1$s %2$s on %3$s between %4$s - %5$s",
+    "Could not generate when statement" : "Could not generate when statement",
+    "Every Day for the entire day" : "Every Day for the entire day",
+    "Every Day for the entire day until %1$s" : "Every Day for the entire day until %1$s",
+    "Every Day between %1$s - %2$s" : "Every Day between %1$s - %2$s",
+    "Every Day between %1$s - %2$s until %3$s" : "Every Day between %1$s - %2$s until %3$s",
+    "Every %1$d Days for the entire day" : "Every %1$d Days for the entire day",
+    "Every %1$d Days for the entire day until %2$s" : "Every %1$d Days for the entire day until %2$s",
+    "Every %1$d Days between %2$s - %3$s" : "Every %1$d Days between %2$s - %3$s",
+    "Every %1$d Days between %2$s - %3$s until %4$s" : "Every %1$d Days between %2$s - %3$s until %4$s",
+    "Could not generate event recurrence statement" : "Could not generate event recurrence statement",
+    "Every Week on %1$s for the entire day" : "Every Week on %1$s for the entire day",
+    "Every Week on %1$s for the entire day until %2$s" : "Every Week on %1$s for the entire day until %2$s",
+    "Every Week on %1$s between %2$s - %3$s" : "Every Week on %1$s between %2$s - %3$s",
+    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Every Week on %1$s between %2$s - %3$s until %4$s",
+    "Every %1$d Weeks on %2$s for the entire day" : "Every %1$d Weeks on %2$s for the entire day",
+    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "Every %1$d Weeks on %2$s for the entire day until %3$s",
+    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "Every %1$d Weeks on %2$s between %3$s - %4$s",
+    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s",
+    "Every Month on the %1$s for the entire day" : "Every Month on the %1$s for the entire day",
+    "Every Month on the %1$s for the entire day until %2$s" : "Every Month on the %1$s for the entire day until %2$s",
+    "Every Month on the %1$s between %2$s - %3$s" : "Every Month on the %1$s between %2$s - %3$s",
+    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Every Month on the %1$s between %2$s - %3$s until %4$s",
+    "Every %1$d Months on the %2$s for the entire day" : "Every %1$d Months on the %2$s for the entire day",
+    "Every %1$d Months on the %2$s for the entire day until %3$s" : "Every %1$d Months on the %2$s for the entire day until %3$s",
+    "Every %1$d Months on the %2$s between %3$s - %4$s" : "Every %1$d Months on the %2$s between %3$s - %4$s",
+    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s",
+    "Every Year in %1$s on the %2$s for the entire day" : "Every Year in %1$s on the %2$s for the entire day",
+    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Every Year in %1$s on the %2$s for the entire day until %3$s",
+    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Every Year in %1$s on the %2$s between %3$s - %4$s",
+    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s",
+    "Every %1$d Years in %2$s on the %3$s for the entire day" : "Every %1$d Years in %2$s on the %3$s for the entire day",
+    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s",
+    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s",
+    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s",
+    "On specific dates for the entire day until %1$s" : "On specific dates for the entire day until %1$s",
+    "On specific dates between %1$s - %2$s until %3$s" : "On specific dates between %1$s - %2$s until %3$s",
+    "In a %1$s on %2$s" : "In a %1$s on %2$s",
+    "In a %1$s on %2$s then on %3$s" : "In a %1$s on %2$s then on %3$s",
+    "In a %1$s on %2$s then on %3$s and %4$s" : "In a %1$s on %2$s then on %3$s and %4$s",
+    "In %1$s %2$s on %3$s" : "In %1$s %2$s on %3$s",
+    "In %1$s %2$s on %3$s then on %4$s" : "In %1$s %2$s on %3$s then on %4$s",
+    "In %1$s %2$s on %3$s then on %4$s and %5$s" : "In %1$s %2$s on %3$s then on %4$s and %5$s",
+    "Could not generate next recurrence statement" : "Could not generate next recurrence statement",
     "Cancelled: %1$s" : "Cancelled: %1$s",
     "\"%1$s\" has been canceled" : "\"%1$s\" has been cancelled",
     "Re: %1$s" : "Re: %1$s",
@@ -86,13 +133,43 @@ OC.L10N.register(
     "Organizer:" : "Organiser:",
     "Attendees:" : "Attendees:",
     "Title:" : "Title:",
-    "Date and time:" : "Date and time:",
+    "When:" : "When:",
     "Location:" : "Location:",
     "Link:" : "Link:",
+    "Occurring:" : "Occurring:",
     "Accept" : "Accept",
     "Decline" : "Decline",
     "More options …" : "More options …",
     "More options at %s" : "More options at %s",
+    "Monday" : "Monday",
+    "Tuesday" : "Tuesday",
+    "Wednesday" : "Wednesday",
+    "Thursday" : "Thursday",
+    "Friday" : "Friday",
+    "Saturday" : "Saturday",
+    "Sunday" : "Sunday",
+    "January" : "January",
+    "February" : "February",
+    "March" : "March",
+    "April" : "April",
+    "May" : "May",
+    "June" : "June",
+    "July" : "July",
+    "August" : "August",
+    "September" : "September",
+    "October" : "October",
+    "November" : "November",
+    "December" : "December",
+    "First" : "First",
+    "Second" : "Second",
+    "Third" : "Third",
+    "Fourth" : "Fourth",
+    "Fifty" : "Fifty",
+    "Last" : "Last",
+    "Second Last" : "Second Last",
+    "Third Last" : "Third Last",
+    "Fourth Last" : "Fourth Last",
+    "Fifty Last" : "Fifty Last",
     "Contacts" : "Contacts",
     "{actor} created address book {addressbook}" : "{actor} created address book {addressbook}",
     "You created address book {addressbook}" : "You created address book {addressbook}",
@@ -135,6 +212,7 @@ OC.L10N.register(
     "Failed to unlink: %1$s" : "Failed to unlink: %1$s",
     "Failed to write file contents: %1$s" : "Failed to write file contents: %1$s",
     "File not found: %1$s" : "File not found: %1$s",
+    "Invalid target path" : "Invalid target path",
     "System is in maintenance mode." : "System is in maintenance mode.",
     "Upgrade needed" : "Upgrade needed",
     "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS.",
@@ -158,6 +236,10 @@ OC.L10N.register(
     "WebDAV" : "WebDAV",
     "First day" : "First day",
     "Last day (inclusive)" : "Last day (inclusive)",
+    "Out of office replacement (optional)" : "Out of office replacement (optional)",
+    "Name of the replacement" : "Name of the replacement",
+    "No results." : "No results.",
+    "Start typing." : "Start typing.",
     "Short absence status" : "Short absence status",
     "Long absence Message" : "Long absence Message",
     "Save" : "Save",
@@ -172,13 +254,6 @@ OC.L10N.register(
     "No working hours set" : "No working hours set",
     "Add slot" : "Add slot",
     "Weekdays" : "Weekdays",
-    "Monday" : "Monday",
-    "Tuesday" : "Tuesday",
-    "Wednesday" : "Wednesday",
-    "Thursday" : "Thursday",
-    "Friday" : "Friday",
-    "Saturday" : "Saturday",
-    "Sunday" : "Sunday",
     "Pick a start time for {dayName}" : "Pick a start time for {dayName}",
     "Pick a end time for {dayName}" : "Pick a end time for {dayName}",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications.",
