@@ -7,7 +7,7 @@ OC.L10N.register(
     "Delete" : "삭제",
     "Tags" : "태그",
     "Show list view" : "리스트 보기",
-    "Show grid view" : "바둑판식 보기",
+    "Show grid view" : "그리드뷰 보기",
     "Home" : "홈",
     "Close" : "닫기",
     "Could not create folder \"{dir}\"" : "폴더 \"{dir}\"을(를) 만들 수 없음",
@@ -19,7 +19,7 @@ OC.L10N.register(
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "남은 공간이 부족합니다. 업로드할 파일 크기는 {size1}이지만 현재 {size2}만큼 남아 있습니다",
     "Target folder \"{dir}\" does not exist any more" : "대상 폴더 \"{dir}\"이(가) 더 이상 존재하지 않습니다",
     "Not enough free space" : "남은 공간이 부족함",
-    "An unknown error has occurred" : "알 수 없는 에러 발생",
+    "An unknown error has occurred" : "알 수 없는 오류 발생",
     "File could not be uploaded" : "파일을 업로드할 수 없음",
     "Uploading …" : "업로드 중…",
     "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
@@ -156,11 +156,17 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "파일이 <strong>즐겨찾기</strong>에서 추가 또는 삭제됨",
     "A file or folder has been <strong>changed</strong>" : "파일이나 폴더가 <strong>변경됨</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "즐겨찾기된 파일이나 폴더가 <strong>변경됨</strong>",
+    "Failed to authorize" : "인증 실패하였습니다",
     "Upload (max. %s)" : "업로드(최대 %s)",
+    "Files compatibility" : "파일 호환성",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "모든 클라이언트와 동기화될 수 있게 제한된 파일이름을 허용하세요. 기본적으로 POSIX(예. 리눅스 혹은 맥오에스)에서 유효한 모든 파일이름은 허용됩니다.",
+    "Enforce Windows compatibility" : "윈도우 호환성 준수",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "예약어나 특수문자사용 같은 윈도우 시스템에서 유효하딘 않은 파일이름은 차단될 것입니다. 그러나 이것은 대소문자 호환성을 강제하지는 않을 것입니다.",
     "Accept" : "수락",
     "Reject" : "거절",
     "Incoming ownership transfer from {user}" : "{user}의 소유권 이전 요청",
     "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "{path}의 소유권을 받으시겠습니까?\n\n참고: 이전 과정은 동의한 시점으로부터 최대 1시간 소요됩니다.",
+    "Ownership transfer denied" : "소유권 이전 거절",
     "Ownership transfer failed" : "소유권 이전 실패",
     "Your ownership transfer of {path} to {user} failed." : "{user}을(를) 향한 {path}의 소유권 이전에 실패했습니다.",
     "The ownership transfer of {path} from {user} failed." : "{user}(으)로부터 {path}의 소유권을 받는 것에 실패했습니다.",
@@ -180,34 +186,31 @@ OC.L10N.register(
     "Toggle selection for file \"{displayName}\"" : "파일 \"{displayName}\" 선택/선택해제",
     "Toggle selection for folder \"{displayName}\"" : "폴더 \"{displayName}\" 선택/선택해제",
     "Rename file" : "파일 이름 바꾸기",
-    "File name" : "파일 이름",
+    "Filename" : "파일 이름",
     "Folder name" : "폴더 이름",
     "This node is unavailable" : "이 노드를 사용할 수 없습니다",
-    "Download file {name}" : "{name} 파일 다운로드",
-    "\"{name}\" is not an allowed filetype." : "\"{name}\"은(는) 허용된 파일 형식이 아님.",
-    "{newName} already exists." : "{newName}이(가) 이미 존재함.",
-    "\"{char}\" is not allowed inside a file name." : "파일 이름에 \"{char}\"(을)를 넣을 수 없습니다.",
-    "Name cannot be empty" : "이름이 비어 있을 수 없음",
-    "Another entry with the same name already exists" : "같은 이름의 항목이 이미 있습니다.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" 에서 \"{newName}\"(으)로 이름 변경함",
     "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\"(이)가 더이상 존재하지 않아 이름을 바꿀 수 없습니다.",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{newName}\" 이름이 \"{dir}\" 폴더에서 이미 사용 중입니다. 다른 이름을 고르세요.",
     "Could not rename \"{oldName}\"" : "\"{oldName}\"의 이름을 바꿀 수 없음",
+    "Clear filter" : "필터 지우기",
+    "Type" : "종류",
+    "Active filters" : "활성 필터",
     "Total rows summary" : "총 행 요약",
     "Toggle selection for all files and folders" : "모든 파일 선택/선택해제",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" 이 일부 요소들에서 실패함",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" 일괄 작업을 성공적으로 실행함",
+    "{count} selected" : "{count}개 선택됨",
     "List of files and folders." : "파일과 폴더의 목록",
     "Column headers with buttons are sortable." : "버튼이 있는 열 머리글은 정렬할 수 있습니다.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "성능 상의 이유로 목록을 전부 표시하지 않았습니다. 목록을 탐색하면 파일들이 표시됩니다.",
     "File not found" : "파일을 찾을 수 없음",
-    "Storage informations" : "저장소 정보",
     "{usedQuotaByte} used" : "{usedQuotaByte} 사용",
     "{relative}% used" : "{relative}% 사용",
     "Could not refresh storage stats" : "저장소 정보를 새로고칠 수 없음",
     "Your storage is full, files can not be updated or synced anymore!" : "저장 공간이 가득 찼습니다. 파일을 업데이트하거나 동기화할 수 없습니다!",
     "Create" : "생성",
-    "A file or folder with that name already exists." : "같은 이름을 사용하는 파일 또는 폴더가 이미 있습니다.",
+    "Submit" : "제출",
     "Transfer ownership of a file or folder" : "파일이나 폴더의 소유권 이전",
     "Choose file or folder to transfer" : "이전할 파일이나 폴더 고르기",
     "Change" : "변경",
@@ -231,11 +234,12 @@ OC.L10N.register(
     "Shared by link" : "링크로 공유됨",
     "Shared" : "공유됨",
     "Switch to list view" : "목록 보기로 전환",
-    "Switch to grid view" : "바둑판식 보기로 전환",
+    "Switch to grid view" : "그리드뷰로 전환",
+    "Upload was cancelled by user" : "사용자에 의해 업로드가 취소됨",
     "Error during upload: {message}" : "업로드 오류: {message}",
     "Error during upload, status code {status}" : "업로드 중 오류 발생, 상태 코드 {status}",
     "Unknown error during upload" : "업로드 중 알 수 없는 오류 발생",
-    "Open the files app settings" : "파일 앱 설정을 열기",
+    "Views" : "보기",
     "Files settings" : "파일 설정",
     "File cannot be accessed" : "파일에 접근할 수 없음",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "파일을 찾을 수 없거나 볼 권한이 없습니다. 보낸 이에게 공유를 요청하세요.",
@@ -245,7 +249,7 @@ OC.L10N.register(
     "Sort folders before files" : "폴더를 파일보다 먼저 정렬",
     "Show hidden files" : "숨김 파일 보이기",
     "Crop image previews" : "이미지 미리보기 확대",
-    "Enable the grid view" : "바둑판식 보기 활성화",
+    "Enable the grid view" : "그리드뷰 활성화",
     "Additional settings" : "고급 설정",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "WebDAV URL",
@@ -261,16 +265,15 @@ OC.L10N.register(
     "Creating file" : "파일 만들기",
     "Blank" : "여백",
     "Unable to create new file from template" : "템플릿으로 새 파일을 만들 수 없음",
+    "Deletion cancelled" : "삭제가 취소됨",
     "Delete permanently" : "영구히 삭제",
     "Delete and unshare" : "삭제 및 공유 해제",
     "Leave these shares" : "이 공유에서 떠나기",
     "Disconnect storages" : "저장소 연결 끊기",
     "Delete files" : "파일 삭제",
     "Delete folders" : "폴더 삭제",
-    "You are about to delete {count} items." : "{count}개 항목을 삭제합니다.",
     "Confirm deletion" : "삭제 확인",
     "Cancel" : "취소",
-    "Deletion cancelled" : "삭제가 취소됨",
     "Destination is not a folder" : "대상이 폴더가 아닙니다.",
     "This file/folder is already in that directory" : "이 파일/폴더가 이미 그 경로에 있습니다.",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "파일/폴더를 그 안이나 그 안의 폴더로 이동할 수 없습니다.",
@@ -283,22 +286,34 @@ OC.L10N.register(
     "Choose destination" : "목적지 선택",
     "Copy to {target}" : "{target}에 복사",
     "Move to {target}" : "{target}에 이동",
-    "Cancelled move or copy operation" : "이동 또는 복사 작업을 취소함",
     "Move or copy operation failed" : "이동 또는 복사 작업에 실패함",
+    "Cancelled move or copy operation" : "이동 또는 복사 작업을 취소함",
     "Open folder {displayName}" : "{displayName} 폴더 열기",
     "Open in Files" : "파일에서 열기",
     "Open details" : "자세한 정보 열기",
+    "Today" : "오늘",
+    "Last 7 days" : "지난 7일",
+    "Last 30 days" : "지난 30일",
+    "Documents" : "문서",
+    "Audio" : "오디오",
+    "Videos" : "동영상",
     "Created new folder \"{name}\"" : "\"{name}\" 폴더를 새로 만듦",
-    "Filename" : "파일 이름",
     "Unable to initialize the templates directory" : "템플릿 디렉터리를 설정할 수 없음",
-    "Create new templates folder" : "새로운 템플릿 폴더 만들기",
     "Templates" : "템플릿",
     "New template folder" : "새 템플릿 폴더",
     "Search in folder: {folder}" : "폴더에서 검색: {folder}",
     "One of the dropped files could not be processed" : "드롭한 파일 중 하나를 처리할 수 없습니다",
+    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "이 브라우저는 Filesystem API를 지원하지 않습니다. 디렉토리가 업로드 되지 않을 것입니다.",
+    "No files to upload" : "업로드할 파일이 없음",
+    "Unable to create the directory {directory}" : "디렉토리 {directory}을(를) 생성할 수 없음",
     "Some files could not be uploaded" : "일부 파일을 업로드할 수 없었습니다.",
     "Files uploaded successfully" : "파일을 성공적으로 업로드했습니다.",
+    "No files to process" : "처리할 파일이 없음",
+    "Some files could not be copied" : "일부 파일을 복사할 수 없음",
     "Some files could not be moved" : "일부 파일을 이동할 수 없음",
+    "Files copied successfully" : "파일을 성공적으로 복사함",
+    "Files moved successfully" : "파일을 성공적으로 이동함",
+    "Upload cancelled" : "업로드가 취소됨",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount}개 폴더"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount}개 파일"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1개 파일과 {folderCount}개 폴더"],
@@ -324,29 +339,15 @@ OC.L10N.register(
     "New text file.txt" : "새 텍스트 파일.txt",
     "Direct link was copied (only works for users who have access to this file/folder)" : "직접 링크를 복사했습니다. (이 파일 및 폴더에 접근할 수 있는 사용자에게만 작동)",
     "Copy direct link (only works for users who have access to this file/folder)" : "직접 링크 복사(이 파일/폴더에 접근 권한이 있는 사람만)",
-    "You can only favorite a single file or folder at a time" : "한번에 한 파일 혹은 한 폴더만 즐겨찾기로 지정할 수 있습니다.",
-    "This file has the tag {tag}" : "이 파일에 {tag} 태그가 있음",
-    "This file has the tags {firstTags} and {lastTag}" : "이 파일에 {firstTags}와 {lastTag} 태그가 있음",
     "\"remote user\"" : "\"원격 사용자\"",
-    "Select the row for {displayName}" : "{displayName}을 위한 행을 선택",
-    "Open folder {name}" : "{name} 폴더 열기",
-    "Unselect all" : "모두 선택 해제",
-    "ascending" : "오름차순",
-    "descending" : "내림차순",
-    "Sort list by {column} ({direction})" : "{column} ({direction})으로 목록 정렬",
-    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "이 목록은 성능 상의 이유로 완전히 표시되지 않았습니다. 목록을 탐색하면 파일이 표시됩니다.",
-    "Search for an account" : "계정 검색",
-    "Choose" : "선택",
-    "No files or folders have been deleted yet" : "아직 삭제된 파일이나 폴더가 없습니다.",
+    "{newName} already exists." : "{newName}이(가) 이미 존재함.",
+    "Name cannot be empty" : "이름이 비어 있을 수 없음",
+    "Another entry with the same name already exists" : "같은 이름의 항목이 이미 있습니다.",
+    "Storage informations" : "저장소 정보",
+    "Open the files app settings" : "파일 앱 설정을 열기",
     "You might not have have permissions to view it, ask the sender to share it" : "이것을 볼 권한이 없는 것 같습니다, 보낸 이에게 공유를 요청하세요.",
-    "Set up templates folder" : "템플릿 폴더 설정",
-    "Toggle %1$s sublist" : "%1$s 서브리스트 켜기/끄기",
-    "Toggle grid view" : "바둑판식 보기 전환",
-    "Shares" : "공유",
-    "Shared with others" : "다른 사람과 공유됨",
-    "Shared with you" : "나와 공유됨",
-    "Deleted shares" : "삭제된 공유",
-    "Pending shares" : "보류 중인 공유",
-    "The files is locked" : "이 파일은 잠겼습니다."
+    "The files is locked" : "이 파일은 잠겼습니다.",
+    "Create new templates folder" : "새로운 템플릿 폴더 만들기",
+    "Toggle %1$s sublist" : "%1$s 서브리스트 켜기/끄기"
 },
 "nplurals=1; plural=0;");
