@@ -128,9 +128,9 @@ OC.L10N.register(
     "Renamed by {user}" : "Zmienione przez {user}",
     "Moved by {user}" : "Przeniesione przez {user}",
     "\"remote account\"" : "\"zdalne konto\"",
-    "You created {file}" : "Utworzy‭łeś {file}",
+    "You created {file}" : "Utworzyłeś {file}",
     "You created an encrypted file in {file}" : "Stworzyłeś zaszyfrowany plik w {file}",
-    "{user} created {file}" : "{user} utworzy‭ł {file}",
+    "{user} created {file}" : "{user} utworzył {file}",
     "{user} created an encrypted file in {file}" : "{user} utworzył zaszyfrowany plik w {file}",
     "{file} was created in a public folder" : "{file} został utworzony w katalogu publicznym",
     "You changed {file}" : "Zmieniłeś {file}",
@@ -180,34 +180,31 @@ OC.L10N.register(
     "Toggle selection for file \"{displayName}\"" : "Przełącz zaznaczenie dla pliku \"{displayName}\"",
     "Toggle selection for folder \"{displayName}\"" : "Przełącz zaznaczenie dla katalogu \"{displayName}\"",
     "Rename file" : "Zmień nazwę pliku",
-    "File name" : "Nazwa pliku",
+    "Filename" : "Nazwa pliku",
     "Folder name" : "Nazwa katalogu",
     "This node is unavailable" : "Ten węzeł jest niedostępny",
-    "Download file {name}" : "Pobierz plik {name}",
-    "\"{name}\" is not an allowed filetype." : "\"{name}\" nie jest dozwolonym typem pliku.",
-    "{newName} already exists." : "{newName} już istnieje.",
-    "\"{char}\" is not allowed inside a file name." : "\"{char}\" jest niedozwolone w nazwie pliku.",
-    "Name cannot be empty" : "Nazwa nie może być pusta",
-    "Another entry with the same name already exists" : "Inny wpis o tej samej nazwie już istnieje",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Zmieniono nazwę \"{oldName}\" na \"{newName}\"",
     "Could not rename \"{oldName}\", it does not exist any more" : "Nie można zmienić nazwy \"{oldName}\", już nie istnieje",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nazwa \"{newName}\" jest już używana w folderze \"{dir}\". Wybierz inną nazwę.",
     "Could not rename \"{oldName}\"" : "Nie można zmienić nazwy \"{oldName}\"",
+    "Clear filter" : "Wyczyść filtr",
+    "Type" : "Rodzaj",
+    "Active filters" : "Aktywne filtry",
     "Total rows summary" : "Podsumowanie wszystkich wierszy",
     "Toggle selection for all files and folders" : "Przełącz zaznaczenie dla wszystkich plików i katalogów",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" nie powiodło się w przypadku niektórych elementów",
     "\"{displayName}\" batch action executed successfully" : "Akcja wsadowa \"{displayName}\" została wykonana pomyślnie",
+    "{count} selected" : "wybrano {count}",
     "List of files and folders." : "Lista plików i katalogów.",
     "Column headers with buttons are sortable." : "Nagłówki kolumn z przyciskami są sortowalne.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Ta lista nie jest w pełni renderowana ze względu na wydajność. Pliki będą renderowane podczas poruszania się po liście.",
     "File not found" : "Nie odnaleziono pliku",
-    "Storage informations" : "Informacje o przechowywaniu",
     "{usedQuotaByte} used" : "Wykorzystano {usedQuotaByte}",
     "{relative}% used" : "Wykorzystano {relative}%",
     "Could not refresh storage stats" : "Nie można odświeżyć statystyk przechowywania",
     "Your storage is full, files can not be updated or synced anymore!" : "Magazyn jest pełny. Nie można już zaktualizować ani zsynchronizować plików!",
     "Create" : "Utwórz",
-    "A file or folder with that name already exists." : "Plik lub katalog o tej nazwie już istnieje.",
+    "Submit" : "Wyślij",
     "Transfer ownership of a file or folder" : "Przenieś własność pliku lub katalogu",
     "Choose file or folder to transfer" : "Wybierz plik lub katalog do przeniesienia",
     "Change" : "Zmień",
@@ -232,10 +229,11 @@ OC.L10N.register(
     "Shared" : "Udostępnione",
     "Switch to list view" : "Przełącz na widok listy",
     "Switch to grid view" : "Przełącz na widok siatki",
+    "Upload was cancelled by user" : "Przesyłanie zostało anulowane przez użytkownika",
     "Error during upload: {message}" : "Błąd podczas wysyłania: {message}",
     "Error during upload, status code {status}" : "Błąd podczas wysyłania, kod statusu {status}",
     "Unknown error during upload" : "Nieznany błąd podczas wysyłania",
-    "Open the files app settings" : "Otwórz ustawienia aplikacji plików",
+    "Views" : "Widoki",
     "Files settings" : "Ustawienia Plików",
     "File cannot be accessed" : "Nie można uzyskać dostępu do pliku",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Nie znaleziono pliku lub nie masz uprawnień, aby go wyświetlić. Poproś nadawcę o udostępnienie.",
@@ -261,16 +259,16 @@ OC.L10N.register(
     "Creating file" : "Tworzenie pliku",
     "Blank" : "Pusty",
     "Unable to create new file from template" : "Nie można utworzyć nowego pliku z szablonu",
+    "Deletion cancelled" : "Usuwanie anulowane",
     "Delete permanently" : "Usuń bezpowrotnie",
     "Delete and unshare" : "Usuń i przestań udostępniać",
     "Leave these shares" : "Opuść udostępnienia",
     "Disconnect storages" : "Odłącz magazyny",
     "Delete files" : "Usuń pliki",
     "Delete folders" : "Usuń katalogi",
-    "You are about to delete {count} items." : "Zamierzasz usunąć {count} elementów.",
     "Confirm deletion" : "Potwierdź usunięcie",
     "Cancel" : "Anuluj",
-    "Deletion cancelled" : "Usuwanie anulowane",
+    "The file should now open locally. If you don't see this happening, make sure that the desktop client is installed on your system." : "Plik powinien teraz otworzyć się lokalnie. Jeśli nie widzisz tego, upewnij się, że klient pulpitowy jest zainstalowany w Twoim systemie.",
     "Destination is not a folder" : "Miejsce docelowe nie jest katalogiem",
     "This file/folder is already in that directory" : "Ten plik/katalog znajduje się już w tym katalogu",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Nie można przenieść pliku/katalogu do tego samego katalogu lub do własnego podkatalogu",
@@ -283,22 +281,37 @@ OC.L10N.register(
     "Choose destination" : "Wybierz miejsce docelowe",
     "Copy to {target}" : "Skopiuj do {target}",
     "Move to {target}" : "Przenieś do {target}",
-    "Cancelled move or copy operation" : "Anulowano operację przenoszenia lub kopiowania",
     "Move or copy operation failed" : "Operacja przenoszenia lub kopiowania nie powiodła się",
+    "Cancelled move or copy operation" : "Anulowano operację przenoszenia lub kopiowania",
     "Open folder {displayName}" : "Otwórz katalog {displayName}",
     "Open in Files" : "Otwórz w Plikach",
     "Open details" : "Otwórz szczegóły",
+    "Today" : "Dzisiaj",
+    "Last 7 days" : "Ostatnie 7 dni",
+    "Last 30 days" : "Ostatnie 30 dni",
+    "Documents" : "Dokumenty",
+    "Folders" : "Katalogi",
+    "Audio" : "Dźwięk",
+    "Videos" : "Filmy",
     "Created new folder \"{name}\"" : "Utworzono nowy katalog \"{name}\"",
-    "Filename" : "Nazwa pliku",
     "Unable to initialize the templates directory" : "Nie można zainicjować katalogu szablonów",
-    "Create new templates folder" : "Stwórz nowy folder z szablonami",
     "Templates" : "Szablony",
+    "New template folder" : "Nowy katalog szablonów",
     "In folder" : "W katalogu",
     "Search in folder: {folder}" : "Szukaj w katalogu: {folder}",
     "One of the dropped files could not be processed" : "Jeden z upuszczonych plików nie mógł być przetworzony",
+    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Twoja przeglądarka nie obsługuje interfejsu API systemu plików. Katalogi nie zostaną przesłane",
+    "No files to upload" : "Brak plików do przesłania",
+    "Unable to create the directory {directory}" : "Nie można utworzyć katalogu {directory}",
     "Some files could not be uploaded" : "Nie udało się wysłać niektórych plików",
     "Files uploaded successfully" : "Pliki przesłane pomyślnie",
+    "No files to process" : "Brak plików do przetworzenia",
+    "Some files could not be copied" : "Nie udało się skopiować niektórych plików",
     "Some files could not be moved" : "Niektóre pliki nie mogły zostać przeniesione",
+    "Files copied successfully" : "Pliki skopiowane pomyślnie",
+    "Files moved successfully" : "Pliki zostały przeniesione pomyślnie",
+    "Conflicts resolution skipped" : "Pominięto rozwiązywanie konfliktów",
+    "Upload cancelled" : "Anulowano przesyłanie",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} katalog","{folderCount} katalogi","{folderCount} katalogów","{folderCount} katalogów"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} plik","{fileCount} pliki","{fileCount} plików","{fileCount} plików"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 plik i {folderCount} katalog","1 plik i {folderCount} katalogi","1 plik i {folderCount} katalogów","1 plik i {folderCount} katalogów"],
@@ -309,6 +322,7 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "Pliki i katalogi, które oznaczysz jako ulubione wyświetlą się tutaj",
     "All files" : "Wszystkie pliki",
     "List of your files and folders." : "Lista Twoich plików i katalogów.",
+    "All folders" : "Wszystkie foldery",
     "Personal Files" : "Pliki osobiste",
     "List of your files and folders that are not shared." : "Lista twoich plików i katalogów, które nie są udostępniane",
     "No personal files found" : "Nie znaleziono plików osobistych",
@@ -324,29 +338,15 @@ OC.L10N.register(
     "New text file.txt" : "Nowy plik tekstowy.txt",
     "Direct link was copied (only works for users who have access to this file/folder)" : "Bezpośredni link został skopiowany (działa tylko dla użytkowników, którzy mają dostęp do tego pliku/katalogu)",
     "Copy direct link (only works for users who have access to this file/folder)" : "Skopiuj bezpośredni link (działa tylko dla użytkowników, którzy mają dostęp do tego pliku/katalogu)",
-    "You can only favorite a single file or folder at a time" : "Możesz dodać do ulubionych tylko pojedynczy plik lub katalog",
-    "This file has the tag {tag}" : "Ten plik posiada etykietę {tag}",
-    "This file has the tags {firstTags} and {lastTag}" : "Ten plik posiada etykiety {firstTags} i {lastTag}",
     "\"remote user\"" : "\"użytkownik zdalny\"",
-    "Select the row for {displayName}" : "Wybierz wiersz dla {displayName}",
-    "Open folder {name}" : "Otwórz katalog {name}",
-    "Unselect all" : "Odznacz wszystko",
-    "ascending" : "rosnąco",
-    "descending" : "malejąco",
-    "Sort list by {column} ({direction})" : "Sortuj listę według {column} ({direction})",
-    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Ta lista nie jest w pełni renderowana ze względu na wydajność. Pliki będą renderowane podczas poruszania się po liście.",
-    "Search for an account" : "Wyszukaj konto",
-    "Choose" : "Wybierz",
-    "No files or folders have been deleted yet" : "Żadne pliki ani katalogi nie zostały jeszcze usunięte",
+    "{newName} already exists." : "{newName} już istnieje.",
+    "Name cannot be empty" : "Nazwa nie może być pusta",
+    "Another entry with the same name already exists" : "Inny wpis o tej samej nazwie już istnieje",
+    "Storage informations" : "Informacje o przechowywaniu",
+    "Open the files app settings" : "Otwórz ustawienia aplikacji plików",
     "You might not have have permissions to view it, ask the sender to share it" : "Możesz nie mieć uprawnień, aby go wyświetlić, poproś nadawcę o udostępnienie",
-    "Set up templates folder" : "Skonfiguruj katalog szablonów",
-    "Toggle %1$s sublist" : "Przełącz podlistę %1$s",
-    "Toggle grid view" : "Przełącz widok siatki",
-    "Shares" : "Udostępnione",
-    "Shared with others" : "Udostępnione innym",
-    "Shared with you" : "Udostępnione dla Ciebie",
-    "Deleted shares" : "Usunięte udostępnienia",
-    "Pending shares" : "Oczekujące udostępnienia",
-    "The files is locked" : "Pliki są zablokowane"
+    "The files is locked" : "Pliki są zablokowane",
+    "Create new templates folder" : "Stwórz nowy folder z szablonami",
+    "Toggle %1$s sublist" : "Przełącz podlistę %1$s"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
