@@ -1,9 +1,6 @@
 OC.L10N.register(
     "files",
     {
-    "Storage is temporarily not available" : "Spațiu de stocare este indisponibil temporar",
-    "Storage invalid" : "Spațiu de stocare invalid",
-    "Unknown error" : "Eroare necunoscută",
     "File could not be found" : "Fișierul nu a fost găsit",
     "Move or copy" : "Mută sau copiază",
     "Download" : "Descarcă",
@@ -13,7 +10,6 @@ OC.L10N.register(
     "Show grid view" : "Afișează vizualizarea grilă",
     "Home" : "Acasă",
     "Close" : "Închide",
-    "Favorites" : "Favorite",
     "Could not create folder \"{dir}\"" : "Nu s-a putut crea directorul \"{dir}\"",
     "This will stop your current uploads." : "Asta va opri descărcările curente.",
     "Upload cancelled." : "Încărcare anulată.",
@@ -26,6 +22,7 @@ OC.L10N.register(
     "An unknown error has occurred" : "A apărut o eroare necunoscută!",
     "File could not be uploaded" : "Fișierele nu au putut fi încărcate",
     "Uploading …" : "Încărcare...",
+    "Uploading … ({currentNumber}/{total})" : "Se încarcă … ({currentNumber}/{total})",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} din {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "Încărcarea acestui obiect nu este suportată",
     "Target folder does not exist any more" : "Directorul destinație nu mai există",
@@ -36,22 +33,22 @@ OC.L10N.register(
     "Move" : "Mută",
     "Copy" : "Copiază",
     "Choose target folder" : "Alege directorul destinație",
+    "Set reminder" : "Setează memo",
+    "Edit locally" : "Editează local",
     "Open" : "Deschide",
-    "Delete file" : "Șterge fișier",
-    "Delete folder" : "Șterge director",
     "Disconnect storage" : "Deconectează stocarea",
-    "Leave this share" : "Părăsește acest cerc",
     "Could not load info for file \"{file}\"" : "Nu s-a putut încărca informația pentru fișierul \"{file}\"",
     "Files" : "Fișiere",
     "Details" : "Detalii",
-    "Please select tag(s) to add to the selection" : "Vă rugam să selectați eticheta pentru a le adăuga la selecția dumneavoastră",
-    "Apply tag(s) to selection" : "Aplică etichetele selecției",
+    "Please select tag(s) to add to the selection" : "Selectați eticheta(ele) pentru adăugare la selecție",
+    "Apply tag(s) to selection" : "Aplică eticheta(ele) selecției",
     "Select directory \"{dirName}\"" : "Selectează dosarul \"{dirName}\"",
     "Select file \"{fileName}\"" : "Selectează fișierul \"{fileName}\"",
     "Pending" : "În așteptare",
     "Unable to determine date" : "Nu s-a putut determina data",
     "This operation is forbidden" : "Operațiunea este interzisă",
     "This directory is unavailable, please check the logs or contact the administrator" : "Acest director nu este disponibil, te rugăm verifică logurile sau contactează un administrator",
+    "Storage is temporarily not available" : "Spațiu de stocare este indisponibil temporar",
     "Could not move \"{file}\", target exists" : "Nu s-a putut muta fișierul \"{file}\", există deja un altul cu același nume în directorul destinație",
     "Could not move \"{file}\"" : "Nu s-a putut muta fișierul \"{file}\"",
     "copy" : "copiază",
@@ -59,6 +56,7 @@ OC.L10N.register(
     "Could not copy \"{file}\"" : "Nu s-a putut copia \"{file}\"",
     "Copied {origin} inside {destination}" : "S-a copiat {origin} în {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "S-a copiat {origin} și {nbfiles} alte fișiere în {destination}",
+    "Failed to redirect to client" : "Eroare la redirectarea către client",
     "{newName} already exists" : "{newName} există deja",
     "Could not rename \"{fileName}\", it does not exist any more" : "Nu s-a putut redenumi \"{fileName}\", fișierul nu mai există",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Numele \"{targetName}\" este deja folosit în directorul \"{dir}\". Alege un nume diferit.",
@@ -79,6 +77,8 @@ OC.L10N.register(
     "_including %n hidden_::_including %n hidden_" : ["incluzând %n ascuns","incluzând %nascunse","incluzând %nascuns"],
     "You do not have permission to upload or create files here" : "Nu ai permisiunea de a încărca fișiere aici",
     "_Uploading %n file_::_Uploading %n files_" : ["Se încarcă %n fișier.","Se încarcă %n fișiere.","Se încarcă %n fișiere."],
+    "New" : "Nou",
+    "New file/folder menu" : "Meniu Fișier/Folder nou",
     "Select file range" : "Selectează un interval",
     "{used} of {quota} used" : "{used} din {quota} folosiți",
     "{used} used" : "{used} folosiți",
@@ -96,14 +96,12 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Stocarea dumneavoastra este aproape plină în proporție de  ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["potrivește \"{filter}\"","potrivește \"{filter}\"","potrivește \"{filter}\""],
     "View in folder" : "Vizualizează în director",
-    "Copied!" : "S-a copiat!",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Copiază link direct (funcționeză numai pentru utilizatorii care au acces la acest fișier/director)",
     "Path" : "Cale",
     "_%n byte_::_%n bytes_" : ["%n octet","%n octeți","%n octeți"],
     "Favorited" : "Adăugate la favorite",
     "Favorite" : "Favorit",
-    "You can only favorite a single file or folder at a time" : "Poți adauga la favorite un singur fișier sau director odată",
     "New folder" : "Un nou dosar",
+    "Create new folder" : "Creează director nou",
     "Upload file" : "Încarcă fișier",
     "Recent" : "Recente",
     "Not favorited" : "Scoate de la favorite",
@@ -114,6 +112,7 @@ OC.L10N.register(
     "Removed from favorites" : "Șters din favorite",
     "You added {file} to your favorites" : "Ai adaugat {file} în favorite",
     "You removed {file} from your favorites" : "Ai șters {file} din favorite",
+    "Favorites" : "Favorite",
     "File changes" : "Modificări fișiere",
     "Created by {user}" : "Creat de {user}",
     "Changed by {user}" : "Modificat de {user}",
@@ -121,7 +120,6 @@ OC.L10N.register(
     "Restored by {user}" : "Restaurat de {user}",
     "Renamed by {user}" : "Redenumit de {user}",
     "Moved by {user}" : "Mutat de {user}",
-    "\"remote user\"" : "\"utilizator la distanță\"",
     "You created {file}" : "Ai creat {file}",
     "You created an encrypted file in {file}" : "Ai creat un fișier criptat în {file}",
     "{user} created {file}" : "{user} a creat {file}",
@@ -139,7 +137,7 @@ OC.L10N.register(
     "{user} restored {file}" : "{user} a restaurat {file}",
     "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Ai redenumit {oldfile} (hidden) în {newfile} (hidden)",
     "You renamed {oldfile} (hidden) to {newfile}" : "Ai redenumit {oldfile} (hidden) în {newfile}",
-    "You renamed {oldfile} to {newfile} (hidden)" : "Ai redenumit {oldfile} (hidden) în {newfile} (hidden)",
+    "You renamed {oldfile} to {newfile} (hidden)" : "Ai redenumit {oldfile} în {newfile} (ascuns)",
     "You renamed {oldfile} to {newfile}" : "Ai redenumit {oldfile} în {newfile}",
     "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} a redenumit {oldfile} (hidden) în {newfile} (hidden)",
     "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} a redenumit {oldfile} (hidden) în {newfile}",
@@ -150,8 +148,6 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "Un fișier a fost adăugat în sau șters din <strong>favorites</strong>",
     "A file or folder has been <strong>changed</strong>" : "Un nou fișier sau dosar a fost <strong>modificat</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Un fișier sau dosar favorit a fost <strong>schimbat</strong>",
-    "All files" : "Toate fișierele",
-    "Unlimited" : "Nelimitată",
     "Upload (max. %s)" : "Încarcă (max. %s)",
     "Accept" : "Accept",
     "Reject" : "Respinge",
@@ -165,59 +161,132 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Transferul de proprietate de {path} către {user} s-a finalizat.",
     "in %s" : "în %s",
     "File Management" : "Management fișiere",
+    "Reload current directory" : "Reîncarcă directorul curent",
+    "Go to the \"{dir}\" directory" : "Salt la directorul \"{dir}\" ",
+    "Drag and drop files here to upload" : "Faceți Drag and drop cu fișierele aici pentru upload",
+    "You don’t have permission to upload or create files here" : "Nu aveți permisiunea de a încărca sau crea fișiere aici",
+    "\"{displayName}\" action executed successfully" : "Acțiunea \"{displayName}\" a fost executată cu succes",
+    "\"{displayName}\" action failed" : "Acțiunea \"{displayName}\" a eșuat",
+    "Rename file" : "Redenumire fișier",
+    "Filename" : "Nume fișier",
+    "Folder name" : "Denumire director",
+    "This node is unavailable" : "Acest nod este indisponibil",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "A fost redenumit  \"{oldName}\" cu \"{newName}\"",
+    "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" nu poate fi redenumit deoarece nu mai există",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Numele \"{newName}\" există în folderul \"{dir}\". Selectați, vă rog, alt nume.",
+    "Could not rename \"{oldName}\"" : "\"{oldName}\" nu poate fi redenumit",
+    "Clear filter" : "Șterge filtrul",
+    "Type" : "Tip",
+    "Active filters" : "Filtre active",
+    "Total rows summary" : "Rezumat total rânduri",
+    "\"{displayName}\" failed on some elements " : "\"{displayName}\" a eșuat asupra unor elemente ",
+    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" acțiunea batch a fost executată cu succes",
+    "List of files and folders." : "Listă fișiere și foldere",
+    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Această lista este incomplet afișată din motive de performanță. Fișierele vor fi afișate pe măsură ce navigați prin listă.",
+    "File not found" : "Fișierul nu a fost găsit",
+    "{usedQuotaByte} used" : "{usedQuotaByte} utilizați",
+    "{relative}% used" : "{relative}% utilizat",
+    "Could not refresh storage stats" : "Nu pot actualiza statisticile de stocare",
+    "Your storage is full, files can not be updated or synced anymore!" : "Spațiul de stocare este plin, fișierele nu mai pot fi actualizate sau sincronizate!",
+    "Create" : "Crează",
+    "Submit" : "Trimite",
     "Transfer ownership of a file or folder" : "Transferă proprietatea unui fisier sau dosar",
     "Choose file or folder to transfer" : "Alege fișierul sau dosarul de transferat",
     "Change" : "Modificare",
     "New owner" : "Proprietarul nou",
-    "Search users" : "Cauta utilizatori",
     "Choose a file or folder to transfer" : "Alege un fișier sau dosar de transferat",
     "Transfer" : "Transfer",
     "Transfer {path} to {userid}" : "Transferă {path} către {userid}",
     "Invalid path selected" : "Calea selectată este invalidă",
+    "Unknown error" : "Eroare necunoscută",
     "Ownership transfer request sent" : "Cererea de transfer a fost trimisă",
     "Cannot transfer ownership of a file or folder you do not own" : "Nu se poate transfera proprietatea unui fișier sau dosar daca nu le deții",
+    "Select file or folder to link to" : "Selectați fișierul sau folderul țintă a link-ului",
+    "Choose {file}" : "Selectați {file}",
+    "Loading current folder" : "Se încarcă folderul curent",
+    "No files in here" : "Niciun fișier aici",
+    "Upload some content or sync with your devices!" : "Încarcă ceva conținut sau sincronizează cu dispozitivele tale!",
+    "Go to the previous folder" : "Salt la folderul anterior",
+    "Go back" : "Înapoi",
+    "Share" : "Partajează",
+    "Shared by link" : "Partajat prin link",
+    "Shared" : "Partajat",
+    "Switch to list view" : "Comuta la organizarea tip listă",
+    "Switch to grid view" : "Comută la organizare tip grilă",
+    "Views" : "Mod de viziualizare",
+    "Files settings" : "Setări Fișiere",
+    "File cannot be accessed" : "Fișierul nu poate fi accesat",
+    "Sort favorites first" : "Sortați favoritele primele",
+    "Show hidden files" : "Arată fișierele ascunse",
+    "Crop image previews" : "Previzualizarea imaginii decupate",
+    "Enable the grid view" : "Activați organizarea tip grilă",
+    "Additional settings" : "Setări adiționale",
+    "WebDAV" : "WebDAV",
+    "Copy to clipboard" : "Copiază în clipboard",
+    "Use this address to access your Files via WebDAV" : "Folosiți această adresă pentru a accesa fișierele dumneavoastră folosind WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Dacă ați activat 2FA, trebuie să creați și să folosiți o nouă parolă de aplicație, dând click aici.",
+    "Clipboard is not available" : "Clipboardul este indisponibil",
+    "WebDAV URL copied to clipboard" : "URL-ul WebDAV a fost copiat în clipboard",
     "Unable to change the favourite state of the file" : "Nu s-a putut schimba starea fișierelor favorite",
     "Error while loading the file data" : "A apărut o eroare în timpul încărcării datele din fișier",
     "Pick a template for {name}" : "Alege un șablon pentru {name}",
-    "Cancel" : "Anulare",
-    "Create" : "Crează",
     "Create a new file with the selected template" : "Crează un fișier nou cu șablonul selectat",
     "Creating file" : "Se crează fișierul",
     "Blank" : "Gol",
     "Unable to create new file from template" : "Nu s-a putut creea un fisier nou pentru acest șablon",
-    "Set up templates folder" : "Setează un dosar pentru șabloane",
-    "Templates" : "Șabloane",
+    "Delete permanently" : "Șterge permanent",
+    "Cancel" : "Anulare",
+    "Destination is not a folder" : "Destinația nu este un folder",
+    "This file/folder is already in that directory" : "Acest fișier/folder există în acel dosar",
+    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Nu se poate muta/redenumi un fișier/folder în el însuși sau într-un subfolder al său",
+    "A file or folder with that name already exists in this folder" : "Un fișier sau folder cu acest nume există deja în acest folder",
+    "The file does not exist anymore" : "Fișierul nu mai există",
+    "Copy to {target}" : "Copiază la {target}",
+    "Move to {target}" : "Mută la {target}",
+    "Cancelled move or copy operation" : "Copierea sau mutarea a fost anulată",
+    "Open folder {displayName}" : "Deschide dosarul {displayName}",
+    "Open in Files" : "Deschide în Fișiere",
+    "Open details" : "Deschide detaliile",
+    "Today" : "Azi",
+    "Last 7 days" : "Ultimele 7 zile",
+    "Last 30 days" : "Ultimele 30 de zile",
+    "Documents" : "Documente",
+    "Audio" : "Audio",
+    "Videos" : "Fișiere video",
+    "Created new folder \"{name}\"" : "A fost creat folderul nou \"{name}\"",
     "Unable to initialize the templates directory" : "Nu s-a putut inițializa dosarul cu șabloane",
-    "%s used" : "%s folosiți",
-    "%1$s of %2$s used" : "%1$s din %2$s utilizat",
-    "Show hidden files" : "Arată fișierele ascunse",
-    "Crop image previews" : "Previzualizarea imaginii decupate",
-    "WebDAV" : "WebDAV",
-    "Use this address to access your Files via WebDAV" : "Folosiți această adresă pentru a accesa fișierele dumneavoastră folosind WebDAV",
-    "Toggle %1$s sublist" : "Comută %1$s sublistă",
-    "Toggle grid view" : "Comută vizualizarea grilă",
-    "No files in here" : "Niciun fișier aici",
-    "Upload some content or sync with your devices!" : "Încarcă ceva conținut sau sincronizează cu dispozitivele tale!",
+    "Templates" : "Șabloane",
+    "Some files could not be moved" : "Unele fișiere nu au putut fi mutate",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} folder","{folderCount} foldere","{folderCount} foldere"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} fișier","{fileCount} fișiere","{fileCount} fișiere"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fișier și {folderCount} folder","1 fișier și {folderCount} foldere","1 fișier și {folderCount} foldere"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} fișier și 1 folder","{fileCount} fișiere și 1 folder","{fileCount} fișiere și 1 folder"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} fișiere și {folderCount} dosare",
+    "List of favorites files and folders." : "Lista fișierelor și dosarelor favorite",
+    "No favorites yet" : "Nu aveți favorite încă",
+    "Files and folders you mark as favorite will show up here" : "FIșierele și directoarele pe care le marchezi ca favorite vor apărea aici",
+    "All files" : "Toate fișierele",
+    "List of your files and folders." : "Lista fișierelor și dosarelor personale.",
+    "List of recently modified files and folders." : "Lista fișierelor și dosarelor modificate recent.",
+    "No recently modified files" : "Niciun fișier modificat recent",
+    "Files and folders you recently modified will show up here." : "Fișierele și dosarele modificate recent vor fi afișate aici",
     "No entries found in this folder" : "Niciun element găsit în acest director",
     "Select all" : "Selectează tot",
     "Upload too large" : "Fișierul încărcat este prea mare",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Fișierele pe care încerci să le încarci depășesc limita de încărcare maximă admisă pe acest server.",
-    "No favorites yet" : "Nu aveți favorite încă",
-    "Files and folders you mark as favorite will show up here" : "FIșierele și directoarele pe care le marchezi ca favorite vor apărea aici",
-    "Deleted files" : "Fișiere șterse",
-    "Shares" : "Partajări",
-    "Shared with others" : "Partajat cu alții",
-    "Shared with you" : "Partajat cu tine",
-    "Shared by link" : "Partajat prin link",
-    "Deleted shares" : "Partajări șterse",
-    "Pending shares" : "Partajări in asteptare",
     "Text file" : "Fișier text",
     "New text file.txt" : "Fișier nou.txt",
-    "Select" : "Alege",
-    "You don’t have permission to upload or create files here" : "Nu aveți permisiunea de a încărca sau crea fișiere aici",
-    "New" : "Nou",
-    "Cannot transfer ownership of a file or folder you don't own" : "Nu se poate transfera proprietatea unui fișier sau dosar ce nu le deții",
-    "%s%% of %s used" : "%s%%din %sfolosiți",
-    "Settings" : "Setări"
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Link-ul direct a fost copiat (funcționează doar pentru utilizatorii care au acces la acest fișier/folder)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Copiază link direct (funcționeză numai pentru utilizatorii care au acces la acest fișier/director)",
+    "\"remote user\"" : "\"utilizator la distanță\"",
+    "{newName} already exists." : "{newName} există deja.",
+    "Name cannot be empty" : "Numele nu poate fi gol",
+    "Another entry with the same name already exists" : "Există o altă intrare cu același nume",
+    "Storage informations" : "Informații despre stocare",
+    "Open the files app settings" : "Deschide setările aplicației Fișiere",
+    "You might not have have permissions to view it, ask the sender to share it" : "S-ar putea să nu aveți permisiunea de a-l vedea, solicitați expeditorului să-l partajeze",
+    "The files is locked" : "Fișierul este blocat",
+    "Create new templates folder" : "Creează un nou dosar pentru șabloane",
+    "Toggle %1$s sublist" : "Comută %1$s sublistă"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
