@@ -1,17 +1,15 @@
 OC.L10N.register(
     "files",
     {
-    "Storage is temporarily not available" : "S'archiviatzione immoe no est a disponimentu",
-    "Storage invalid" : "Archiviatzione non vàlida",
-    "Unknown error" : "Errore disconnotu",
     "File could not be found" : "No at fatu a agatare s'archìviu",
     "Move or copy" : "Tràmuda o còpia",
     "Download" : "Iscàrriga",
     "Delete" : "Cantzella",
     "Tags" : "Etichetas",
+    "Show list view" : "Mustra sa visualizatzione de lista",
+    "Show grid view" : "Mustra sa visualizatzione de mosàicu",
     "Home" : "Pàgina printzipale",
     "Close" : "Serra",
-    "Favorites" : "Preferidos",
     "Could not create folder \"{dir}\"" : "No at fatu a creare sa cartella \"{dir}\"",
     "This will stop your current uploads." : "Custu at a firmare is carrigamentos tuos atuales.",
     "Upload cancelled." : "Carrigamentu annulladu.",
@@ -22,7 +20,10 @@ OC.L10N.register(
     "Target folder \"{dir}\" does not exist any more" : "Sa cartella de destinatzione \"{dir}\" no esistit prus",
     "Not enough free space" : "Non b'at logu lìberu",
     "An unknown error has occurred" : "B'at àpidu un'errore disconnotu",
+    "File could not be uploaded" : "Impossìbile carrigare s'archìviu",
     "Uploading …" : "Carrighende ...",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "Carrighende ... ({currentNumber}/{total})",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "Su carrigamentu de s'elementu no est suportadu.",
     "Target folder does not exist any more" : "Sa cartella de destinatzione no esistit prus",
@@ -33,20 +34,24 @@ OC.L10N.register(
     "Move" : "Tràmuda",
     "Copy" : "Còpia",
     "Choose target folder" : "Sèbera cartella de destinatzione",
+    "Set reminder" : "Cunfigura un'apuntu",
+    "Edit locally" : "Modìfica in locale",
     "Open" : "Aberi",
     "Delete file" : "Cantzella archìviu",
-    "Delete folder" : "Cantzella cartella",
+    "Delete folder" : "Cantzella sa cartella",
     "Disconnect storage" : "Disconnete archiviatzione",
-    "Leave this share" : "Lassa custa cumpartzidura",
     "Could not load info for file \"{file}\"" : "No at fatu a carrigare informatziones de s'archìviu \"{file}\"",
     "Files" : "Archìvios",
     "Details" : "Detàllios",
     "Please select tag(s) to add to the selection" : "Seletziona eticheta(s) pro agiùnghere a sa seletzione",
     "Apply tag(s) to selection" : "Àplica eticheta(s) a sa seletzione",
+    "Select directory \"{dirName}\"" : "Seletziona sa cartella \"{dirName}\"",
+    "Select file \"{fileName}\"" : "Seletziona s'archìviu \"{fileName}\"",
     "Pending" : "In suspesu",
     "Unable to determine date" : "Non faghet a determinare sa data",
     "This operation is forbidden" : "Custa operatzione no est permìtida",
     "This directory is unavailable, please check the logs or contact the administrator" : "Custa cartella no est a disponimentu, controlla is informes o cuntata s'amministratzione",
+    "Storage is temporarily not available" : "S'archiviatzione immoe no est a disponimentu",
     "Could not move \"{file}\", target exists" : "No at fatu a tramudare \"{file}\", sa destinatzione esistit giai",
     "Could not move \"{file}\"" : "No at fatu a tramudare \"{file}\"",
     "copy" : "còpia",
@@ -72,8 +77,12 @@ OC.L10N.register(
     "_%n file_::_%n files_" : ["%n archìviu","%n archìvios"],
     "{dirs} and {files}" : "{dirs} e {files}",
     "_including %n hidden_::_including %n hidden_" : ["inclùdidu %n cuadu","inclùdidos %n cuados"],
+    "You do not have permission to upload or create files here" : "Non tenes permissu pro carrigare o creare archìvios inoghe",
     "_Uploading %n file_::_Uploading %n files_" : ["Carrighende %n archìviu","Carrighende %n archìvios"],
+    "New" : "Nou",
+    "New file/folder menu" : "Menù de cartella o archìviu nou",
     "Select file range" : "Seletziona classe de archìviu",
+    "{used}%" : "{used}%",
     "{used} of {quota} used" : "{used} de {quota} impreadu",
     "{used} used" : "{used} impreadu",
     "\"{name}\" is an invalid file name." : "\"{name}\" est unu nùmene de archìviu non vàlidu.",
@@ -90,14 +99,12 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "S'archiviatzione tua est giai prena ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["currispondet '{filter}'","currispondent '{filter}'"],
     "View in folder" : "Visualiza in sa cartella",
-    "Copied!" : "Copiadu!",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Còpia ligòngiu deretu (faghet isceti pro utentes chi tenent atzessu a custu archìviu/cartella)",
     "Path" : "Percursu",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
     "Favorited" : "Preferidu",
     "Favorite" : "Preferidu",
-    "You can only favorite a single file or folder at a time" : "Podes preferire isceti un'archìviu o una cartella cada borta",
     "New folder" : "Cartella noa",
+    "Create new folder" : "Crea cartella noa",
     "Upload file" : "Carriga archìviu",
     "Recent" : "Reghente",
     "Not favorited" : "Non preferidu",
@@ -108,6 +115,7 @@ OC.L10N.register(
     "Removed from favorites" : "Bogadu dae preferidos",
     "You added {file} to your favorites" : "As agiuntu {file} a preferidos",
     "You removed {file} from your favorites" : "As bogadu {file} dae preferidos",
+    "Favorites" : "Preferidos",
     "File changes" : "Modìficas de s'archìviu",
     "Created by {user}" : "Creadu dae {user}",
     "Changed by {user}" : "Modificadu dae {user}",
@@ -115,7 +123,6 @@ OC.L10N.register(
     "Restored by {user}" : "Ripristinadu dae {user}",
     "Renamed by {user}" : "Torradu a numenare dae {user}",
     "Moved by {user}" : "Tramudadu dae {user}",
-    "\"remote user\"" : "\"utèntzia remota\"",
     "You created {file}" : "As creadu {file}",
     "You created an encrypted file in {file}" : "As creadu un'archìviu tzifradu in {file}",
     "{user} created {file}" : "{user} at creadu {file}",
@@ -144,8 +151,6 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "Ant agiuntu o bogadu un'archìviu dae is <strong>preferidos</strong>",
     "A file or folder has been <strong>changed</strong>" : "Ant <strong>cambiadu</strong> un'archìviu o una cartella",
     "A favorite file or folder has been <strong>changed</strong>" : "Ant <strong>cambiadu</strong>un'archìviu o una cartella preferida",
-    "All files" : "Totu is archìvios",
-    "Unlimited" : "Chene lìmites",
     "Upload (max. %s)" : "Càrriga (max. %s)",
     "Accept" : "Atzeta",
     "Reject" : "Refuda",
@@ -159,58 +164,122 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Tràmuda de propriedade de {path} dae {user} cumpletada.",
     "in %s" : "in %s",
     "File Management" : "Gestione archìvios",
+    "Reload current directory" : "Torra a carrigare sa cartella atuale",
+    "Go to the \"{dir}\" directory" : "Bae a sa cartella \"{dir}\"",
+    "Drag and drop files here to upload" : "Traga archìvios inoghe pro ddos carrigare",
+    "You don’t have permission to upload or create files here" : "Non tenes su permissu pro carrigare o creare archìvios inoghe",
+    "Rename file" : "Torra a numenare s'archìviu",
+    "Filename" : "Nùmene de s'archìviu",
+    "Folder name" : "Nùmene de sa cartella",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" s'est torradu a numenare comente \"{newName}\"",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Impossìbile torrare a numenare \"{oldName}\", dae chi no esistit prus",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Su nùmene \"{newName}\" est giai impreadu in sa cartella \"{dir}\". Sèbera unu nùmene diferente.",
+    "Could not rename \"{oldName}\"" : "Impossìbile torrare a numenare \"{oldName}\"",
+    "Clear filter" : "Lìmpia filtru",
+    "Type" : "Genia",
+    "List of files and folders." : "Lista de archìvios e cartellas.",
+    "File not found" : "Archìviu no agatadu",
+    "{usedQuotaByte} used" : "{usedQuotaByte} impreadu",
+    "{relative}% used" : "{relative}% impreadu",
+    "Could not refresh storage stats" : "Impossìbile atualizare is istatìsticas de archiviatzione",
+    "Your storage is full, files can not be updated or synced anymore!" : "S'archiviatzione est prena, non podes prus carrigare o sincronizare archìvios!",
+    "Create" : "Crea",
+    "Submit" : "Imbia",
     "Transfer ownership of a file or folder" : "Tràmuda propriedade de un'archìviu o una cartella",
     "Choose file or folder to transfer" : "Sèbera archìviu o cartella de tramudare",
     "Change" : "Càmbia",
     "New owner" : "Propriedade noa",
-    "Search users" : "Chirca utentes",
     "Choose a file or folder to transfer" : "Sèbera un'archìviu o una cartella de tramudare",
     "Transfer" : "Tràmuda",
     "Transfer {path} to {userid}" : "Tràmuda {path} a {userid}",
     "Invalid path selected" : "Percursu seletzionadu non vàlidu",
+    "Unknown error" : "Errore disconnotu",
     "Ownership transfer request sent" : "Dimanda de tràmuda de propriedade imbiada",
+    "Cannot transfer ownership of a file or folder you do not own" : "Impossìbile tramudare sa propiedade de un'archìviu o de una cartella chi no sunt tuos",
+    "Select file or folder to link to" : "Seletziona un'archìviu o una cartella de ligongiare",
+    "Choose file" : "Sèbera un'archìviu",
+    "Choose {file}" : "Sèbera {file}",
+    "Loading current folder" : "Carrighende sa cartella atuale",
+    "No files in here" : "Perunu archìviu",
+    "Upload some content or sync with your devices!" : "Càrriga cuntenutos o sincroniza cun is dispositivos tuos!",
+    "Go to the previous folder" : "Bae a sa cartella pretzedente",
+    "Go back" : "In segus",
+    "Share" : "Cumpartzidura",
+    "Shared by link" : "Cumpartzidu cun ligòngiu",
+    "Shared" : "Cumpartzidu",
+    "Switch to list view" : "Càmbia a sa vista de s'elencu",
+    "Switch to grid view" : "Càmbia a vista de mosàicu",
+    "Error during upload: {message}" : "Errore in sa càrriga: {message}",
+    "Unknown error during upload" : "Errore disconnotu durante sa càrriga",
+    "Views" : "Visualizatziones",
+    "Files settings" : "Cunfiguratziones de archìvios",
+    "File cannot be accessed" : "Impossìbile atzèdere a s'archìviu",
+    "Show hidden files" : "Mustra archìvios cuados",
+    "Crop image previews" : "Retàllia anteprimas de s'immàgine",
+    "Enable the grid view" : "Ativa sa visualizatzione de mosàicu",
+    "Additional settings" : "Cunfiguratziones in agiunta",
+    "WebDAV" : "WebDAV",
+    "WebDAV URL" : "URL WebDAV",
+    "Copy to clipboard" : "Còpia in is punta de billete",
+    "Use this address to access your Files via WebDAV" : "Imprea custu indiritzu pro intrare in archìvios tràmite WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si as ativadu 2FA, depes creare e impreare una crae de s'aplicatzione noa incarchende inoghe.",
+    "WebDAV URL copied to clipboard" : "URL WebDAV copiadu in punta de billete.",
     "Unable to change the favourite state of the file" : "Non faghet a cambiare s'istadu de preferidu de s'archìviu",
     "Error while loading the file data" : "Errore in su carrigamentu de is datos de s'archìviu",
     "Pick a template for {name}" : "Sèbera unu modellu pro {name}",
-    "Cancel" : "Annulla",
-    "Create" : "Crea",
     "Create a new file with the selected template" : "Crea un'archìviu nou cun su modellu seletzionadu",
     "Creating file" : "Creende s'archìviu",
     "Blank" : "Isbòidu",
     "Unable to create new file from template" : "Non faghet a creare un'archìviu nou dae su modellu",
-    "Set up templates folder" : "Imposta cartella de is modellos",
-    "Templates" : "Modellos",
+    "Delete permanently" : "Cantzella in manera definitiva",
+    "Cancel" : "Annulla",
+    "Destination is not a folder" : "Sa destinatzione no est una cartella",
+    "This file/folder is already in that directory" : "Custu archìviu o cartella est giai in cussu diretòriu",
+    "The file does not exist anymore" : "S'archìviu no esistit prus",
+    "Choose destination" : "Sèbera unu destinu",
+    "Copy to {target}" : "Còpia a {target}",
+    "Move to {target}" : "Tràmuda a {target}",
+    "Cancelled move or copy operation" : "Operatzione de tràmuda o còpia annullada",
+    "Open folder {displayName}" : "Aberi sa cartella {displayName}",
+    "Open in Files" : "Aberi in Archìvios",
+    "Open details" : "Aberi is detàllios",
+    "Today" : "Oe ",
+    "Last 7 days" : "Ùrtimas 7 dies",
+    "Last 30 days" : "Ùrtimas 30 dies",
+    "Documents" : "Documentos",
+    "Folders" : "Cartellas",
+    "Videos" : "Vìdeos",
+    "Created new folder \"{name}\"" : "Cartella noa \"{name}\" creada",
     "Unable to initialize the templates directory" : "Non faghet a initzializare sa cartella de is modellos",
-    "%s used" : "%s impreadu",
-    "%1$s of %2$s used" : "%1$s de %2$s impreadu",
-    "Show hidden files" : "Mustra archìvios cuados",
-    "Crop image previews" : "Retàllia anteprimas de s'imàgine",
-    "WebDAV" : "WebDAV",
-    "Use this address to access your Files via WebDAV" : "Imprea custu indiritzu pro intrare in archìvios tràmite WebDAV",
-    "Toggle %1$s sublist" : "Passa a sa sutalista %1$s",
-    "Toggle grid view" : "Càmbia a visualizatzione in mosàicu",
-    "No files in here" : "Perunu archìviu",
-    "Upload some content or sync with your devices!" : "Càrriga cuntenutos o sincroniza cun is dispositivos tuos!",
+    "Templates" : "Modellos",
+    "Some files could not be moved" : "No at fatu a tramudare carchi archìviu",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} cartella","{folderCount} cartellas"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} archìviu","{fileCount} archìvios"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 archìviu e {folderCount} cartella","1 archìviu e {folderCount} cartellas"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{folderCount} archìviu e 1 cartella","{folderCount} archìvios e 1 cartella"],
+    "{fileCount} files and {folderCount} folders" : "{folderCount} archìvios e {folderCount} cartellas",
+    "List of favorites files and folders." : "Lista de cartellas e de archìvios preferidos.",
+    "No favorites yet" : "Ancora perunu preferidu",
+    "Files and folders you mark as favorite will show up here" : "Is archìvios e is cartellas chi marcas comente preferidos ant a aparèssere inoghe",
+    "All files" : "Totu is archìvios",
+    "List of your files and folders." : "Lista de is cartellas e is archìvios tuos.",
+    "List of recently modified files and folders." : "Lista de cartellas e archìvios modificados de reghente.",
+    "No recently modified files" : "Nissunu archìviu modificadu de reghente",
+    "Files and folders you recently modified will show up here." : "Is cartellas e is archìvios chi apas modificadu de reghente ant a èssere mustrados inoghe.",
     "No entries found in this folder" : "Perunu elementu agatadu in custa cartella",
     "Select all" : "Seletziona totu",
     "Upload too large" : "Carrigamentu tropu mannu",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Is archìvios chi boles carrigare passant sa mannària màssima de carrigamentu de archìvios in custu serbidore.",
-    "No favorites yet" : "Ancora perunu preferidu",
-    "Files and folders you mark as favorite will show up here" : "Is archìvios e is cartellas chi marcas comente preferidos ant a aparèssere inoghe",
-    "Deleted files" : "Archìvios cantzellados",
-    "Shares" : "Cumpartziduras",
-    "Shared with others" : "Cumpartzidu cun àtere",
-    "Shared with you" : "Cumpartzidu cun tegus",
-    "Shared by link" : "Cumpartzidu cun ligòngiu",
-    "Deleted shares" : "Cumpartziduras cantzelladas",
-    "Pending shares" : "Cumpartziduras in suspesu",
     "Text file" : "Archìviu de testu",
     "New text file.txt" : "Archìviu de testu .txt nou",
-    "Select" : "Seletziona",
-    "You don’t have permission to upload or create files here" : "Non tenes su permissu pro carrigare o creare archìvios inoghe",
-    "New" : "Nou",
-    "Cannot transfer ownership of a file or folder you don't own" : "Non faghet a tramudare sa propriedade de un'archìviu o cartella de is chi non ses mere",
-    "%s%% of %s used" : "%s%% de %s impreadu",
-    "Settings" : "Impostatziones"
+    "Copy direct link (only works for users who have access to this file/folder)" : "Còpia ligòngiu deretu (faghet isceti pro utentes chi tenent atzessu a custu archìviu/cartella)",
+    "\"remote user\"" : "\"utèntzia remota\"",
+    "{newName} already exists." : "{newName} esistit giai.",
+    "Name cannot be empty" : "Su nùmene non podet èssere isbòidu",
+    "Another entry with the same name already exists" : "Esistit giai un'intrada cun custu nùmene",
+    "Storage informations" : "Informatziones de s'archiviatzione",
+    "Open the files app settings" : "Aberi sa cunfiguratzione de s'aplicatzione de archìvios",
+    "You might not have have permissions to view it, ask the sender to share it" : "Podet èssere chi non tèngias permissos pro ddu bìdere. Pregunta a chie ti dd'at imbiadu de ddu cumpartzire",
+    "Toggle %1$s sublist" : "Passa a sa sutalista %1$s"
 },
 "nplurals=2; plural=(n != 1);");
