@@ -10,35 +10,6 @@
 
 (function(){
 
-// TODO: move to a separate file
-var MOUNT_OPTIONS_DROPDOWN_TEMPLATE =
-	'<div class="drop dropdown mountOptionsDropdown">' +
-	// FIXME: options are hard-coded for now
-	'	<div class="optionRow">' +
-	'		<input id="mountOptionsEncrypt" name="encrypt" type="checkbox" value="true" checked="checked"/>' +
-	'		<label for="mountOptionsEncrypt">{{t "files_external" "Enable encryption"}}</label>' +
-	'	</div>' +
-	'	<div class="optionRow">' +
-	'		<input id="mountOptionsPreviews" name="previews" type="checkbox" value="true" checked="checked"/>' +
-	'		<label for="mountOptionsPreviews">{{t "files_external" "Enable previews"}}</label>' +
-	'	</div>' +
-	'	<div class="optionRow">' +
-	'		<input id="mountOptionsSharing" name="enable_sharing" type="checkbox" value="true"/>' +
-	'		<label for="mountOptionsSharing">{{t "files_external" "Enable sharing"}}</label>' +
-	'	</div>' +
-	'	<div class="optionRow">' +
-	'		<label for="mountOptionsFilesystemCheck">{{t "files_external" "Check for changes"}}</label>' +
-	'		<select id="mountOptionsFilesystemCheck" name="filesystem_check_changes" data-type="int">' +
-	'			<option value="0">{{t "files_external" "Never"}}</option>' +
-	'			<option value="1" selected="selected">{{t "files_external" "Once every direct access"}}</option>' +
-	'		</select>' +
-	'	</div>' +
-	'	<div class="optionRow">' +
-	'		<input id="mountOptionsEncoding" name="encoding_compatibility" type="checkbox" value="true"/>' +
-	'		<label for="mountOptionsEncoding">{{mountOptionsEncodingLabel}}</label>' +
-	'	</div>' +
-	'</div>';
-
 /**
  * Returns the selection of applicable users in the given configuration row
  *
@@ -53,6 +24,28 @@ function getSelection($row) {
 	return values;
 }
 
+function getSelectedApplicable($row) {
+	var users = [];
+	var groups = [];
+	var multiselect = getSelection($row);
+	$.each(multiselect, function(index, value) {
+		// FIXME: don't rely on string parts to detect groups...
+		var pos = (value.indexOf)?value.indexOf('(group)'): -1;
+		if (pos !== -1) {
+			groups.push(value.substr(0, pos));
+		} else {
+			users.push(value);
+		}
+	});
+
+	// FIXME: this should be done in the multiselect change event instead
+	$row.find('.applicable')
+		.data('applicable-groups', groups)
+		.data('applicable-users', users);
+
+	return { users, groups };
+}
+
 function highlightBorder($element, highlight) {
 	$element.toggleClass('warning-input', highlight);
 	return highlight;
@@ -83,14 +76,22 @@ function highlightInput($input) {
  * Initialize select2 plugin on the given elements
  *
  * @param {Array<Object>} array of jQuery elements
- * @param {int} userListLimit page size for result list
+ * @param {number} userListLimit page size for result list
  */
-function addSelect2 ($elements, userListLimit) {
+function initApplicableUsersMultiselect($elements, userListLimit) {
+	var escapeHTML = function (text) {
+		return text.toString()
+			.split('&').join('&amp;')
+			.split('<').join('&lt;')
+			.split('>').join('&gt;')
+			.split('"').join('&quot;')
+			.split('\'').join('&#039;');
+	};
 	if (!$elements.length) {
 		return;
 	}
-	$elements.select2({
-		placeholder: t('files_external', 'All users. Type to select user or group.'),
+	return $elements.select2({
+		placeholder: t('files_external', 'Type to select account or group.'),
 		allowClear: true,
 		multiple: true,
 		toggleSelect: true,
@@ -114,8 +115,8 @@ function addSelect2 ($elements, userListLimit) {
 					var userCount = 0; // users is an object
 
 					// add groups
-					$.each(data.groups, function(i, group) {
-						results.push({name:group+'(group)', displayname:group, type:'group' });
+					$.each(data.groups, function(gid, group) {
+						results.push({name:gid+'(group)', displayname:group, type:'group' });
 					});
 					// add users
 					$.each(data.users, function(id, user) {
@@ -162,20 +163,20 @@ function addSelect2 ($elements, userListLimit) {
 			return element.name;
 		},
 		formatResult: function (element) {
-			var $result = $('<span><div class="avatardiv"/><span>'+escapeHTML(element.displayname)+'</span></span>');
+			var $result = $('<span><div class="avatardiv"></div><span>'+escapeHTML(element.displayname)+'</span></span>');
 			var $div = $result.find('.avatardiv')
 				.attr('data-type', element.type)
 				.attr('data-name', element.name)
 				.attr('data-displayname', element.displayname);
 			if (element.type === 'group') {
-				var url = OC.imagePath('core','places/contacts-dark'); // TODO better group icon
+				var url = OC.imagePath('core','actions/group');
 				$div.html('<img width="32" height="32" src="'+url+'">');
 			}
 			return $result.get(0).outerHTML;
 		},
 		formatSelection: function (element) {
 			if (element.type === 'group') {
-				return '<span title="'+escapeHTML(element.name)+'" class="group">'+escapeHTML(element.displayname+' '+t('files_external', '(group)'))+'</span>';
+				return '<span title="'+escapeHTML(element.name)+'" class="group">'+escapeHTML(element.displayname+' '+t('files_external', '(Group)'))+'</span>';
 			} else {
 				return '<span title="'+escapeHTML(element.name)+'" class="user">'+escapeHTML(element.displayname)+'</span>';
 			}
@@ -188,11 +189,13 @@ function addSelect2 ($elements, userListLimit) {
 				$div.avatar($div.data('name'),32);
 			}
 		});
+	}).on('change', function(event) {
+		highlightBorder($(event.target).closest('.applicableUsersContainer').find('.select2-choices'), !event.val.length);
 	});
 }
 
 /**
- * @class OCA.External.Settings.StorageConfig
+ * @class OCA.Files_External.Settings.StorageConfig
  *
  * @classdesc External storage config
  */
@@ -200,7 +203,7 @@ var StorageConfig = function(id) {
 	this.id = id;
 	this.backendOptions = {};
 };
-// Keep this in sync with \OC_Mount_Config::STATUS_*
+// Keep this in sync with \OCA\Files_External\MountConfig::STATUS_*
 StorageConfig.Status = {
 	IN_PROGRESS: -1,
 	SUCCESS: 0,
@@ -214,7 +217,7 @@ StorageConfig.Visibility = {
 	DEFAULT: 3
 };
 /**
- * @memberof OCA.External.Settings
+ * @memberof OCA.Files_External.Settings
  */
 StorageConfig.prototype = {
 	_url: null,
@@ -377,8 +380,8 @@ StorageConfig.prototype = {
 };
 
 /**
- * @class OCA.External.Settings.GlobalStorageConfig
- * @augments OCA.External.Settings.StorageConfig
+ * @class OCA.Files_External.Settings.GlobalStorageConfig
+ * @augments OCA.Files_External.Settings.StorageConfig
  *
  * @classdesc Global external storage config
  */
@@ -388,10 +391,10 @@ var GlobalStorageConfig = function(id) {
 	this.applicableGroups = [];
 };
 /**
- * @memberOf OCA.External.Settings
+ * @memberOf OCA.Files_External.Settings
  */
 GlobalStorageConfig.prototype = _.extend({}, StorageConfig.prototype,
-	/** @lends OCA.External.Settings.GlobalStorageConfig.prototype */ {
+	/** @lends OCA.Files_External.Settings.GlobalStorageConfig.prototype */ {
 	_url: 'apps/files_external/globalstorages',
 
 	/**
@@ -431,8 +434,8 @@ GlobalStorageConfig.prototype = _.extend({}, StorageConfig.prototype,
 });
 
 /**
- * @class OCA.External.Settings.UserStorageConfig
- * @augments OCA.External.Settings.StorageConfig
+ * @class OCA.Files_External.Settings.UserStorageConfig
+ * @augments OCA.Files_External.Settings.StorageConfig
  *
  * @classdesc User external storage config
  */
@@ -440,13 +443,13 @@ var UserStorageConfig = function(id) {
 	this.id = id;
 };
 UserStorageConfig.prototype = _.extend({}, StorageConfig.prototype,
-	/** @lends OCA.External.Settings.UserStorageConfig.prototype */ {
+	/** @lends OCA.Files_External.Settings.UserStorageConfig.prototype */ {
 	_url: 'apps/files_external/userstorages'
 });
 
 /**
- * @class OCA.External.Settings.UserGlobalStorageConfig
- * @augments OCA.External.Settings.StorageConfig
+ * @class OCA.Files_External.Settings.UserGlobalStorageConfig
+ * @augments OCA.Files_External.Settings.StorageConfig
  *
  * @classdesc User external storage config
  */
@@ -454,13 +457,13 @@ var UserGlobalStorageConfig = function (id) {
 	this.id = id;
 };
 UserGlobalStorageConfig.prototype = _.extend({}, StorageConfig.prototype,
-	/** @lends OCA.External.Settings.UserStorageConfig.prototype */ {
+	/** @lends OCA.Files_External.Settings.UserStorageConfig.prototype */ {
 
 	_url: 'apps/files_external/userglobalstorages'
 });
 
 /**
- * @class OCA.External.Settings.MountOptionsDropdown
+ * @class OCA.Files_External.Settings.MountOptionsDropdown
  *
  * @classdesc Dropdown for mount options
  *
@@ -469,7 +472,7 @@ UserGlobalStorageConfig.prototype = _.extend({}, StorageConfig.prototype,
 var MountOptionsDropdown = function() {
 };
 /**
- * @memberof OCA.External.Settings
+ * @memberof OCA.Files_External.Settings
  */
 MountOptionsDropdown.prototype = {
 	/**
@@ -491,18 +494,22 @@ MountOptionsDropdown.prototype = {
 			MountOptionsDropdown._last.hide();
 		}
 
-		var template = MountOptionsDropdown._template;
-		if (!template) {
-			template = Handlebars.compile(MOUNT_OPTIONS_DROPDOWN_TEMPLATE);
-			MountOptionsDropdown._template = template;
-		}
-
-		var $el = $(template({
-			mountOptionsEncodingLabel: t('files_external', 'Compatibility with Mac NFD encoding (slow)')
+		var $el = $(OCA.Files_External.Templates.mountOptionsDropDown({
+			mountOptionsEncodingLabel: t('files_external', 'Compatibility with Mac NFD encoding (slow)'),
+			mountOptionsEncryptLabel: t('files_external', 'Enable encryption'),
+			mountOptionsPreviewsLabel: t('files_external', 'Enable previews'),
+			mountOptionsSharingLabel: t('files_external', 'Enable sharing'),
+			mountOptionsFilesystemCheckLabel: t('files_external', 'Check for changes'),
+			mountOptionsFilesystemCheckOnce: t('files_external', 'Never'),
+			mountOptionsFilesystemCheckDA: t('files_external', 'Once every direct access'),
+			mountOptionsReadOnlyLabel: t('files_external', 'Read only'),
+			deleteLabel: t('files_external', 'Disconnect')
 		}));
 		this.$el = $el;
 
-		this.setOptions(mountOptions, visibleOptions);
+		var storage = $container[0].parentNode.className;
+
+		this.setOptions(mountOptions, visibleOptions, storage);
 
 		this.$el.appendTo($container);
 		MountOptionsDropdown._last = this;
@@ -550,7 +557,13 @@ MountOptionsDropdown.prototype = {
 	 * @param {Object} options mount options
 	 * @param {Array} visibleOptions enabled mount options
 	 */
-	setOptions: function(options, visibleOptions) {
+	setOptions: function(options, visibleOptions, storage) {
+		if (storage === 'owncloud') {
+			var ind = visibleOptions.indexOf('encrypt');
+			if (ind > 0) {
+				visibleOptions.splice(ind, 1);
+			}
+		}
 		var $el = this.$el;
 		_.each(options, function(value, key) {
 			var $optionEl = $el.find('input, select').filterAttr('name', key);
@@ -566,7 +579,7 @@ MountOptionsDropdown.prototype = {
 		$el.find('.optionRow').each(function(i, row){
 			var $row = $(row);
 			var optionId = $row.find('input, select').attr('name');
-			if (visibleOptions.indexOf(optionId) === -1) {
+			if (visibleOptions.indexOf(optionId) === -1 && !$row.hasClass('persistent')) {
 				$row.hide();
 			} else {
 				$row.show();
@@ -576,13 +589,13 @@ MountOptionsDropdown.prototype = {
 };
 
 /**
- * @class OCA.External.Settings.MountConfigListView
+ * @class OCA.Files_External.Settings.MountConfigListView
  *
  * @classdesc Mount configuration list view
  *
  * @param {Object} $el DOM object containing the list
  * @param {Object} [options]
- * @param {int} [options.userListLimit] page size in applicable users dropdown
+ * @param {number} [options.userListLimit] page size in applicable users dropdown
  */
 var MountConfigListView = function($el, options) {
 	this.initialize($el, options);
@@ -601,7 +614,7 @@ MountConfigListView.ParameterTypes = {
 };
 
 /**
- * @memberOf OCA.External.Settings
+ * @memberOf OCA.Files_External.Settings
  */
 MountConfigListView.prototype = _.extend({
 
@@ -653,16 +666,16 @@ MountConfigListView.prototype = _.extend({
 	/**
 	 * @param {Object} $el DOM object containing the list
 	 * @param {Object} [options]
-	 * @param {int} [options.userListLimit] page size in applicable users dropdown
+	 * @param {number} [options.userListLimit] page size in applicable users dropdown
 	 */
 	initialize: function($el, options) {
 		var self = this;
 		this.$el = $el;
 		this._isPersonal = ($el.data('admin') !== true);
 		if (this._isPersonal) {
-			this._storageConfigClass = OCA.External.Settings.UserStorageConfig;
+			this._storageConfigClass = OCA.Files_External.Settings.UserStorageConfig;
 		} else {
-			this._storageConfigClass = OCA.External.Settings.GlobalStorageConfig;
+			this._storageConfigClass = OCA.Files_External.Settings.GlobalStorageConfig;
 		}
 
 		if (options && !_.isUndefined(options.userListLimit)) {
@@ -670,6 +683,7 @@ MountConfigListView.prototype = _.extend({
 		}
 
 		this._encryptionEnabled = options.encryptionEnabled;
+		this._canCreateLocal = options.canCreateLocal;
 
 		// read the backend config that was carefully crammed
 		// into the data-configurations attribute of the select
@@ -684,7 +698,7 @@ MountConfigListView.prototype = _.extend({
 	 * Trigger callback for all existing configurations
 	 */
 	whenSelectBackend: function(callback) {
-		this.$el.find('tbody tr:not(#addMountPoint)').each(function(i, tr) {
+		this.$el.find('tbody tr:not(#addMountPoint):not(.externalStorageLoading)').each(function(i, tr) {
 			var backend = $(tr).find('.backend').data('identifier');
 			callback($(tr), backend);
 		});
@@ -692,7 +706,7 @@ MountConfigListView.prototype = _.extend({
 	},
 	whenSelectAuthMechanism: function(callback) {
 		var self = this;
-		this.$el.find('tbody tr:not(#addMountPoint)').each(function(i, tr) {
+		this.$el.find('tbody tr:not(#addMountPoint):not(.externalStorageLoading)').each(function(i, tr) {
 			var authMechanism = $(tr).find('.selectAuthMechanism').val();
 			callback($(tr), authMechanism, self._allAuthMechanisms[authMechanism]['scheme']);
 		});
@@ -716,16 +730,23 @@ MountConfigListView.prototype = _.extend({
 			self.recheckStorageConfig($(this).closest('tr'));
 		});
 
-		this.$el.on('click', 'td.remove>img', function() {
+		this.$el.on('click', 'td.mountOptionsToggle .icon-delete', function() {
 			self.deleteStorageConfig($(this).closest('tr'));
 		});
 
-		this.$el.on('click', 'td.mountOptionsToggle>img', function() {
+		this.$el.on('click', 'td.save>.icon-checkmark', function () {
+			self.saveStorageConfig($(this).closest('tr'));
+		});
+
+		this.$el.on('click', 'td.mountOptionsToggle>.icon-more', function() {
+			$(this).attr('aria-expanded', 'true');
 			self._showMountOptionsDropdown($(this).closest('tr'));
 		});
 
 		this.$el.on('change', '.selectBackend', _.bind(this._onSelectBackend, this));
 		this.$el.on('change', '.selectAuthMechanism', _.bind(this._onSelectAuthMechanism, this));
+
+		this.$el.on('change', '.applicableToAllUsers', _.bind(this._onChangeApplicableToAllUsers, this));
 	},
 
 	_onChange: function(event) {
@@ -738,13 +759,6 @@ MountConfigListView.prototype = _.extend({
 		highlightInput($target);
 		var $tr = $target.closest('tr');
 		this.updateStatus($tr, null);
-
-		var timer = $tr.data('save-timer');
-		clearTimeout(timer);
-		timer = setTimeout(function() {
-			self.saveStorageConfig($tr, null, timer);
-		}, 2000);
-		$tr.data('save-timer', timer);
 	},
 
 	_onSelectBackend: function(event) {
@@ -756,8 +770,11 @@ MountConfigListView.prototype = _.extend({
 		storageConfig.backend = $target.val();
 		$tr.find('.mountPoint input').val('');
 
+		$tr.find('.selectBackend').prop('selectedIndex', 0)
+
 		var onCompletion = jQuery.Deferred();
 		$tr = this.newStorage(storageConfig, onCompletion);
+		$tr.find('.applicableToAllUsers').prop('checked', false).trigger('change');
 		onCompletion.resolve();
 
 		$tr.find('td.configuration').children().not('[type=hidden]').first().focus();
@@ -776,6 +793,19 @@ MountConfigListView.prototype = _.extend({
 		this.saveStorageConfig($tr);
 	},
 
+	_onChangeApplicableToAllUsers: function(event) {
+		var $target = $(event.target);
+		var $tr = $target.closest('tr');
+		var checked = $target.is(':checked');
+
+		$tr.find('.applicableUsersContainer').toggleClass('hidden', checked);
+		if (!checked) {
+			$tr.find('.applicableUsers').select2('val', '', true);
+		}
+
+		this.saveStorageConfig($tr);
+	},
+
 	/**
 	 * Configure the storage config with a new authentication mechanism
 	 *
@@ -802,24 +832,36 @@ MountConfigListView.prototype = _.extend({
 	 *
 	 * @param {StorageConfig} storageConfig storage config to pull values from
 	 * @param {jQuery.Deferred} onCompletion
+	 * @param {boolean} deferAppend
 	 * @return {jQuery} created row
 	 */
-	newStorage: function(storageConfig, onCompletion) {
+	newStorage: function(storageConfig, onCompletion, deferAppend) {
 		var mountPoint = storageConfig.mountPoint;
 		var backend = this._allBackends[storageConfig.backend];
 
+		if (!backend) {
+			backend = {
+				name: 'Unknown: ' + storageConfig.backend,
+				invalid: true
+			};
+		}
+
 		// FIXME: Replace with a proper Handlebar template
-		var $tr = this.$el.find('tr#addMountPoint');
-		this.$el.find('tbody').append($tr.clone());
+		var $template = this.$el.find('tr#addMountPoint');
+		var $tr = $template.clone();
+		if (!deferAppend) {
+			$tr.insertBefore($template);
+		}
 
 		$tr.data('storageConfig', storageConfig);
 		$tr.show();
-		$tr.find('td').last().attr('class', 'remove');
-		$tr.find('td.mountOptionsToggle').removeClass('hidden');
+		$tr.find('td.mountOptionsToggle, td.save, td.remove').removeClass('hidden');
 		$tr.find('td').last().removeAttr('style');
 		$tr.removeAttr('id');
 		$tr.find('select#selectBackend');
-		addSelect2($tr.find('.applicableUsers'), this._userListLimit);
+		if (!deferAppend) {
+			initApplicableUsersMultiselect($tr.find('.applicableUsers'), this._userListLimit);
+		}
 
 		if (storageConfig.id) {
 			$tr.data('id', storageConfig.id);
@@ -833,6 +875,16 @@ MountConfigListView.prototype = _.extend({
 		$tr.addClass(backend.identifier);
 		$tr.find('.backend').data('identifier', backend.identifier);
 
+		if (backend.invalid || (backend.identifier === 'local' && !this._canCreateLocal)) {
+			$tr.find('[name=mountPoint]').prop('disabled', true);
+			$tr.find('.applicable,.mountOptionsToggle').empty();
+			$tr.find('.save').empty();
+			if (backend.invalid) {
+				this.updateStatus($tr, false, t('files_external', 'Unknown backend: {backendName}', {backendName: backend.name}));
+			}
+			return $tr;
+		}
+
 		var selectAuthMechanism = $('<select class="selectAuthMechanism"></select>');
 		var neededVisibility = (this._isPersonal) ? StorageConfig.Visibility.PERSONAL : StorageConfig.Visibility.ADMIN;
 		$.each(this._allAuthMechanisms, function(authIdentifier, authMechanism) {
@@ -880,7 +932,14 @@ MountConfigListView.prototype = _.extend({
 				})
 			);
 		}
-		$tr.find('.applicableUsers').val(applicable).trigger('change');
+		if (applicable.length) {
+			$tr.find('.applicableUsers').val(applicable).trigger('change')
+			$tr.find('.applicableUsersContainer').removeClass('hidden');
+		} else {
+			// applicable to all
+			$tr.find('.applicableUsersContainer').addClass('hidden');
+		}
+		$tr.find('.applicableToAllUsers').prop('checked', !applicable.length);
 
 		var priorityEl = $('<input type="hidden" class="priority" value="' + backend.priority + '" />');
 		$tr.append(priorityEl);
@@ -894,7 +953,8 @@ MountConfigListView.prototype = _.extend({
 				'previews': true,
 				'enable_sharing': false,
 				'filesystem_check_changes': 1,
-				'encoding_compatibility': false
+				'encoding_compatibility': false,
+				'readonly': false,
 			}));
 		}
 
@@ -907,6 +967,14 @@ MountConfigListView.prototype = _.extend({
 	loadStorages: function() {
 		var self = this;
 
+		var onLoaded1 = $.Deferred();
+		var onLoaded2 = $.Deferred();
+
+		this.$el.find('.externalStorageLoading').removeClass('hidden');
+		$.when(onLoaded1, onLoaded2).always(() => {
+			self.$el.find('.externalStorageLoading').addClass('hidden');
+		})
+
 		if (this._isPersonal) {
 			// load userglobal storages
 			$.ajax({
@@ -915,8 +983,10 @@ MountConfigListView.prototype = _.extend({
 				data: {'testOnly' : true},
 				contentType: 'application/json',
 				success: function(result) {
+					result = Object.values(result);
 					var onCompletion = jQuery.Deferred();
-					$.each(result, function(i, storageParams) {
+					var $rows = $();
+					result.forEach(function(storageParams) {
 						var storageConfig;
 						var isUserGlobal = storageParams.type === 'system' && self._isPersonal;
 						storageParams.mountPoint = storageParams.mountPoint.substr(1); // trim leading slash
@@ -926,7 +996,7 @@ MountConfigListView.prototype = _.extend({
 							storageConfig = new self._storageConfigClass();
 						}
 						_.extend(storageConfig, storageParams);
-						var $tr = self.newStorage(storageConfig, onCompletion);
+						var $tr = self.newStorage(storageConfig, onCompletion,true);
 
 						// userglobal storages must be at the top of the list
 						$tr.detach();
@@ -945,15 +1015,29 @@ MountConfigListView.prototype = _.extend({
 							// userglobal storages do not expose configuration data
 							$tr.find('.configuration').text(t('files_external', 'Admin defined'));
 						}
+
+						// don't recheck config automatically when there are a large number of storages
+						if (result.length < 20) {
+							self.recheckStorageConfig($tr);
+						} else {
+							self.updateStatus($tr, StorageConfig.Status.INDETERMINATE, t('files_external', 'Automatic status checking is disabled due to the large number of configured storages, click to check status'));
+						}
+						$rows = $rows.add($tr);
 					});
+					initApplicableUsersMultiselect(self.$el.find('.applicableUsers'), this._userListLimit);
+					self.$el.find('tr#addMountPoint').before($rows);
 					var mainForm = $('#files_external');
 					if (result.length === 0 && mainForm.attr('data-can-create') === 'false') {
 						mainForm.hide();
 						$('a[href="#external-storage"]').parent().hide();
+						$('.emptycontent').show();
 					}
 					onCompletion.resolve();
+					onLoaded1.resolve();
 				}
 			});
+		} else {
+			onLoaded1.resolve();
 		}
 
 		var url = this._storageConfigClass.prototype._url;
@@ -963,15 +1047,27 @@ MountConfigListView.prototype = _.extend({
 			url: OC.generateUrl(url),
 			contentType: 'application/json',
 			success: function(result) {
+				result = Object.values(result);
 				var onCompletion = jQuery.Deferred();
-				$.each(result, function(i, storageParams) {
-					storageParams.mountPoint = storageParams.mountPoint.substr(1); // trim leading slash
+				var $rows = $();
+				result.forEach(function(storageParams) {
+					storageParams.mountPoint = (storageParams.mountPoint === '/')? '/' : storageParams.mountPoint.substr(1); // trim leading slash
 					var storageConfig = new self._storageConfigClass();
 					_.extend(storageConfig, storageParams);
-					var $tr = self.newStorage(storageConfig, onCompletion);
-					self.recheckStorageConfig($tr);
+					var $tr = self.newStorage(storageConfig, onCompletion, true);
+
+					// don't recheck config automatically when there are a large number of storages
+					if (result.length < 20) {
+						self.recheckStorageConfig($tr);
+					} else {
+						self.updateStatus($tr, StorageConfig.Status.INDETERMINATE, t('files_external', 'Automatic status checking is disabled due to the large number of configured storages, click to check status'));
+					}
+					$rows = $rows.add($tr);
 				});
+				initApplicableUsersMultiselect($rows.find('.applicableUsers'), this._userListLimit);
+				self.$el.find('tr#addMountPoint').before($rows);
 				onCompletion.resolve();
+				onLoaded2.resolve();
 			}
 		});
 	},
@@ -1014,6 +1110,19 @@ MountConfigListView.prototype = _.extend({
 		} else {
 			newElement = $('<input type="text" class="'+classes.join(' ')+'" data-parameter="'+parameter+'" placeholder="'+ trimmedPlaceholder+'" />');
 		}
+
+		if (placeholder.defaultValue) {
+			if (placeholder.type === MountConfigListView.ParameterTypes.BOOLEAN) {
+				newElement.find('input').prop('checked', placeholder.defaultValue);
+			} else {
+				newElement.val(placeholder.defaultValue);
+			}
+		}
+
+		if (placeholder.tooltip) {
+			newElement.attr('title', placeholder.tooltip);
+		}
+
 		highlightInput(newElement);
 		$td.append(newElement);
 		return newElement;
@@ -1023,7 +1132,7 @@ MountConfigListView.prototype = _.extend({
 	 * Gets the storage model from the given row
 	 *
 	 * @param $tr row element
-	 * @return {OCA.External.StorageConfig} storage model instance
+	 * @return {OCA.Files_External.StorageConfig} storage model instance
 	 */
 	getStorageConfig: function($tr) {
 		var storageId = $tr.data('id');
@@ -1074,24 +1183,25 @@ MountConfigListView.prototype = _.extend({
 
 		// gather selected users and groups
 		if (!this._isPersonal) {
-			var groups = [];
-			var users = [];
-			var multiselect = getSelection($tr);
-			$.each(multiselect, function(index, value) {
-				var pos = (value.indexOf)?value.indexOf('(group)'): -1;
-				if (pos !== -1) {
-					groups.push(value.substr(0, pos));
-				} else {
-					users.push(value);
-				}
-			});
-			// FIXME: this should be done in the multiselect change event instead
-			$tr.find('.applicable')
-				.data('applicable-groups', groups)
-				.data('applicable-users', users);
+			var multiselect = getSelectedApplicable($tr);
+			var users = multiselect.users || [];
+			var groups = multiselect.groups || [];
+			var isApplicableToAllUsers = $tr.find('.applicableToAllUsers').is(':checked');
 
-			storage.applicableUsers = users;
-			storage.applicableGroups = groups;
+			if (isApplicableToAllUsers) {
+				storage.applicableUsers = [];
+				storage.applicableGroups = [];
+			} else {
+				storage.applicableUsers = users;
+				storage.applicableGroups = groups;
+
+				if (!storage.applicableUsers.length && !storage.applicableGroups.length) {
+					if (!storage.errors) {
+						storage.errors = {};
+					}
+					storage.errors['requiredApplicable'] = true;
+				}
+			}
 
 			storage.priority = parseInt($tr.find('input.priority').val() || '100', 10);
 		}
@@ -1119,14 +1229,22 @@ MountConfigListView.prototype = _.extend({
 			return;
 		}
 		var storage = new this._storageConfigClass(configId);
-		this.updateStatus($tr, StorageConfig.Status.IN_PROGRESS);
 
-		storage.destroy({
-			success: function() {
-				$tr.remove();
-			},
-			error: function() {
-				self.updateStatus($tr, StorageConfig.Status.ERROR);
+		OC.dialogs.confirm(t('files_external', 'Are you sure you want to disconnect this external storage? It will make the storage unavailable in Nextcloud and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself.', {
+				storage: this.mountPoint
+			}), t('files_external', 'Delete storage?'), function(confirm) {
+			if (confirm) {
+				self.updateStatus($tr, StorageConfig.Status.IN_PROGRESS);
+
+				storage.destroy({
+					success: function () {
+						$tr.remove();
+					},
+					error: function (result) {
+						const statusMessage = (result && result.responseJSON) ? result.responseJSON.message : undefined;
+						self.updateStatus($tr, StorageConfig.Status.ERROR, statusMessage);
+					}
+				});
 			}
 		});
 	},
@@ -1151,7 +1269,7 @@ MountConfigListView.prototype = _.extend({
 				if (concurrentTimer === undefined
 					|| $tr.data('save-timer') === concurrentTimer
 				) {
-					self.updateStatus($tr, result.status);
+					self.updateStatus($tr, result.status, result.statusMessage);
 					$tr.data('id', result.id);
 
 					if (_.isFunction(callback)) {
@@ -1159,11 +1277,12 @@ MountConfigListView.prototype = _.extend({
 					}
 				}
 			},
-			error: function() {
+			error: function(result) {
 				if (concurrentTimer === undefined
 					|| $tr.data('save-timer') === concurrentTimer
 				) {
-					self.updateStatus($tr, StorageConfig.Status.ERROR);
+					const statusMessage = (result && result.responseJSON) ? result.responseJSON.message : undefined;
+					self.updateStatus($tr, StorageConfig.Status.ERROR, statusMessage);
 				}
 			}
 		});
@@ -1187,8 +1306,9 @@ MountConfigListView.prototype = _.extend({
 			success: function(result) {
 				self.updateStatus($tr, result.status, result.statusMessage);
 			},
-			error: function() {
-				self.updateStatus($tr, StorageConfig.Status.ERROR);
+			error: function(result) {
+				const statusMessage = (result && result.responseJSON) ? result.responseJSON.message : undefined;
+				self.updateStatus($tr, StorageConfig.Status.ERROR, statusMessage);
 			}
 		});
 	},
@@ -1197,29 +1317,35 @@ MountConfigListView.prototype = _.extend({
 	 * Update status display
 	 *
 	 * @param {jQuery} $tr
-	 * @param {int} status
+	 * @param {number} status
 	 * @param {string} message
 	 */
 	updateStatus: function($tr, status, message) {
 		var $statusSpan = $tr.find('.status span');
-		$statusSpan.removeClass('loading-small success indeterminate error');
 		switch (status) {
 			case null:
 				// remove status
+				$statusSpan.hide();
 				break;
 			case StorageConfig.Status.IN_PROGRESS:
-				$statusSpan.addClass('loading-small');
+				$statusSpan.attr('class', 'icon-loading-small');
 				break;
 			case StorageConfig.Status.SUCCESS:
-				$statusSpan.addClass('success');
+				$statusSpan.attr('class', 'success icon-checkmark-white');
 				break;
 			case StorageConfig.Status.INDETERMINATE:
-				$statusSpan.addClass('indeterminate');
+				$statusSpan.attr('class', 'indeterminate icon-info-white');
 				break;
 			default:
-				$statusSpan.addClass('error');
+				$statusSpan.attr('class', 'error icon-error-white');
 		}
-		$statusSpan.attr('data-original-title', (typeof message === 'string') ? message : '');
+		if (status !== null) {
+			$statusSpan.show();
+		}
+		if (typeof message !== 'string') {
+			message = t('files_external', 'Click to recheck the configuration');
+		}
+		$statusSpan.attr('title', message);
 	},
 
 	/**
@@ -1261,11 +1387,6 @@ MountConfigListView.prototype = _.extend({
 	 * @param {Object} $tr configuration row
 	 */
 	_showMountOptionsDropdown: function($tr) {
-		if (this._preventNextDropdown) {
-			// prevented because the click was on the toggle
-			this._preventNextDropdown = false;
-			return;
-		}
 		var self = this;
 		var storage = this.getStorageConfig($tr);
 		var $toggle = $tr.find('.mountOptionsToggle');
@@ -1274,7 +1395,9 @@ MountConfigListView.prototype = _.extend({
 			'previews',
 			'filesystem_check_changes',
 			'enable_sharing',
-			'encoding_compatibility'
+			'encoding_compatibility',
+			'readonly',
+			'delete'
 		];
 		if (this._encryptionEnabled) {
 			visibleOptions.push('encrypt');
@@ -1282,15 +1405,7 @@ MountConfigListView.prototype = _.extend({
 		dropDown.show($toggle, storage.mountOptions || [], visibleOptions);
 		$('body').on('mouseup.mountOptionsDropdown', function(event) {
 			var $target = $(event.target);
-			if ($toggle.has($target).length) {
-				// why is it always so hard to make dropdowns behave ?
-				// this prevents the click on the toggle to cause
-				// the dropdown to reopen itself
-				// (preventDefault doesn't work here because the click
-				// event is already in the queue and cannot be cancelled)
-				self._preventNextDropdown = true;
-			}
-			if ($target.closest('.dropdown').length) {
+			if ($target.closest('.popovermenu').length) {
 				return;
 			}
 			dropDown.hide();
@@ -1300,16 +1415,19 @@ MountConfigListView.prototype = _.extend({
 			var mountOptions = dropDown.getOptions();
 			$('body').off('mouseup.mountOptionsDropdown');
 			$tr.find('input.mountOptions').val(JSON.stringify(mountOptions));
+			$tr.find('td.mountOptionsToggle>.icon-more').attr('aria-expanded', 'false');
 			self.saveStorageConfig($tr);
 		});
 	}
 }, OC.Backbone.Events);
 
-$(document).ready(function() {
+window.addEventListener('DOMContentLoaded', function() {
 	var enabled = $('#files_external').attr('data-encryption-enabled');
+	var canCreateLocal = $('#files_external').attr('data-can-create-local');
 	var encryptionEnabled = (enabled ==='true')? true: false;
 	var mountConfigListView = new MountConfigListView($('#externalStorage'), {
-		encryptionEnabled: encryptionEnabled
+		encryptionEnabled: encryptionEnabled,
+		canCreateLocal: (canCreateLocal === 'true') ? true: false,
 	});
 	mountConfigListView.loadStorages();
 
@@ -1360,7 +1478,7 @@ $(document).ready(function() {
 		var user = $form.find('[name=username]').val();
 		var password = $form.find('[name=password]').val();
 		var $submit = $form.find('[type=submit]');
-		$submit.val(t('files_external', 'Saving...'));
+		$submit.val(t('files_external', 'Saving …'));
 		$.ajax({
 			type: 'POST',
 			contentType: 'application/json',
@@ -1382,13 +1500,13 @@ $(document).ready(function() {
 	});
 
 	// global instance
-	OCA.External.Settings.mountConfig = mountConfigListView;
+	OCA.Files_External.Settings.mountConfig = mountConfigListView;
 
 	/**
 	 * Legacy
 	 *
 	 * @namespace
-	 * @deprecated use OCA.External.Settings.mountConfig instead
+	 * @deprecated use OCA.Files_External.Settings.mountConfig instead
 	 */
 	OC.MountConfig = {
 		saveStorage: _.bind(mountConfigListView.saveStorageConfig, mountConfigListView)
@@ -1397,14 +1515,14 @@ $(document).ready(function() {
 
 // export
 
-OCA.External = OCA.External || {};
+OCA.Files_External = OCA.Files_External || {};
 /**
  * @namespace
  */
-OCA.External.Settings = OCA.External.Settings || {};
+OCA.Files_External.Settings = OCA.Files_External.Settings || {};
 
-OCA.External.Settings.GlobalStorageConfig = GlobalStorageConfig;
-OCA.External.Settings.UserStorageConfig = UserStorageConfig;
-OCA.External.Settings.MountConfigListView = MountConfigListView;
+OCA.Files_External.Settings.GlobalStorageConfig = GlobalStorageConfig;
+OCA.Files_External.Settings.UserStorageConfig = UserStorageConfig;
+OCA.Files_External.Settings.MountConfigListView = MountConfigListView;
 
 })();
