@@ -4,6 +4,7 @@
  *
  * @author Bart Visscher <bartv@thisnet.nl>
  * @author Björn Schießle <bjoern@schiessle.org>
+ * @author J0WI <J0WI@users.noreply.github.com>
  * @author Joas Schilling <coding@schilljs.com>
  * @author Michael Gapczynski <GapczynskiM@gmail.com>
  * @author Morris Jobke <hey@morrisjobke.de>
@@ -12,7 +13,7 @@
  * @author Roeland Jago Douma <roeland@famdouma.nl>
  * @author scambra <sergio@entrecables.com>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
- * @author Vincent Petry <pvince81@owncloud.com>
+ * @author Vincent Petry <vincent@nextcloud.com>
  *
  * @license AGPL-3.0
  *
@@ -26,29 +27,41 @@
  * GNU Affero General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
+ * along with this program. If not, see <http://www.gnu.org/licenses/>
  *
  */
-
 namespace OCA\Files_Sharing;
 
+use OC\Files\Cache\CacheDependencies;
 use OC\Files\Cache\FailedCache;
-use OC\Files\Filesystem;
-use OC\Files\Storage\Wrapper\PermissionsMask;
+use OC\Files\Cache\NullWatcher;
+use OC\Files\Cache\Watcher;
+use OC\Files\ObjectStore\HomeObjectStoreStorage;
+use OC\Files\Storage\Common;
 use OC\Files\Storage\FailedStorage;
+use OC\Files\Storage\Home;
+use OC\Files\Storage\Wrapper\PermissionsMask;
+use OC\Files\Storage\Wrapper\Wrapper;
+use OC\User\NoUserException;
+use OCA\Files_External\Config\ConfigAdapter;
 use OCP\Constants;
 use OCP\Files\Cache\ICacheEntry;
+use OCP\Files\Config\IUserMountCache;
+use OCP\Files\Folder;
+use OCP\Files\IHomeStorage;
+use OCP\Files\IRootFolder;
+use OCP\Files\Node;
 use OCP\Files\NotFoundException;
 use OCP\Files\Storage\IDisableEncryptionStorage;
 use OCP\Files\Storage\IStorage;
 use OCP\Lock\ILockingProvider;
-use OC\User\NoUserException;
+use OCP\Share\IShare;
+use Psr\Log\LoggerInterface;
 
 /**
  * Convert target path to source path and pass the function call to the correct storage provider
  */
 class SharedStorage extends \OC\Files\Storage\Wrapper\Jail implements ISharedStorage, IDisableEncryptionStorage {
-
 	/** @var \OCP\Share\IShare */
 	private $superShare;
 
@@ -70,22 +83,32 @@ class SharedStorage extends \OC\Files\Storage\Wrapper\Jail implements ISharedSto
 	/** @var string */
 	private $user;
 
-	/**
-	 * @var \OCP\ILogger
-	 */
-	private $logger;
+	private LoggerInterface $logger;
 
 	/** @var  IStorage */
 	private $nonMaskedStorage;
 
-	private $options;
+	private array $mountOptions = [];
 
 	/** @var boolean */
 	private $sharingDisabledForUser;
 
+	/** @var ?Folder $ownerUserFolder */
+	private $ownerUserFolder = null;
+
+	private string $sourcePath = '';
+
+	private static int $initDepth = 0;
+
+	/**
+	 * @psalm-suppress NonInvariantDocblockPropertyType
+	 * @var ?\OC\Files\Storage\Storage $storage
+	 */
+	protected $storage;
+
 	public function __construct($arguments) {
 		$this->ownerView = $arguments['ownerView'];
-		$this->logger = \OC::$server->getLogger();
+		$this->logger = \OC::$server->get(LoggerInterface::class);
 
 		$this->superShare = $arguments['superShare'];
 		$this->groupedShares = $arguments['groupedShares'];
@@ -118,19 +141,65 @@ class SharedStorage extends \OC\Files\Storage\Wrapper\Jail implements ISharedSto
 		return $this->sourceRootInfo;
 	}
 
+	/**
+	 * @psalm-assert \OC\Files\Storage\Storage $this->storage
+	 */
 	private function init() {
 		if ($this->initialized) {
+			if (!$this->storage) {
+				// marked as initialized but no storage set
+				// this is probably because some code path has caused recursion during the share setup
+				// we setup a "failed storage" so `getWrapperStorage` doesn't return null.
+				// If the share setup completes after this the "failed storage" will be overwritten by the correct one
+				$this->logger->warning('Possible share setup recursion detected');
+				$this->storage = new FailedStorage(['exception' => new \Exception('Possible share setup recursion detected')]);
+				$this->cache = new FailedCache();
+				$this->rootPath = '';
+			}
 			return;
 		}
+
 		$this->initialized = true;
+		self::$initDepth++;
+
 		try {
-			Filesystem::initMountPoints($this->superShare->getShareOwner());
-			$sourcePath = $this->ownerView->getPath($this->superShare->getNodeId());
-			list($this->nonMaskedStorage, $this->rootPath) = $this->ownerView->resolvePath($sourcePath);
-			$this->storage = new PermissionsMask([
-				'storage' => $this->nonMaskedStorage,
-				'mask' => $this->superShare->getPermissions()
-			]);
+			if (self::$initDepth > 10) {
+				throw new \Exception("Maximum share depth reached");
+			}
+
+			/** @var IRootFolder $rootFolder */
+			$rootFolder = \OC::$server->get(IRootFolder::class);
+			$this->ownerUserFolder = $rootFolder->getUserFolder($this->superShare->getShareOwner());
+			$sourceId = $this->superShare->getNodeId();
+			$ownerNodes = $this->ownerUserFolder->getById($sourceId);
+
+			if (count($ownerNodes) === 0) {
+				$this->storage = new FailedStorage(['exception' => new NotFoundException("File by id $sourceId not found")]);
+				$this->cache = new FailedCache();
+				$this->rootPath = '';
+			} else {
+				foreach ($ownerNodes as $ownerNode) {
+					$nonMaskedStorage = $ownerNode->getStorage();
+
+					// check if potential source node would lead to a recursive share setup
+					if ($nonMaskedStorage instanceof Wrapper && $nonMaskedStorage->isWrapperOf($this)) {
+						continue;
+					}
+					$this->nonMaskedStorage = $nonMaskedStorage;
+					$this->sourcePath = $ownerNode->getPath();
+					$this->rootPath = $ownerNode->getInternalPath();
+					$this->cache = null;
+					break;
+				}
+				if (!$this->nonMaskedStorage) {
+					// all potential source nodes would have been recursive
+					throw new \Exception('recursive share detected');
+				}
+				$this->storage = new PermissionsMask([
+					'storage' => $this->nonMaskedStorage,
+					'mask' => $this->superShare->getPermissions(),
+				]);
+			}
 		} catch (NotFoundException $e) {
 			// original file not accessible or deleted, set FailedStorage
 			$this->storage = new FailedStorage(['exception' => $e]);
@@ -145,22 +214,30 @@ class SharedStorage extends \OC\Files\Storage\Wrapper\Jail implements ISharedSto
 			$this->storage = new FailedStorage(['exception' => $e]);
 			$this->cache = new FailedCache();
 			$this->rootPath = '';
-			$this->logger->logException($e);
+			$this->logger->error($e->getMessage(), ['exception' => $e]);
 		}
 
 		if (!$this->nonMaskedStorage) {
 			$this->nonMaskedStorage = $this->storage;
 		}
+		self::$initDepth--;
 	}
 
 	/**
 	 * @inheritdoc
 	 */
-	public function instanceOfStorage($class) {
-		if ($class === '\OC\Files\Storage\Common') {
+	public function instanceOfStorage($class): bool {
+		if ($class === '\OC\Files\Storage\Common' || $class == Common::class) {
 			return true;
 		}
-		if (in_array($class, ['\OC\Files\Storage\Home', '\OC\Files\ObjectStore\HomeObjectStoreStorage'])) {
+		if (in_array($class, [
+			'\OC\Files\Storage\Home',
+			'\OC\Files\ObjectStore\HomeObjectStoreStorage',
+			'\OCP\Files\IHomeStorage',
+			Home::class,
+			HomeObjectStoreStorage::class,
+			IHomeStorage::class
+		])) {
 			return false;
 		}
 		return parent::instanceOfStorage($class);
@@ -173,7 +250,7 @@ class SharedStorage extends \OC\Files\Storage\Wrapper\Jail implements ISharedSto
 		return $this->superShare->getId();
 	}
 
-	private function isValid() {
+	private function isValid(): bool {
 		return $this->getSourceRootInfo() && ($this->getSourceRootInfo()->getPermissions() & Constants::PERMISSION_SHARE) === Constants::PERMISSION_SHARE;
 	}
 
@@ -182,24 +259,24 @@ class SharedStorage extends \OC\Files\Storage\Wrapper\Jail implements ISharedSto
 	 *
 	 * @return string
 	 */
-	public function getId() {
+	public function getId(): string {
 		return 'shared::' . $this->getMountPoint();
 	}
 
 	/**
 	 * Get the permissions granted for a shared file
 	 *
-	 * @param string $target Shared target file path
+	 * @param string $path Shared target file path
 	 * @return int CRUDS permissions granted
 	 */
-	public function getPermissions($target = '') {
+	public function getPermissions($path = ''): int {
 		if (!$this->isValid()) {
 			return 0;
 		}
-		$permissions = parent::getPermissions($target) & $this->superShare->getPermissions();
+		$permissions = parent::getPermissions($path) & $this->superShare->getPermissions();
 
 		// part files and the mount point always have delete permissions
-		if ($target === '' || pathinfo($target, PATHINFO_EXTENSION) === 'part') {
+		if ($path === '' || pathinfo($path, PATHINFO_EXTENSION) === 'part') {
 			$permissions |= \OCP\Constants::PERMISSION_DELETE;
 		}
 
@@ -210,11 +287,11 @@ class SharedStorage extends \OC\Files\Storage\Wrapper\Jail implements ISharedSto
 		return $permissions;
 	}
 
-	public function isCreatable($path) {
-		return ($this->getPermissions($path) & \OCP\Constants::PERMISSION_CREATE);
+	public function isCreatable($path): bool {
+		return (bool)($this->getPermissions($path) & \OCP\Constants::PERMISSION_CREATE);
 	}
 
-	public function isReadable($path) {
+	public function isReadable($path): bool {
 		if (!$this->isValid()) {
 			return false;
 		}
@@ -223,93 +300,91 @@ class SharedStorage extends \OC\Files\Storage\Wrapper\Jail implements ISharedSto
 		}
 		/** @var IStorage $storage */
 		/** @var string $internalPath */
-		list($storage, $internalPath) = $this->resolvePath($path);
+		[$storage, $internalPath] = $this->resolvePath($path);
 		return $storage->isReadable($internalPath);
 	}
 
-	public function isUpdatable($path) {
-		return ($this->getPermissions($path) & \OCP\Constants::PERMISSION_UPDATE);
+	public function isUpdatable($path): bool {
+		return (bool)($this->getPermissions($path) & \OCP\Constants::PERMISSION_UPDATE);
 	}
 
-	public function isDeletable($path) {
-		return ($this->getPermissions($path) & \OCP\Constants::PERMISSION_DELETE);
+	public function isDeletable($path): bool {
+		return (bool)($this->getPermissions($path) & \OCP\Constants::PERMISSION_DELETE);
 	}
 
-	public function isSharable($path) {
+	public function isSharable($path): bool {
 		if (\OCP\Util::isSharingDisabledForUser() || !\OC\Share\Share::isResharingAllowed()) {
 			return false;
 		}
-		return ($this->getPermissions($path) & \OCP\Constants::PERMISSION_SHARE);
+		return (bool)($this->getPermissions($path) & \OCP\Constants::PERMISSION_SHARE);
 	}
 
 	public function fopen($path, $mode) {
-		if ($source = $this->getUnjailedPath($path)) {
-			switch ($mode) {
-				case 'r+':
-				case 'rb+':
-				case 'w+':
-				case 'wb+':
-				case 'x+':
-				case 'xb+':
-				case 'a+':
-				case 'ab+':
-				case 'w':
-				case 'wb':
-				case 'x':
-				case 'xb':
-				case 'a':
-				case 'ab':
-					$creatable = $this->isCreatable(dirname($path));
-					$updatable = $this->isUpdatable($path);
-					// if neither permissions given, no need to continue
-					if (!$creatable && !$updatable) {
-						if (pathinfo($path, PATHINFO_EXTENSION) === 'part') {
-							$updatable = $this->isUpdatable(dirname($path));
-						}
-
-						if (!$updatable) {
-							return false;
-						}
+		$source = $this->getUnjailedPath($path);
+		switch ($mode) {
+			case 'r+':
+			case 'rb+':
+			case 'w+':
+			case 'wb+':
+			case 'x+':
+			case 'xb+':
+			case 'a+':
+			case 'ab+':
+			case 'w':
+			case 'wb':
+			case 'x':
+			case 'xb':
+			case 'a':
+			case 'ab':
+				$creatable = $this->isCreatable(dirname($path));
+				$updatable = $this->isUpdatable($path);
+				// if neither permissions given, no need to continue
+				if (!$creatable && !$updatable) {
+					if (pathinfo($path, PATHINFO_EXTENSION) === 'part') {
+						$updatable = $this->isUpdatable(dirname($path));
 					}
 
-					$exists = $this->file_exists($path);
-					// if a file exists, updatable permissions are required
-					if ($exists && !$updatable) {
+					if (!$updatable) {
 						return false;
 					}
+				}
 
-					// part file is allowed if !$creatable but the final file is $updatable
-					if (pathinfo($path, PATHINFO_EXTENSION) !== 'part') {
-						if (!$exists && !$creatable) {
-							return false;
-						}
+				$exists = $this->file_exists($path);
+				// if a file exists, updatable permissions are required
+				if ($exists && !$updatable) {
+					return false;
+				}
+
+				// part file is allowed if !$creatable but the final file is $updatable
+				if (pathinfo($path, PATHINFO_EXTENSION) !== 'part') {
+					if (!$exists && !$creatable) {
+						return false;
 					}
-			}
-			$info = array(
-				'target' => $this->getMountPoint() . $path,
-				'source' => $source,
-				'mode' => $mode,
-			);
-			\OCP\Util::emitHook('\OC\Files\Storage\Shared', 'fopen', $info);
-			return $this->nonMaskedStorage->fopen($this->getUnjailedPath($path), $mode);
+				}
 		}
-		return false;
+		$info = [
+			'target' => $this->getMountPoint() . '/' . $path,
+			'source' => $source,
+			'mode' => $mode,
+		];
+		\OCP\Util::emitHook('\OC\Files\Storage\Shared', 'fopen', $info);
+		return $this->nonMaskedStorage->fopen($this->getUnjailedPath($path), $mode);
 	}
 
 	/**
-	 * see http://php.net/manual/en/function.rename.php
+	 * see https://www.php.net/manual/en/function.rename.php
 	 *
-	 * @param string $path1
-	 * @param string $path2
+	 * @param string $source
+	 * @param string $target
 	 * @return bool
 	 */
-	public function rename($path1, $path2) {
+	public function rename($source, $target): bool {
 		$this->init();
-		$isPartFile = pathinfo($path1, PATHINFO_EXTENSION) === 'part';
-		$targetExists = $this->file_exists($path2);
-		$sameFodler = dirname($path1) === dirname($path2);
+		$isPartFile = pathinfo($source, PATHINFO_EXTENSION) === 'part';
+		$targetExists = $this->file_exists($target);
+		$sameFolder = dirname($source) === dirname($target);
 
-		if ($targetExists || ($sameFodler && !$isPartFile)) {
+		if ($targetExists || ($sameFolder && !$isPartFile)) {
 			if (!$this->isUpdatable('')) {
 				return false;
 			}
@@ -319,7 +394,7 @@ class SharedStorage extends \OC\Files\Storage\Wrapper\Jail implements ISharedSto
 			}
 		}
 
-		return $this->nonMaskedStorage->rename($this->getUnjailedPath($path1), $this->getUnjailedPath($path2));
+		return $this->nonMaskedStorage->rename($this->getUnjailedPath($source), $this->getUnjailedPath($target));
 	}
 
 	/**
@@ -327,14 +402,14 @@ class SharedStorage extends \OC\Files\Storage\Wrapper\Jail implements ISharedSto
 	 *
 	 * @return string
 	 */
-	public function getMountPoint() {
+	public function getMountPoint(): string {
 		return $this->superShare->getTarget();
 	}
 
 	/**
 	 * @param string $path
 	 */
-	public function setMountPoint($path) {
+	public function setMountPoint($path): void {
 		$this->superShare->setTarget($path);
 
 		foreach ($this->groupedShares as $share) {
@@ -347,14 +422,14 @@ class SharedStorage extends \OC\Files\Storage\Wrapper\Jail implements ISharedSto
 	 *
 	 * @return string
 	 */
-	public function getSharedFrom() {
+	public function getSharedFrom(): string {
 		return $this->superShare->getShareOwner();
 	}
 
 	/**
 	 * @return \OCP\Share\IShare
 	 */
-	public function getShare() {
+	public function getShare(): IShare {
 		return $this->superShare;
 	}
 
@@ -363,15 +438,10 @@ class SharedStorage extends \OC\Files\Storage\Wrapper\Jail implements ISharedSto
 	 *
 	 * @return string
 	 */
-	public function getItemType() {
+	public function getItemType(): string {
 		return $this->superShare->getNodeType();
 	}
 
-	/**
-	 * @param string $path
-	 * @param null $storage
-	 * @return Cache
-	 */
 	public function getCache($path = '', $storage = null) {
 		if ($this->cache) {
 			return $this->cache;
@@ -379,12 +449,17 @@ class SharedStorage extends \OC\Files\Storage\Wrapper\Jail implements ISharedSto
 		if (!$storage) {
 			$storage = $this;
 		}
-		$sourceRoot  = $this->getSourceRootInfo();
+		$sourceRoot = $this->getSourceRootInfo();
 		if ($this->storage instanceof FailedStorage) {
 			return new FailedCache();
 		}
 
-		$this->cache = new \OCA\Files_Sharing\Cache($storage, $sourceRoot, $this->superShare);
+		$this->cache = new \OCA\Files_Sharing\Cache(
+			$storage,
+			$sourceRoot,
+			\OC::$server->get(CacheDependencies::class),
+			$this->getShare()
+		);
 		return $this->cache;
 	}
 
@@ -395,16 +470,42 @@ class SharedStorage extends \OC\Files\Storage\Wrapper\Jail implements ISharedSto
 		return new \OCA\Files_Sharing\Scanner($storage);
 	}
 
-	public function getOwner($path) {
+	public function getOwner($path): string {
 		return $this->superShare->getShareOwner();
 	}
 
+	public function getWatcher($path = '', $storage = null): Watcher {
+		if ($this->watcher) {
+			return $this->watcher;
+		}
+
+		// Get node information
+		$node = $this->getShare()->getNodeCacheEntry();
+		if ($node) {
+			/** @var IUserMountCache $userMountCache */
+			$userMountCache = \OC::$server->get(IUserMountCache::class);
+			$mounts = $userMountCache->getMountsForStorageId($node->getStorageId());
+			foreach ($mounts as $mount) {
+				// If the share is originating from an external storage
+				if ($mount->getMountProvider() === ConfigAdapter::class) {
+					// Propagate original storage scan
+					$this->watcher = parent::getWatcher($path, $storage);
+					return $this->watcher;
+				}
+			}
+		}
+
+		// cache updating is handled by the share source
+		$this->watcher = new NullWatcher();
+		return $this->watcher;
+	}
+
 	/**
 	 * unshare complete storage, also the grouped shares
 	 *
 	 * @return bool
 	 */
-	public function unshareStorage() {
+	public function unshareStorage(): bool {
 		foreach ($this->groupedShares as $share) {
 			\OC::$server->getShareManager()->deleteFromSelf($share, $this->user);
 		}
@@ -419,11 +520,11 @@ class SharedStorage extends \OC\Files\Storage\Wrapper\Jail implements ISharedSto
 	 */
 	public function acquireLock($path, $type, ILockingProvider $provider) {
 		/** @var \OCP\Files\Storage $targetStorage */
-		list($targetStorage, $targetInternalPath) = $this->resolvePath($path);
+		[$targetStorage, $targetInternalPath] = $this->resolvePath($path);
 		$targetStorage->acquireLock($targetInternalPath, $type, $provider);
 		// lock the parent folders of the owner when locking the share as recipient
 		if ($path === '') {
-			$sourcePath = $this->ownerView->getPath($this->superShare->getNodeId());
+			$sourcePath = $this->ownerUserFolder->getRelativePath($this->sourcePath);
 			$this->ownerView->lockFile(dirname($sourcePath), ILockingProvider::LOCK_SHARED, true);
 		}
 	}
@@ -435,11 +536,11 @@ class SharedStorage extends \OC\Files\Storage\Wrapper\Jail implements ISharedSto
 	 */
 	public function releaseLock($path, $type, ILockingProvider $provider) {
 		/** @var \OCP\Files\Storage $targetStorage */
-		list($targetStorage, $targetInternalPath) = $this->resolvePath($path);
+		[$targetStorage, $targetInternalPath] = $this->resolvePath($path);
 		$targetStorage->releaseLock($targetInternalPath, $type, $provider);
 		// unlock the parent folders of the owner when unlocking the share as recipient
 		if ($path === '') {
-			$sourcePath = $this->ownerView->getPath($this->superShare->getNodeId());
+			$sourcePath = $this->ownerUserFolder->getRelativePath($this->sourcePath);
 			$this->ownerView->unlockFile(dirname($sourcePath), ILockingProvider::LOCK_SHARED, true);
 		}
 	}
@@ -451,7 +552,7 @@ class SharedStorage extends \OC\Files\Storage\Wrapper\Jail implements ISharedSto
 	 */
 	public function changeLock($path, $type, ILockingProvider $provider) {
 		/** @var \OCP\Files\Storage $targetStorage */
-		list($targetStorage, $targetInternalPath) = $this->resolvePath($path);
+		[$targetStorage, $targetInternalPath] = $this->resolvePath($path);
 		$targetStorage->changeLock($targetInternalPath, $type, $provider);
 	}
 
@@ -462,14 +563,14 @@ class SharedStorage extends \OC\Files\Storage\Wrapper\Jail implements ISharedSto
 		// shares do not participate in availability logic
 		return [
 			'available' => true,
-			'last_checked' => 0
+			'last_checked' => 0,
 		];
 	}
 
 	/**
-	 * @param bool $available
+	 * @param bool $isAvailable
 	 */
-	public function setAvailability($available) {
+	public function setAvailability($isAvailable) {
 		// shares do not participate in availability logic
 	}
 
@@ -480,6 +581,16 @@ class SharedStorage extends \OC\Files\Storage\Wrapper\Jail implements ISharedSto
 
 	public function getWrapperStorage() {
 		$this->init();
+
+		/**
+		 * @psalm-suppress DocblockTypeContradiction
+		 */
+		if (!$this->storage) {
+			$message = "no storage set after init for share " . $this->getShareId();
+			$this->logger->error($message);
+			$this->storage = new FailedStorage(['exception' => new \Exception($message)]);
+		}
+
 		return $this->storage;
 	}
 
@@ -501,7 +612,16 @@ class SharedStorage extends \OC\Files\Storage\Wrapper\Jail implements ISharedSto
 		return parent::file_put_contents($path, $data);
 	}
 
+	/**
+	 * @return void
+	 */
 	public function setMountOptions(array $options) {
+		/* Note: This value is never read */
 		$this->mountOptions = $options;
 	}
+
+	public function getUnjailedPath($path) {
+		$this->init();
+		return parent::getUnjailedPath($path);
+	}
 }
