@@ -61,12 +61,14 @@ OC.L10N.register(
     "Wrong admin recovery password. Please check the password and try again." : "رمز مدیریتی بازیابی غلط است. لطفاً رمز را کنترل کرده و دوباره امتحان نمایید.",
     "Administrator documentation" : "مستندات مدیر",
     "User documentation" : "مستندات کاربر",
+    "Nextcloud help overview" : "نمای کلی راهنمای نکست‌کلود",
     "Invalid SMTP password." : "گذرواژه SMTP نامعتبر است.",
     "Email setting test" : "تست تنظیم پست الکترونیک",
     "Well done, %s!" : "انجام شد،%s!",
     "If you received this email, the email configuration seems to be correct." : "اگر این پست الکترونیک را دریافت کردید ، پیکربندی ایمیل درست است.",
     "Email could not be sent. Check your mail server log" : "پست الکترونیک قابل ارسال نیست. ورود به سیستم سرور پست الکترونیک خود را بررسی کنید",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "ارسال پست الکترونیک با خطا مواجه شد، لطفاً تنظیمات خود را مورد بازبینی قرار دهید. (خطا:%s)",
+    "Disabled accounts" : "حساب‌های غیرفعال",
     "Invalid mail address" : "آدرس ایمیل نامعتبر است",
     "Settings saved" : "تنظیمات ذخیره شد",
     "Unable to change full name" : "امکان تغییر نام کامل وجود ندارد",
@@ -124,26 +126,20 @@ OC.L10N.register(
     "The old server-side-encryption format is enabled. We recommend disabling this." : "The old server-side-encryption format is enabled. We recommend disabling this.",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended.",
     "Supported" : "پشتیبانی شده",
-    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface.",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response.",
     "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation.",
     "PHP configuration option \"output_buffering\" must be disabled" : "گزینه «output_buffering» تنظیمات پی‌اچ‌پی باید غیرفعال شود",
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update.",
     "Architecture" : "Architecture",
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel.",
-    "Profile information" : "Profile information",
-    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled",
+    "Profile information" : "اطلاعات نمایه",
     "Nextcloud settings" : "تنظیمات نکست کلود",
     "Task:" : "Task:",
     "Machine translation" : "Machine translation",
     "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment.",
-    "Speech-To-Text" : "Speech-To-Text",
-    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "Speech-To-Text can be implemented by different apps. Here you can set which app should be used.",
-    "None of your currently installed apps provide Speech-To-Text functionality" : "None of your currently installed apps provide Speech-To-Text functionality",
     "Image generation" : "Image generation",
     "Text processing" : "Text processing",
     "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task.",
-    "None of your currently installed apps provide Text processing functionality" : "None of your currently installed apps provide Text processing functionality",
     "Here you can decide which group can access certain sections of the administration settings." : "Here you can decide which group can access certain sections of the administration settings.",
     "None" : "هیچ‌کدام",
     "Unable to modify setting" : "Unable to modify setting",
@@ -272,7 +268,7 @@ OC.L10N.register(
     "Change password" : "تغییر گذر واژه",
     "Your profile picture" : "نگارهٔ نمایه‌تان",
     "Upload profile picture" : "بارگذاری نگارهٔ نمایه",
-    "Choose profile picture from Files" : "Choose profile picture from Files",
+    "Choose profile picture from Files" : "تصویر نمایه‌تان را از پرونده‌ها انتخاب کنید",
     "Remove profile picture" : "برداشتن نگارهٔ نمایه",
     "The file must be a PNG or JPG" : "The file must be a PNG or JPG",
     "Picture provided by original account" : "نگاره فراهم شده به دست حساب اصلی",
@@ -315,7 +311,6 @@ OC.L10N.register(
     "Your organisation" : "نام سازمان",
     "Your phone number" : "شماره تلفن شما",
     "Edit your Profile visibility" : "ویرایش امکان مشاهده پروفایل",
-    "Unable to update profile enabled state" : "Unable to update profile enabled state",
     "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "ملاک عمل، تنظیمات با محدودیت بالاتر است که اعمال می شوند. برای مثال، اگر \"قابلیت دیده شدن\" در وضعیت \"نمایش برای همه\" تنظیم شده باشد و \"محدوده دیده شدن\" در وضعیت \"خصوصی\" تنظیم شده باشد، تنظیم به وضعیت \"خصوصی\" که محدودیت بیشتری اعمال میکند اعمال خواهد شد.",
     "Unable to update visibility of {displayId}" : "Unable to update visibility of {displayId}",
     "Your role" : "نقش شما",
@@ -392,6 +387,7 @@ OC.L10N.register(
     "Your browser does not support WebAuthn." : "Your browser does not support WebAuthn.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "به عنوان مدیر ، می توانید رفتار اشتراک گذاری را تنظیم کنید. لطفا برای اطلاعات بیشتر به اسناد مراجعه کنید.",
     "You need to enable the File sharing App." : "You need to enable the File sharing App.",
+    "All accounts" : "همهٔ حساب‌ها",
     "Admins" : "مدیران",
     "Group name" : "نام گروه",
     "Sending…" : "در حال ارسال",
@@ -418,6 +414,7 @@ OC.L10N.register(
     "Featured apps" : "برنامه‌های برگزیده",
     "Supported apps" : "Supported apps",
     "Show to everyone" : "نمایش به همه",
+    "Show to logged in accounts only" : "فقط به حساب‌هایی که وارد شده‌اند نمایش یابد",
     "Hide" : "پنهان کردن",
     "Download and enable" : "بارگیری و فعال سازی",
     "Allow untested app" : "Allow untested app",
@@ -435,6 +432,7 @@ OC.L10N.register(
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "There were too many requests from your network. Retry later or contact your administrator if this is an error.",
     "Error" : "خطا",
     "Forum" : "انجمن",
+    "Nextcloud help & privacy resources" : "منابع راهنما و حریم شخصی نکست‌کلود",
     "Legal notice" : "توصیهٔ حقوقی",
     "Privacy policy" : "سیاست محرمانگی",
     "None/STARTTLS" : "None/STARTTLS",
@@ -473,112 +471,37 @@ OC.L10N.register(
     "No user supplied" : "هیچ کاربری تعریف نشده است",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "لطفاً رمز عبور بازیابی مدیر را ارائه دهید. در غیر این صورت ، تمام داده های کاربر از بین می رود.",
     "Backend does not support password change, but the user's encryption key was updated." : " سرور از تغییرات گذرواژه پشتیبانی نمی کند، اما کلید رمزگذاری کاربر به روز شد.",
-    "installing and updating apps via the App Store or Federated Cloud Sharing" : "installing and updating apps via the App Store or Federated Cloud Sharing",
-    "Federated Cloud Sharing" : "اشتراک گذاری ابر فدرال",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL از نسخه (%2$s) منسوخ شده %1$s استفاده می کند. لطفا سیستم عامل خود را به روز کنید یا ویژگی هایی از قبیل %3$s قابل اعتماد کار نمی کنند.",
-    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "نمی توان تعیین کرد که آیا نسخه TLS متعلق به cURL قدیمی است یا خیر. زیرا خطایی در طول درخواست HTTPS به https://nextcloud.com رخ داده است. لطفاً فایل گزارش نکست‌کلود را برای جزئیات بیشتر بررسی کنید.",
-    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration.",
-    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function.",
-    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades.",
-    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades.",
-    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply <code>opcache.file_cache_only=0</code> to your PHP configuration and use the file cache as second level cache only." : "The shared memory based OPcache is disabled. For better performance, it is recommended to apply <code>opcache.file_cache_only=0</code> to your PHP configuration and use the file cache as second level cache only.",
-    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>.",
-    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>.",
-    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>.",
     "You need to set your user email before being able to send test emails. Go to %s for that." : "You need to set your user email before being able to send test emails. Go to %s for that.",
     "Invalid user" : "کاربر نامعتبر",
     "Your username is: %s" : "نام کاربری شما %s هست.",
     "Logged in user must be a subadmin" : "ورود به سیستم کاربر باید زیرمجموعه باشد",
     "A background job is pending that checks for user imported SSL certificates. Please check back later." : "A background job is pending that checks for user imported SSL certificates. Please check back later.",
     "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below.",
-    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them.",
+    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster.",
     "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher.",
     "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher.",
     "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher.",
-    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system.",
-    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "هنگامی که گروه ها انتخاب و حذف شدند ، از این منطق استفاده می کنند تا مشخص شود آیا کاربر 2FA اجباری دارد: اگر هیچ گروه انتخاب نشده باشند ، 2FA برای همه غیر از اعضای گروه های محروم امکان پذیر است. در صورت انتخاب گروه ها ، 2FA برای همه اعضای این گروه فعال است. اگر کاربر هر دو در یک گروه منتخب و مستثنی باشد ، انتخاب شده دارای اولویت است و 2FA اجرا می شود.",
-    "Enable all" : "به کار انداختن همه",
-    "Internet Explorer" : "اینترنت اکسپلور",
-    "Edge" : "اج",
-    "Firefox" : "فایرفاکس",
-    "Google Chrome" : "کروم گوگل",
-    "Safari" : "سافاری",
-    "iPhone" : "آی‌فون",
-    "iPad" : "آی‌پد",
-    "Sync client - {os}" : "کارخواه هم‌گام سازی - {os}",
-    "Error while deleting the token" : "هنگام حذف نشانه خطایی رخ داد",
-    "Use the credentials below to configure your app or device." : "برای پیکربندی کردن برنامه یا وسیله خود از اعتبارنامه زیر استفاده کنید.",
-    "For security reasons this password will only be shown once." : "به دلایل امنیتی این گذرواژه فقط یک بار نشان داده می شود.",
-    "Username" : "نام کاربری",
-    "Copied!" : "رونوشت شد!",
-    "Copy" : "رونوشت",
-    "Execute one task with each page loaded. Use case: Single user instance." : "اجرای یک وظیفه با هر بار شدن صفحه. مناسب نمونه‌های تک کاربره.",
-    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "پروندهٔ cron.php ثبت شده در یک خدمت webcron برای فراخوانی هر ۵ دقیقه یک بار روی HTTP. مناسب برای نمونه‌های بسیار کوچک ( تا ۵ کاربر بسته به استفاده).",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "برای اجرای این کار نیاز به افزونهٔ PHP POSIX دارید. برای جزییات بیش‌تر، {linkstart}مستندات پی‌اچ‌پی{linkend} را ببینید.",
-    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "استفاده از خدمت کرون سامانه برای فراخوانی cron.php هر ۵ دقیقه یک بار. مناسب تمامی نمونه‌ها.",
-    "The cron.php needs to be executed by the system user \"{user}\"." : "پروندهٔ cron.php باید به دست کاربر سامانه‌ای {user} قابل اجرا باشد.",
-    "Enable or disable profile by default for new users." : "به یا از کار انداختن نمایه برای کاربران جدید به صورت پیش‌گزیده.",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "در حال برداشتن گروه {group} هستید. کاربران حذف نخواهند شد.",
-    "Please confirm the group removal " : "لطفاً برداشتن گروه را تأیید کنید",
-    "Your profile information" : "Your profile information",
-    "Your email address" : "پست الکترونیکی شما",
-    "Additional emails" : "Additional emails",
-    "Enable Profile" : "فعال کردن پروفایل",
-    "Your Twitter handle" : "آی دی شما در توییتر",
-    "You do not have permissions to see the details of this user" : "شما مجوز دیدن جزئیات این کاربر را ندارید",
-    "Edit display name" : "Edit display name",
-    "Add new password" : "رمزعبور جدید اضافه کنید",
-    "Add new email address" : "آدرس ایمیل جدید اضافه کنید",
-    "Add user to group" : "Add user to group",
-    "Set user as admin for" : "کاربر را به عنوان مدیر تنظیم کنید",
-    "Select user quota" : "سهمیه کاربر را انتخاب کنید",
-    "Select manager" : "Select manager",
-    "Toggle user actions menu" : "Toggle user actions menu",
-    "Delete user" : "حذف کردن کاربر",
-    "Wipe all devices" : "همه دستگاه ها را پاک کنید.",
-    "Disable user" : "غیرفعال کردن کاربر",
-    "Enable user" : "کاربر را فعال کنید",
-    "Edit User" : "ویرایش کاربر",
-    "User's table" : "User's table",
-    "New user" : "کاربر جدید",
-    "Will be autogenerated" : "به صورت خودکار تولید می شود",
-    "Select user manager" : "Select user manager",
-    "Add a new user" : "افزودن کاربر جدید",
-    "User backend" : "پشتیبان کاربر",
-    "No users in here" : "هیچ کاربر در اینجا نیست",
-    "Name your device" : "Name your device",
-    "Server error while trying to add WebAuthn device" : "Server error while trying to add WebAuthn device",
-    "{license}-licensed" : "دارای مجوز- {license}",
-    "by {author}\n{license}" : "by {author}\n{license}",
-    "Enter group name" : "Enter group name",
-    "Add group" : "افزودن گروه",
-    "Active users" : "کاربران فعال",
-    "Disabled users" : "کاربران غیرفعال شده است",
-    "Default quota:" : "سهمیه پیش فرض:",
-    "Show Languages" : "نمایش زبانها",
-    "Show user backend" : "نمایش پس زمینه کاربر",
-    "Send email to new user" : "ارسال ایمیل به کاربر جدید",
-    "Not saved" : "ناموفق در ذخیره",
-    "Twitter" : "توییتر",
-    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Not available as federation has been disabled for your account, contact your system administrator if you have any questions",
-    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions",
-    "Show to logged in users only" : "نمایش فقط برای کاربران وارد شده به سامانه",
-    "Enable untested app" : "برنامه آزمایش نشده را فعال کنید",
-    "SMTP Username" : "نام کاربری SMTP",
-    "Expire after" : "Expire after",
-    "day(s)" : "روز(s)",
-    "Exclude groups from password requirements:" : "Exclude groups from password requirements:",
-    "Set default expiration date" : "اعمال تاریخ اتمام پیش فرض",
-    "Exclude groups from creating link shares:" : "Exclude groups from creating link shares:",
+    "Speech-To-Text" : "Speech-To-Text",
+    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "Speech-To-Text can be implemented by different apps. Here you can set which app should be used.",
+    "None of your currently installed apps provide Speech-To-Text functionality" : "None of your currently installed apps provide Speech-To-Text functionality",
+    "None of your currently installed apps provide Text processing functionality" : "None of your currently installed apps provide Text processing functionality",
     "Exclude groups from sharing" : "مستثنی شدن گروه ها از اشتراک گذاری",
     "These groups will still be able to receive shares, but not to initiate them." : "این گروه ها هنوز هم می توانند سهم دریافت کنند ، اما نه آنها را شروع کنند.",
     "Allow username autocompletion in share dialog and allow access to the system address book" : "Allow username autocompletion in share dialog and allow access to the system address book",
-    "Allow username autocompletion to users within the same groups and limit system address books to users in the same groups" : "Allow username autocompletion to users within the same groups and limit system address books to users in the same groups",
-    "Allow username autocompletion to users based on phone number integration" : "Allow username autocompletion to users based on phone number integration",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster.",
+    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system.",
+    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "هنگامی که گروه ها انتخاب و حذف شدند ، از این منطق استفاده می کنند تا مشخص شود آیا کاربر 2FA اجباری دارد: اگر هیچ گروه انتخاب نشده باشند ، 2FA برای همه غیر از اعضای گروه های محروم امکان پذیر است. در صورت انتخاب گروه ها ، 2FA برای همه اعضای این گروه فعال است. اگر کاربر هر دو در یک گروه منتخب و مستثنی باشد ، انتخاب شده دارای اولویت است و 2FA اجرا می شود.",
+    "{license}-licensed" : "دارای مجوز- {license}",
+    "Username" : "نام کاربری",
+    "Execute one task with each page loaded. Use case: Single user instance." : "اجرای یک وظیفه با هر بار شدن صفحه. مناسب نمونه‌های تک کاربره.",
+    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "پروندهٔ cron.php ثبت شده در یک خدمت webcron برای فراخوانی هر ۵ دقیقه یک بار روی HTTP. مناسب برای نمونه‌های بسیار کوچک ( تا ۵ کاربر بسته به استفاده).",
+    "The cron.php needs to be executed by the system user \"{user}\"." : "پروندهٔ cron.php باید به دست کاربر سامانه‌ای {user} قابل اجرا باشد.",
+    "Enable or disable profile by default for new users." : "به یا از کار انداختن نمایه برای کاربران جدید به صورت پیش‌گزیده.",
+    "Additional emails" : "Additional emails",
+    "Enable Profile" : "فعال کردن پروفایل",
     "No users" : "No users",
     "Loading users …" : "Loading users …",
     "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list.",
+    "New user" : "کاربر جدید",
     "Groups (required)" : "Groups (required)",
     "Set user groups" : "Set user groups",
     "Administered groups" : "Administered groups",
@@ -588,12 +511,32 @@ OC.L10N.register(
     "Set user manager" : "Set user manager",
     "Username will be autogenerated" : "Username will be autogenerated",
     "Username (required)" : "Username (required)",
-    "_{userCount} user …_::_{userCount} users …_" : ["{userCount} user …","{userCount} users …"],
-    "_{userCount} user_::_{userCount} users_" : ["{userCount} user","{userCount} users"],
+    "User backend" : "پشتیبان کاربر",
     "User actions" : "User actions",
     "Loading user …" : "Loading user …",
+    "You do not have permissions to see the details of this user" : "شما مجوز دیدن جزئیات این کاربر را ندارید",
+    "Add user to group" : "Add user to group",
+    "Set user as admin for" : "کاربر را به عنوان مدیر تنظیم کنید",
+    "Select user quota" : "سهمیه کاربر را انتخاب کنید",
+    "Delete user" : "حذف کردن کاربر",
+    "Wipe all devices" : "همه دستگاه ها را پاک کنید.",
+    "Disable user" : "غیرفعال کردن کاربر",
+    "Enable user" : "کاربر را فعال کنید",
     "Failed to update user manager" : "Failed to update user manager",
+    "Toggle user actions menu" : "Toggle user actions menu",
     "User management settings" : "User management settings",
-    "Send welcome email to new users" : "Send welcome email to new users"
+    "Show user backend" : "نمایش پس زمینه کاربر",
+    "Send welcome email to new users" : "Send welcome email to new users",
+    "Name your device" : "Name your device",
+    "Server error while trying to add WebAuthn device" : "Server error while trying to add WebAuthn device",
+    "by {author}\n{license}" : "by {author}\n{license}",
+    "Active users" : "کاربران فعال",
+    "Disabled users" : "کاربران غیرفعال شده است",
+    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Not available as federation has been disabled for your account, contact your system administrator if you have any questions",
+    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions",
+    "Show to logged in users only" : "نمایش فقط برای کاربران وارد شده به سامانه",
+    "Nextcloud help resources" : "منابع راهنمای نکست‌کلود",
+    "SMTP Username" : "نام کاربری SMTP",
+    "Active accounts" : "حساب‌های فعال"
 },
 "nplurals=2; plural=(n > 1);");
