@@ -21,7 +21,7 @@ OC.L10N.register(
     "Group list is empty" : "Daftar grup kosong",
     "Unable to retrieve the group list" : "Tidak dapat mengambil daftar grup",
     "{actor} added you to group {group}" : "{actor} menambahkanmu ke grup {group}",
-    "You added {user} to group {group}" : "Kamu menambahkan {user} ke grup {group}",
+    "You added {user} to group {group}" : "Anda menambahkan {user} ke grup {group}",
     "{actor} added {user} to group {group}" : "{actor} menambahkan {user} kedalam grup {group}",
     "An administrator added you to group {group}" : "Admin telah menambahkan Anda ke grup {group}",
     "An administrator added {user} to group {group}" : "Admin menambahkan {user} kedalam grup {group}",
@@ -31,15 +31,13 @@ OC.L10N.register(
     "An administrator removed you from group {group}" : "Admin mengeluarkan Anda dari grup {group}",
     "An administrator removed {user} from group {group}" : "Admin mengeluarkan {user} dari grup {group}",
     "Your <strong>group memberships</strong> were modified" : "<strong>Keanggotaan grup</strong> Anda telah diubah",
-    "{actor} changed your password" : "{actor} mengganti kata sandi anda",
+    "{actor} changed your password" : "{actor} mengganti kata sandi Anda",
     "You changed your password" : "Anda mengganti kata sandi",
-    "Your password was reset by an administrator" : "Kata sandi anda telah diatur ulang oleh administrator",
+    "Your password was reset by an administrator" : "Kata sandi Anda telah diatur ulang oleh administrator",
     "Your password was reset" : "Kata sandi Anda telah disetel ulang",
-    "{actor} changed your email address" : "{actor} mengubah alamat surel anda",
+    "{actor} changed your email address" : "{actor} mengubah alamat surel Anda",
     "You changed your email address" : "Anda mengubah alamat surel sendiri",
     "Your email address was changed by an administrator" : "Alamat surel Anda telah diubah oleh administrator",
-    "You created app password \"{token}\"" : "Anda telah membuat kata sandi aplikasi \"{token}\"",
-    "An administrator created app password \"{token}\"" : "Administrator membuat sandi aplikasi \"{token}\"",
     "You deleted app password \"{token}\"" : "Anda menghapus kata sandi aplikasi \"{token}\"",
     "You renamed app password \"{token}\" to \"{newToken}\"" : "Anda mengubah kata sandi aplikasi \"{token}\" ke \"{newToken}\"",
     "You granted filesystem access to app password \"{token}\"" : "Anda mengijinkan mengakses berkas sistem ke kata sandi aplikasi \"{token}\"",
@@ -50,32 +48,27 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "Pembersihan secara remote telah dimulai di %1$s",
     "Remote wipe has finished on %1$s" : "Pembersihan secara remote telah selesai di %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>Kata sandi</strong> atau <strong>surel</strong> Anda telah diubah",
+    "Settings" : "Setelan",
     "Could not remove app." : "Tidak dapat hapus aplikasi.",
     "Could not update app." : "Tidak dapat perbarui aplikasi.",
     "Wrong password" : "Kata sandi salah",
     "Unable to change personal password" : "Tidak dapat mengubah kata sandi pribadi",
     "Saved" : "Disimpan",
-    "No user supplied" : "Tidak ada pengguna yang diberikan",
     "Unable to change password. Password too long." : "Tidak dapat berubah kata sandi. Kata sandi terlalu panjang.",
     "Authentication error" : "Terjadi kesalahan saat otentikasi",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Berikan kata sandi pemulihan admin; Jika tidak, semua data pengguna akan hilang.",
     "Wrong admin recovery password. Please check the password and try again." : "Kata sandi pemulihan admin salah. Periksa kata sandi dan ulangi kembali.",
-    "Federated Cloud Sharing" : "Federated Cloud Sharing",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL menggunakan versi %1$s yang usang(%2$s). Mohon perbarui sistem operasi Anda atau fitur sejenisnya termasuk %3$s tidak akan bekerja secara penuh.",
-    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "Modul PHP OPcache tidak dimuat. Untuk kinerja yang lebih baik, disarankan untuk memuatnya ke dalam instalasi PHP Anda.",
-    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache dinonaktifkan. Untuk kinerja yang lebih baik, disarankan untuk menerapkan <code>opcache.enable=1</code> ke konfigurasi PHP Anda.",
+    "Administrator documentation" : "Dokumentasi administrator",
+    "User documentation" : "Dokumentasi pengguna",
     "Invalid SMTP password." : "Kata sandi SMTP tidak valid.",
     "Email setting test" : "Uji pengaturan surel",
     "Well done, %s!" : "Bagus, %s!",
-    "If you received this email, the email configuration seems to be correct." : "Kalau kamu menerima surel ini, konfigurasi surel sepertinya benar.",
+    "If you received this email, the email configuration seems to be correct." : "Kalau Anda menerima surel ini, konfigurasi surel sepertinya benar.",
     "Email could not be sent. Check your mail server log" : "Surel tidak dapat dikirim. Periksa log server mail Anda",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Terjadi masalah saat mengirim surel. Mohon periksa kembali pengaturan Anda. (Kesalahan: %s)",
-    "You need to set your user email before being able to send test emails. Go to %s for that." : "Kamu harus pilih alamat email pengguna sebelum bisa mengirin email-email percobaan. Pergilah ke %s jadi bisa pilih email pengguna.",
-    "Invalid user" : "Pengguna tidak sah",
     "Invalid mail address" : "Alamat surel salah",
     "Settings saved" : "Pengaturan disimpan",
     "Unable to change full name" : "Tidak dapat mengubah nama lengkap",
-    "Unable to change email address" : "Tidak dapat mengubah alamat email",
+    "Unable to change email address" : "Tidak dapat mengubah alamat surel",
     "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Untuk memverifikasi akun Twitter Anda, posting tweet berikut ini ke Twitter (pastikan untuk posting tanpa ada jeda baris):",
     "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Untuk memverifikasi Situs Anda, simpan konten berikut ini ke web-root Anda di '.well-known/CloudIdVerificationCode.txt' (pastikan dalam satu baris):",
     "%1$s changed your password on %2$s." : "%1$s mengganti kata sandi Anda di %2$s",
@@ -86,117 +79,123 @@ OC.L10N.register(
     "If you did not request this, please contact an administrator." : "Jika Anda tidak merasa meminta ini, mohon hubungi administrator.",
     "Your email address on %s was changed." : "Alamat emailmu di %s telah diubah.",
     "Your email address on %s was changed by an administrator." : "Alamat surel Anda di %s telah diubah oleh administrator",
-    "Email address for %1$s changed on %2$s" : "Alamat email untuk %1$s telah diubah di %2$s",
-    "Email address changed for %s" : "Alamat email telah diubah untuk %s",
-    "The new email address is %s" : "Alamat email barunya yaitu %s",
+    "Email address for %1$s changed on %2$s" : "Alamat surel untuk %1$s telah diubah di %2$s",
+    "Email address changed for %s" : "Alamat surel telah diubah untuk %s",
+    "The new email address is %s" : "Alamat surel barunya yaitu %s",
     "Your %s account was created" : "Akun %s Anda telah dibuat",
     "Welcome aboard" : "Selamat datang",
     "Welcome aboard %s" : "Selamat bergabung %s",
     "Welcome to your %s account, you can add, protect, and share your data." : "Selamat datang ke akun %s Anda, kini Anda dapat menambahkan, melindungi, dan membagikan data Anda.",
-    "Your username is: %s" : "Nama pengguna Anda: %s",
     "Set your password" : "Atur kata sandi Anda",
     "Go to %s" : "Pergi ke %s",
     "Install Client" : "Pasang Klien",
-    "Logged in user must be a subadmin" : "Masuk ke dalam pengguna harus sebagai seorang subadmin",
     "Apps" : "Aplikasi",
-    "Settings" : "Setelan",
     "Personal" : "Personal",
     "Administration" : "Administrasi",
+    "Users" : "Pengguna",
     "Additional settings" : "Setelan tambahan",
     "Administration privileges" : "Hak administrator",
     "Groupware" : "Peralatan Grup",
     "Overview" : "Ringkasan",
     "Basic settings" : "Setelan dasar",
     "Sharing" : "Berbagi",
+    "Calendar" : "Kalender",
     "Personal info" : "Info pribadi",
     "Mobile & desktop" : "Mobil & desktop",
     "Email server" : "Server surel",
     "Security & setup warnings" : "Peringatan Keamanan & Pengaturan",
     "Background jobs" : "Pekerjaan latar belakang",
-    "Create" : "Buat",
-    "Change" : "Ubah",
-    "Delete" : "Hapus",
     "Unlimited" : "Tak terbatas",
     "Verifying" : "Memverifikasi",
+    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Pangkalan data kehilangan beberapa kolom opsional. Berdasarkan fakta bahwa menambahkannya pada tabel yang besar membutuhkan waktu cukup lama, maka ini tidak dilakukan otomatis. Eksekusi \"occ db: add-missing-columns\", untuk menambahkan kolom secara manual sementara instance tetap berjalan. Setelah itu dilakukan, maka beberapa fitur dapat meningkatkan daya tanggap atau kegunaan.",
+    "Disabled" : "Dinonaktifkan",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "Format enkripsi sisi server lama diaktifkan. Kami menyarankan untuk menonaktifkan ini.",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Fungsi PHP \"set_time_limit\" tidak tersedia. Hal ini dapat menyebabkan instalasi Anda, akibat eksekusi skrip terhenti ditengah-tengah. Mengaktifkan fungsi ini sangat dianjurkan.",
+    "Supported" : "Didukung",
+    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP Anda tidak mendukung FreeType, yang akan menyebabkan gangguan pada foto profil dan pengaturan antarmuka.",
+    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP tidak disetel sesuai untuk melakukan kueri system environment variables. Pengujian dengan getenv(\"PATH\") hanya menghasilkan pesan kosong. ",
+    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "Modul PHP OPcache tidak dimuat. Untuk kinerja yang lebih baik, disarankan untuk memuatnya ke dalam instalasi PHP Anda.",
+    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Konfigurasi baca-saja telah diaktifkan. Hal ini mencegah penyetelan beberapa konfigurasi via antarmuka web. Pada setiap proses pembaruan berikutnya, secara manual berkas tersebut perlu dibuat agar dapat ditulis.",
+    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Database Anda tidak dijalankan dengan isolasi transaksi level \"READ COMMITED\". Ini dapat menyebabkan masalah saat banyak tindakan dilakukan secara paralel.",
     "Profile information" : "Informasi profil",
-    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Gambar profil, nama lengkap, email, nomor telepon, alamat, situs web, Twitter, organisasi, peran, judul, biografi, dan apakah profilmu diaktifkan",
+    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Gambar profil, nama lengkap, surel, nomor telepon, alamat, situs web, Twitter, organisasi, peran, judul, biografi, dan apakah profilmu diaktifkan",
     "Nextcloud settings" : "Pengaturan Nextcloud",
     "None" : "Tidak ada",
+    "Allow apps to use the Share API" : "Izinkan aplikasi untuk menggunakan API Pembagian",
+    "Allow resharing" : "Izinkan pembagian ulang",
+    "Allow sharing with groups" : "Izinkan pembagian dengan grup",
+    "Restrict users to only share with users in their groups" : "Batasi pengguna untuk hanya membagikan dengan pengguna didalam grup mereka",
+    "Allow public uploads" : "Izinkan unggahan publik",
+    "Always ask for a password" : "Selalu tanya kata sandi",
+    "Enforce password protection" : "Berlakukan perlindungan sandi",
+    "Enforce expiration date" : "Berlakukan tanggal kadaluarsa",
+    "Default share permissions" : "Ijin bawaan berbagi",
     "Two-Factor Authentication" : "Autentikasi Dua-Faktor",
     "Limit to groups" : "Batasi ke grup",
     "Excluded groups" : "Grup yang dikecualikan",
     "Save changes" : "Simpan perubahan",
+    "Update to {update}" : "Perbarui ke {update}",
+    "Remove" : "Hapus",
+    "Disable" : "Nonaktifkan",
+    "Featured" : "Unggulan",
+    "This app is supported via your current Nextcloud subscription." : "Aplikasi ini didukung dengan langganan Nextcloud Anda saat ini.",
+    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Aplikasi unggulan dikembangkan oleh dan dalam komunitas. Mereka menawarkan fungsionalitas sentral dan mereka siap dipakai untuk produksi.",
+    "All apps are up-to-date." : "Semua aplikasi terkini.",
+    "Name" : "Nama",
+    "Version" : "Versi",
+    "Actions" : "Tindakan",
+    "Results from other categories" : "Hasil dari kategori lainnya",
+    "No apps found for your version" : "Aplikasi tidak ditemukan untuk versi ini",
+    "Disable all" : "Matikan semua",
+    "_%n app has an update available_::_%n apps have an update available_" : ["Ada pembaruan tersedia untuk %naplikasi"],
+    "_Update_::_Update all_" : ["Perbarui semua"],
+    "Loading" : "Memuat",
+    "Description" : "Deskrisi",
+    "Details" : "Detil",
     "All" : "Semua",
     "Limit app usage to groups" : "Batas pemakaian aplikasi untuk grup",
     "No results" : "Tidak ada hasil",
     "Update to {version}" : "Perbarui ke {version}",
-    "Remove" : "Hapus",
-    "Disable" : "Nonaktifkan",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Aplikasi ini tidak mempunyai versi minimum Nextcloud yang ditetapkan. Di masa depan nanti ini akan menjadi kesalahan.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Aplikasi ini tidak mempunyai versi maksimum Nextcloud yang ditetapkan. Di masa depan nanti ini akan menjadi kesalahan.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Apl ini tidak dapat diinstal karena ketergantungan berikut belum terpenuhi:",
+    "Author" : "Penulis",
+    "Categories" : "Kategori",
+    "Resources" : "Sumber daya",
+    "Documentation" : "Dokumentasi",
+    "Interact" : "Interaksi",
+    "Report a bug" : "Laporkan kerusakan",
+    "Request feature" : "Minta fitur",
+    "Ask questions or discuss" : "Tanyakan atau berdiskusi",
     "View in store" : "Lihat di toko",
     "Visit website" : "Kunjungi laman web",
-    "Report a bug" : "Laporkan kerusakan",
-    "User documentation" : "Dokumentasi pengguna",
     "Admin documentation" : "Dokumentasi admin",
     "Developer documentation" : "Dokumentasi pengembang",
-    "This app is supported via your current Nextcloud subscription." : "Aplikasi ini didukung dengan langganan Nextcloud Anda saat ini.",
-    "Supported" : "Didukung",
-    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Aplikasi unggulan dikembangkan oleh dan dalam komunitas. Mereka menawarkan fungsionalitas sentral dan mereka siap dipakai untuk produksi.",
-    "Featured" : "Unggulan",
-    "Update to {update}" : "Perbarui ke {update}",
-    "All apps are up-to-date." : "Semua aplikasi terkini.",
-    "Results from other categories" : "Hasil dari kategori lainnya",
-    "No apps found for your version" : "Aplikasi tidak ditemukan untuk versi ini",
-    "Disable all" : "Matikan semua",
-    "Enable all" : "Hidupkan semua",
-    "_%n app has an update available_::_%n apps have an update available_" : ["Ada pembaruan tersedia untuk %naplikasi"],
-    "_Update_::_Update all_" : ["Perbarui semua"],
+    "Changelog" : "Log pembaruan",
     "Marked for remote wipe" : "Tandai untuk penghapusan remote",
     "Device settings" : "Pengaturan perangkat",
     "Allow filesystem access" : "Ijinkan akses berkas sistem",
     "Rename" : "Ubah nama",
     "Revoke" : "Cabut ijin",
     "Wipe device" : "Hapus perangkat",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
     "Google Chrome for Android" : "Google Chrome untuk Android",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
-    "Sync client - {os}" : "Klien sync - {os}",
     "This session" : "Sesi ini",
     "Device" : "Perangkat",
     "Last activity" : "Aktivitas terakhir",
     "Devices & sessions" : "Perangkat & sesi",
     "Web, desktop and mobile clients currently logged in to your account." : "Klien web, desktop dan mobile yang sedang login di akun Anda.",
-    "Do you really want to wipe your data from this device?" : "Yakin ingin menghapus data Anda dari perangkat ini?",
-    "Confirm wipe" : "Konfirmasi penghapusan",
-    "Error while creating device token" : "Terjadi kesalahan saat membuat token perangkat",
-    "Error while updating device token scope" : "Galat saat memperbarui bidang token perangkat",
-    "Error while updating device token name" : "Galat saat memperbarui nama token perangkat",
-    "Error while deleting the token" : "Terjadi kesalahan saat menghapus token",
-    "Error while wiping the device with the token" : "Galat saat menghapus perangkat dengan token",
     "App name" : "Nama aplikasi",
     "Create new app password" : "Buat kata sandi aplikasi baru",
-    "Use the credentials below to configure your app or device." : "Gunakan kredensial berikut untuk mengkonfigurasi aplikasi atau perangkat.",
-    "For security reasons this password will only be shown once." : "Untuk alasan keamanan kata sandi ini akan ditunjukkan hanya sekali.",
-    "Username" : "Nama pengguna",
+    "Error while creating device token" : "Terjadi kesalahan saat membuat token perangkat",
+    "Login" : "Masuk",
     "Password" : "Kata sandi",
-    "Done" : "Selesai",
     "Show QR code for mobile apps" : "Tampilkan kode QR untuk aplikasi mobile",
-    "Copied!" : "Tersalin!",
-    "Copy" : "Salin",
     "Could not copy app password. Please copy it manually." : "Tidak dapat menyalin kata sandi aplikasi. Mohon salin secara manual.",
+    "Last job ran {relativeTime}." : "Tugas terakhir dijalankan {relativeTime}.",
     "AJAX" : "AJAX",
     "Webcron" : "Webcron",
     "Cron (Recommended)" : "Cron (Direkomendasikan)",
     "Profile" : "Profil",
-    "Enable or disable profile by default for new users." : "Aktifkan atau nonaktifkan profil secara default untuk pengguna baru.",
     "Enable" : "Aktifkan",
     "Unable to update profile default setting" : "Tidak dapat memperbarui pengaturan bawaan profil",
     "Server-side encryption" : "Enkripsi sisi-server",
@@ -209,81 +208,60 @@ OC.L10N.register(
     "This is the final warning: Do you really want to enable encryption?" : "Ini adalah peringatan terakhir: Apakah Anda yakin ingin mengaktifkan enkripsi?",
     "No encryption module loaded, please enable an encryption module in the app menu." : "Tidak ada modul enkripsi yang dimuat, mohon aktifkan modul enkripsi di menu aplikasi.",
     "Select default encryption module:" : "Pilih modul enkripsi baku:",
+    "Cancel" : "Batal",
+    "Confirm" : "Konfirmasi",
     "Rename group" : "Ganti nama grup",
     "Remove group" : "Hapus grup",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "Anda akan menghapus grup  {group}. Pengguna di dalamnya TIDAK akan dihapus.",
-    "Please confirm the group removal " : "Mohon konfirmasi penghapusan grup",
     "Current password" : "Kata sandi saat ini",
     "New password" : "Kata sandi baru",
     "Change password" : "Ubah kata sandi",
     "Your profile picture" : "Gambar profilmu",
     "Upload profile picture" : "Unggah gambar profil",
     "Remove profile picture" : "Hapus gambar profil",
-    "png or jpg, max. 20 MB" : "png atau jpg, maks. 20 MB",
     "Picture provided by original account" : "Gambar disediakan oleh akun asli",
-    "Cancel" : "Batal",
     "Choose your profile picture" : "Pilih gambar profilmu",
     "Error removing profile picture" : "Kesalahan terjadi ketika mencoba hapus gambar profil",
     "Your biography" : "Biografi Anda",
-    "Details" : "Detil",
     "You are a member of the following groups:" : "Anda adalah seorang anggota dari grup berikut ini:",
     "Your full name" : "Nama lengkap Anda",
-    "Primary email for password reset and notifications" : "Email utama untuk pengaturan ulang kata sandi dan pemberitahuan",
-    "Remove primary email" : "Hapus email utama",
-    "Delete email" : "Hapus email",
-    "Your email address" : "Alamat surel Anda",
+    "Primary email for password reset and notifications" : "Surel utama untuk pengaturan ulang kata sandi dan pemberitahuan",
+    "Remove primary email" : "Hapus surel utama",
+    "Delete email" : "Hapus surel",
     "No email address set" : "Alamat surel tidak diatur",
-    "Language" : "Bahasa",
     "Help translate" : "Bantu menerjemahkan",
     "No language set" : "Tidak ada bahasa yang disetel",
     "Your phone number" : "Nomor telefon Anda",
     "Edit your Profile visibility" : "Ubah visibilitas Profil Anda",
     "Add" : "Masukkan",
-    "You do not have permissions to see the details of this user" : "Anda tidak memiliki ijin untuk melihat detil pengguna ini",
-    "Set user as admin for" : "Atur pengguna sebagai admin untuk",
-    "Select user quota" : "Pilih kuota pengguna",
-    "Delete user" : "Hapus pengguna",
-    "Disable user" : "Nonaktifkan pengguna",
-    "Enable user" : "Aktifkan pengguna",
-    "Resend welcome email" : "Kirim ulang email selamat datang",
-    "Welcome mail sent!" : "Surat selamat datang terkirim!",
-    "{size} used" : "{size} digunakan",
-    "New user" : "Pengguna baru",
-    "Display name" : "Nama tampilan",
-    "Email" : "Surel",
+    "Create" : "Buat",
+    "Change" : "Ubah",
+    "Delete" : "Hapus",
     "Default language" : "Bahasa bawaan",
-    "Add a new user" : "Tambah pengguna baru",
-    "Group admin for" : "Grup admin untuk",
-    "Quota" : "Kuota",
-    "User backend" : "Backend pengguna",
-    "Storage location" : "Lokasi penyimpanan",
-    "Last login" : "Log masuk terakhir",
-    "No users in here" : "Tidak ada pengguna disini",
-    "Default quota" : "Kuota standar",
     "Common languages" : "Bahasa umum",
     "Password change is disabled because the master key is disabled" : "Pengaturan kata sandi dinonaktifkan karena kunci master dinonaktifkan",
+    "Display name" : "Nama tampilan",
+    "Email" : "Surel",
+    "Quota" : "Kuota",
+    "Language" : "Bahasa",
+    "Avatar" : "Avatar",
+    "Group admin for" : "Grup admin untuk",
+    "Storage location" : "Lokasi penyimpanan",
+    "Last login" : "Log masuk terakhir",
+    "{size} used" : "{size} digunakan",
+    "Resend welcome email" : "Kirim ulang surel selamat datang",
+    "Welcome mail sent!" : "Surat selamat datang terkirim!",
+    "Done" : "Selesai",
+    "Edit" : "Sunting",
+    "Show storage path" : "Tampilkan jalur penyimpanan",
+    "Show last login" : "Tampilkan yang terakhir masuk",
+    "Send email" : "Kirim surel",
+    "Default quota" : "Kuota standar",
+    "Select default quota" : "Pilih kuota bawaan",
     "Passwordless authentication requires a secure connection." : "Otentikasi tanpa kata sandi membutuhkan koneksi aman.",
     "Passwordless Authentication" : "Otentikasi Tanpa Kata Sandi",
     "No devices configured." : "Tidak ada perangkat yang dikonfigurasi.",
-    "Your apps" : "Aplikasi anda",
-    "Active apps" : "Aplikasi aktif",
-    "Disabled apps" : "Matikan Aplikasi",
-    "Updates" : "Pembaruan",
-    "App bundles" : "Kumpulan Apl",
-    "{license}-licensed" : "{license}-dilisensikan",
-    "Changelog" : "Log pembaruan",
-    "Add group" : "Tambah grup",
-    "Active users" : "Pengguna aktif",
     "Admins" : "Admin",
-    "Disabled users" : "Nonaktifkan pengguna",
-    "Default quota:" : "Kuota bawaan:",
-    "Select default quota" : "Pilih kuota bawaan",
-    "Show Languages" : "Tampilkan bahasa",
-    "Show last login" : "Tampilkan yang terakhir masuk",
-    "Show user backend" : "Tampilkan pengguna backend",
-    "Show storage path" : "Tampilkan jalur penyimpanan",
-    "Send email to new user" : "Kirim surel kepada pengguna baru",
-    "Not saved" : "Belum disimpan",
+    "Group name" : "Nama grup",
     "Sending…" : "Mengirim…",
     "Email sent" : "Surel terkirim",
     "Location" : "Lokasi",
@@ -291,38 +269,43 @@ OC.L10N.register(
     "About" : "Tentang.",
     "Full name" : "Nama lengkap",
     "Phone number" : "Nomor telefon",
-    "Twitter" : "Twitter",
     "Website" : "Situs",
     "Profile visibility" : "Visibilitas profil",
+    "Your apps" : "Aplikasi Anda",
+    "Active apps" : "Aplikasi aktif",
+    "Disabled apps" : "Matikan Aplikasi",
+    "Updates" : "Pembaruan",
+    "App bundles" : "Kumpulan Apl",
+    "Featured apps" : "Aplikasi yang difiturkan",
     "Hide" : "Sembunyikan",
     "Download and enable" : "Unduh dan hidupkan",
-    "Enable untested app" : "Hidupkan aplikasi yang belum dites",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Aplikasi ini tidak ditandai sebagai versi Nextcloud Anda yang kompatibel. Jika Anda tetap ingin melanjutkannya, Anda tetap dapat memasang aplikasi. Catatan bahwa aplikasinya mungkin tidak akan berjalan seperti yang diharapkan.",
     "Never" : "Tidak pernah",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikasi diaktifkan namun butuh diperbarui. Anda akan dialihkan ke halaman pembaruan dalam 5 detik.",
-    "Administrator documentation" : "Dokumentasi administrator",
-    "Documentation" : "Dokumentasi",
+    "Do you really want to wipe your data from this device?" : "Yakin ingin menghapus data Anda dari perangkat ini?",
+    "Confirm wipe" : "Konfirmasi penghapusan",
+    "Error while wiping the device with the token" : "Galat saat menghapus perangkat dengan token",
+    "Error while updating device token name" : "Galat saat memperbarui nama token perangkat",
+    "Error while updating device token scope" : "Galat saat memperbarui bidang token perangkat",
+    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Ada terlalu banyak permintaan dari jaringan Anda. Coba lagi nanti atau hubungi administrator Anda jika ini adalah kesalahan.",
+    "Error" : "Galat",
     "Forum" : "Forum",
-    "Login" : "Masuk",
-    "Plain" : "Biasa",
-    "NT LAN Manager" : "Manajer NT LAN",
-    "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "STARTTLS",
+    "Legal notice" : "Pemberitahuan hukum",
+    "Privacy policy" : "Kebijakan privasi",
+    "SSL" : "SSL",
     "Open documentation" : "Buka dokumentasi",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Sangat penting untuk mengatur server ini untuk dapat mengirim surat, seperti melakukan reset kata sandi dan notifikasi.",
     "Send mode" : "Modus kirim",
     "Encryption" : "Enkripsi",
-    "Sendmail mode" : "Mode kirim email",
+    "Sendmail mode" : "Mode kirim surel",
     "From address" : "Dari alamat",
-    "Authentication method" : "Metode otentikasi",
-    "Authentication required" : "Diperlukan otentikasi",
     "Server address" : "Alamat server",
     "Port" : "Port",
+    "Authentication" : "Otentikasi",
+    "Authentication required" : "Diperlukan otentikasi",
     "Credentials" : "Kredensial",
-    "SMTP Username" : "Nama pengguna SMTP",
     "SMTP Password" : "Kata sandi SMTP",
     "Save" : "Simpan",
-    "Send email" : "Kirim surel",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Sangat penting sekali untuk semuanya diatur secara benar demi keamanan dan performa instansi Anda. Untuk membantu Anda dengan hal itu kami melakukan cek otomatis. Mohon melihat tautan dokumentasi untuk lebih lanjut.",
     "All checks passed." : "Semua pemeriksaan lulus.",
     "There are some errors regarding your setup." : "Terdapat beberapa galat terkait dengan setup Anda.",
@@ -330,19 +313,6 @@ OC.L10N.register(
     "Checking for system and security issues." : "Mengecek isu sistem dan keamanan",
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Mohon cek kembali Petunjuk pemasangan ↗, dan cek semua galat atau peringatan di <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">log<a href=\"%2$s\">.",
     "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Cek keamanan Nextcloud Anda dengan <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">pemindaian keamanan kami ↗</a>.",
-    "Version" : "Versi",
-    "Allow apps to use the Share API" : "Izinkan aplikasi untuk menggunakan API Pembagian",
-    "Enforce expiration date" : "Berlakukan tanggal kadaluarsa",
-    "Allow public uploads" : "Izinkan unggahan publik",
-    "Always ask for a password" : "Selalu tanya kata sandi",
-    "Enforce password protection" : "Berlakukan perlindungan sandi",
-    "Set default expiration date" : "Atur tanggal kadaluarsa default",
-    "Allow resharing" : "Izinkan pembagian ulang",
-    "Allow sharing with groups" : "Izinkan pembagian dengan grup",
-    "Restrict users to only share with users in their groups" : "Batasi pengguna untuk hanya membagikan dengan pengguna didalam grup mereka",
-    "Exclude groups from sharing" : "Tidak termasuk grup untuk berbagi",
-    "These groups will still be able to receive shares, but not to initiate them." : "Grup ini akan tetap dapat menerima berbagi, tatapi tidak dapat membagikan.",
-    "Default share permissions" : "Ijin bawaan berbagi",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Dikembangkan oleh {commmunityopen}komunitas Nextcloud{linkclose}, {githubopen}sumber kode{linkclose} dilisensikan dibawah {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Sukai kami di halaman Facebook",
     "Follow us on Twitter" : "Ikuti kami di Twitter",
@@ -350,47 +320,29 @@ OC.L10N.register(
     "Check out our blog" : "Cek blog kami",
     "Subscribe to our newsletter" : "Berlangganan surat berita kami",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Rilis komunitas Nextcloud ini tidak didukung dan pemberitahuan instan tidak tersedia.",
-    "Migration in progress. Please wait until the migration is finished" : "Migrasi sedang dalam proses. Mohon tunggu sampai migrasi selesai",
-    "Migration started …" : "Migrasi dimulai …",
-    "An error occurred while changing your language. Please reload the page and try again." : "Galat terjadi ketika mengubah bahasa Anda. Mohon muat ulang halaman dan coba lagi.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "Galat terjadi saat mengubah tempat Anda. Mohon muat ulang halaman dan coba lagi.",
-    "Select a profile picture" : "Pilih foto profil",
-    "Week starts on {fdow}" : "Minggu dimulai di hari {fdow}",
-    "Couldn't remove app." : "Tidak dapat menghapus aplikasi.",
-    "Couldn't update app." : "Tidak dapat memperbarui aplikasi.",
-    "Backend doesn't support password change, but the user's encryption key was updated." : "Backend tidak mendukung perubahan kata sandi, namun kunci enkripsi pengguna telah diperbarui.",
-    "You need to set your user email before being able to send test emails." : "Anda perlu menetapkan surel pengguna Anda sebelum dapat mengirim surel percobaan.",
-    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Mencabut token ini mungkin akan mencegah penghapusan perangkat Anda jika penghapusan belum dimulai.",
-    "All languages" : "Semua bahasa",
-    "Everyone" : "Semua orang",
-    "An error occured during the request. Unable to proceed." : "Galat terjadi saat proses permintaan. Tidak dapat memproses.",
-    "Test email settings" : "Pengaturan surel percobaan",
-    "Please read carefully before activating server-side encryption: " : "Mohon baca dengan teliti sebelum mengaktifkan enkripsi server-side: ",
-    "Enable encryption" : "Aktifkan enkripsi",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Anda perlu mengganti kunci enkrispi Anda dari enkripsi lama (ownCloud <= 8.0) ke yang baru. Mohon aktifkan \"Modul enkripsi standar\" dan jalankan 'occ encryption:migrate'",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Anda perlu untuk mengubah kunci enkripsi dari enkripsi lama (ownCloud <= 8.0) ke yang baru.",
-    "Start migration" : "Mulai migrasi",
-    "Last job execution ran %s. Something seems wrong." : "Pekerjaan terakhir dieksekusi berjalan %s. Ada yang salah.",
-    "Last job ran %s." : "Pekerjaan terakhir dijalankan %s",
-    "Background job didn’t run yet!" : "Pekerjaan latar belakang belum berjalan!",
-    "Pick background job setting" : "Pilih pengaturan pekerjaan latar belakang",
-    "Recommended" : "Direkomendasikan",
-    "days" : "hari",
-    "Upload new" : "Unggah baru",
-    "Select from Files" : "Pilih dari berkas",
-    "Remove image" : "Hapus gambar",
-    "Choose as profile picture" : "Pilih sebagai gambar profil",
-    "You are using <strong>%s</strong>" : "Anda menggunakan <strong>%s</strong>",
-    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Anda menggunakan <strong>%1$s</strong> dari<strong>%2$s</strong> (<strong>%3$s %%</strong>)",
-    "No display name set" : "Nama tampilan tidak diatur",
-    "Address" : "Alamat",
-    "Your postal address" : "Alamat post Anda",
-    "It can take up to 24 hours before the account is displayed as verified." : "Ini akan memerlukan hingga 24 jam sebelum akun diverifikasi.",
-    "Link https://…" : "Tautan https://...",
-    "Twitter handle @…" : "Twitter handle @…",
-    "Admin privileges" : "Hak istimewa admin",
-    "Unable to update biography" : "Tidak dapat memperbarui biografi",
-    "Unable to update full name" : "Tidak dapat memperbarui nama lengkap",
-    "Avatar" : "Avatar"
+    "No user supplied" : "Tidak ada pengguna yang diberikan",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Berikan kata sandi pemulihan admin; Jika tidak, semua data pengguna akan hilang.",
+    "You need to set your user email before being able to send test emails. Go to %s for that." : "Anda harus pilih alamat surel pengguna sebelum bisa mengirim surel percobaan. Pergilah ke %s untuk itu.",
+    "Invalid user" : "Pengguna tidak sah",
+    "Your username is: %s" : "Nama pengguna Anda: %s",
+    "Logged in user must be a subadmin" : "Masuk ke dalam pengguna harus sebagai seorang subadmin",
+    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Pangkalan data kehilangan beberapa indeks. Berdasarkan fakta bahwa menambahkan indeks pada tabel yang besar membutuhkan waktu cukup lama, maka ini tidak dilakukan otomatis. Eksekusi \"occ db: add-missing-indexes\", untuk menambahkan indeks secara manual sementara instance tetap berjalan. Setelah itu dilakukan, maka kueri akan jauh lebih cepat.",
+    "Exclude groups from sharing" : "Tidak termasuk grup untuk berbagi",
+    "These groups will still be able to receive shares, but not to initiate them." : "Grup ini akan tetap dapat menerima berbagi, tatapi tidak dapat membagikan.",
+    "{license}-licensed" : "{license}-dilisensikan",
+    "Username" : "Nama pengguna",
+    "Enable or disable profile by default for new users." : "Aktifkan atau nonaktifkan profil secara default untuk pengguna baru.",
+    "New user" : "Pengguna baru",
+    "User backend" : "Backend pengguna",
+    "You do not have permissions to see the details of this user" : "Anda tidak memiliki ijin untuk melihat detil pengguna ini",
+    "Set user as admin for" : "Atur pengguna sebagai admin untuk",
+    "Select user quota" : "Pilih kuota pengguna",
+    "Delete user" : "Hapus pengguna",
+    "Disable user" : "Nonaktifkan pengguna",
+    "Enable user" : "Aktifkan pengguna",
+    "Show user backend" : "Tampilkan pengguna backend",
+    "Active users" : "Pengguna aktif",
+    "Disabled users" : "Nonaktifkan pengguna",
+    "SMTP Username" : "Nama pengguna SMTP"
 },
 "nplurals=1; plural=0;");
