@@ -125,8 +125,6 @@ OC.L10N.register(
     "Missing optional column \"%s\" in table \"%s\"." : "Missing optional column \"%s\" in table \"%s\".",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability.",
     "Database missing indices" : "Database missing indices",
-    "Missing optional index \"%s\" in table \"%s\"." : "Missing optional index \"%s\" in table \"%s\".",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster.",
     "Database missing primary keys" : "Database missing primary keys",
     "Missing primary key on table \"%s\"." : "Missing primary key on table \"%s\".",
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running.",
@@ -182,9 +180,6 @@ OC.L10N.register(
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update.",
     "Nextcloud configuration file is writable" : "Nextcloud configuration file is writable",
     "Database version" : "Database version",
-    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher.",
-    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher.",
-    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend. This is particularly recommended when using the desktop client for file synchronisation. To migrate to another database use the command line tool: \"occ db:convert-type\"." : "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend. This is particularly recommended when using the desktop client for file synchronisation. To migrate to another database use the command line tool: \"occ db:convert-type\".",
     "Unknown database platform" : "Unknown database platform",
     "Architecture" : "Architecture",
@@ -196,18 +191,14 @@ OC.L10N.register(
     "Profile information" : "Profile information",
     "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled",
     "Nextcloud settings" : "Nextcloud settings",
+    "Task:" : "Task:",
     "Machine translation" : "Machine translation",
     "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment.",
-    "Speech-To-Text" : "Speech-To-Text",
-    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "Speech-To-Text can be implemented by different apps. Here you can set which app should be used.",
-    "None of your currently installed apps provide Speech-To-Text functionality" : "None of your currently installed apps provide Speech-To-Text functionality",
     "Image generation" : "Image generation",
     "Image generation can be implemented by different apps. Here you can set which app should be used." : "Image generation can be implemented by different apps. Here you can set which app should be used.",
     "None of your currently installed apps provide image generation functionality" : "None of your currently installed apps provide image generation functionality",
     "Text processing" : "Text processing",
     "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task.",
-    "Task:" : "Task:",
-    "None of your currently installed apps provide Text processing functionality" : "None of your currently installed apps provide Text processing functionality",
     "Here you can decide which group can access certain sections of the administration settings." : "Here you can decide which group can access certain sections of the administration settings.",
     "None" : "None",
     "Unable to modify setting" : "Unable to modify setting",
@@ -233,10 +224,7 @@ OC.L10N.register(
     "Set default expiration date for shares via link or mail" : "Set default expiration date for shares via link or mail",
     "Default expiration time of shares in days" : "Default expiration time of shares in days",
     "Privacy settings for sharing" : "Privacy settings for sharing",
-    "Allow username autocompletion in share dialog and allow access to the system address book" : "Allow username autocompletion in share dialog and allow access to the system address book",
     "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user.",
-    "Allow username autocompletion to users within the same groups and limit system address books to users in the same groups" : "Allow username autocompletion to users within the same groups and limit system address books to users in the same groups",
-    "Allow username autocompletion to users based on phone number integration" : "Allow username autocompletion to users based on phone number integration",
     "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Show disclaimer text on the public link upload page (only shown when the file list is hidden)",
     "Disclaimer text" : "Disclaimer text",
@@ -435,42 +423,26 @@ OC.L10N.register(
     "Common languages" : "Common languages",
     "Other languages" : "Other languages",
     "Password change is disabled because the master key is disabled" : "Password change is disabled because the master key is disabled",
-    "New user" : "New user",
     "Display name" : "Display name",
     "Either password or email is required" : "Either password or email is required",
     "Password (required)" : "Password (required)",
     "Email (required)" : "Email (required)",
     "Email" : "Email",
-    "Groups (required)" : "Groups (required)",
-    "Set user groups" : "Set user groups",
-    "Administered groups" : "Administered groups",
-    "Set user as admin for …" : "Set user as admin for …",
     "Quota" : "Quota",
-    "Set user quota" : "Set user quota",
     "Language" : "Language",
     "Set default language" : "Set default language",
     "Manager" : "Manager",
-    "Add new user" : "Add new user",
-    "Set user manager" : "Set user manager",
-    "Username will be autogenerated" : "Username will be autogenerated",
-    "Username (required)" : "Username (required)",
     "Total rows summary" : "Total rows summary",
-    "Loading users …" : "Loading users …",
     "Scroll to load more rows" : "Scroll to load more rows",
-    "_{userCount} user …_::_{userCount} users …_" : ["{userCount} user …","{userCount} users …"],
-    "_{userCount} user_::_{userCount} users_" : ["{userCount} user","{userCount} users"],
     "Avatar" : "Avatar",
-    "Username" : "Username",
     "Group admin for" : "Group admin for",
-    "User backend" : "User backend",
     "Storage location" : "Storage location",
     "Last login" : "Last login",
-    "User actions" : "User actions",
+    "Account actions" : "Account actions",
     "Password or insufficient permissions message" : "Password or insufficient permissions message",
     "Change display name" : "Change display name",
     "Set new password" : "Set new password",
     "Set new email address" : "Set new email address",
-    "Add user to group" : "Add user to group",
     "Set the language" : "Set the language",
     "{size} used" : "{size} used",
     "Delete account" : "Delete account",
@@ -556,6 +528,7 @@ OC.L10N.register(
     "Error while updating device token name" : "Error while updating device token name",
     "Error while updating device token scope" : "Error while updating device token scope",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "There were too many requests from your network. Retry later or contact your administrator if this is an error.",
+    "Error" : "Error",
     "Account documentation" : "Account documentation",
     "Administration documentation" : "Administration documentation",
     "Forum" : "Forum",
@@ -598,112 +571,79 @@ OC.L10N.register(
     "No user supplied" : "No user supplied",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Please provide an admin recovery password; otherwise, all user data will be lost.",
     "Backend does not support password change, but the user's encryption key was updated." : "Backend does not support password change, but the user's encryption key was updated.",
-    "installing and updating apps via the App Store or Federated Cloud Sharing" : "installing and updating apps via the App Store or Federated Cloud Sharing",
-    "Federated Cloud Sharing" : "Federated Cloud Sharing",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably.",
-    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details.",
-    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration.",
-    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function.",
-    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades.",
-    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades.",
-    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply <code>opcache.file_cache_only=0</code> to your PHP configuration and use the file cache as second level cache only." : "The shared memory based OPcache is disabled. For better performance, it is recommended to apply <code>opcache.file_cache_only=0</code> to your PHP configuration and use the file cache as second level cache only.",
-    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>.",
-    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>.",
-    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>.",
     "You need to set your user email before being able to send test emails. Go to %s for that." : "You need to set your user email before being able to send test emails. Go to %s for that.",
     "Invalid user" : "Invalid user",
     "Your username is: %s" : "Your username is: %s",
     "Logged in user must be a subadmin" : "Logged in user must be a subadmin",
+    "Old user imported certificates" : "Old user imported certificates",
     "A background job is pending that checks for user imported SSL certificates. Please check back later." : "A background job is pending that checks for user imported SSL certificates. Please check back later.",
     "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below.",
-    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them.",
-    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occured. Please run it manually by calling occ dav:sync-system-addressbook." : "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occured. Please run it manually by calling occ dav:sync-system-addressbook.",
+    "Missing optional index \"%s\" in table \"%s\"." : "Missing optional index \"%s\" in table \"%s\".",
+    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster.",
+    "You are currently running PHP %s. PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "You are currently running PHP %s. PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible.",
+    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher.",
+    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher.",
+    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher.",
+    "Speech-To-Text" : "Speech-To-Text",
+    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "Speech-To-Text can be implemented by different apps. Here you can set which app should be used.",
+    "None of your currently installed apps provide Speech-To-Text functionality" : "None of your currently installed apps provide Speech-To-Text functionality",
+    "None of your currently installed apps provide Text processing functionality" : "None of your currently installed apps provide Text processing functionality",
+    "Exclude groups from sharing" : "Exclude groups from sharing",
+    "These groups will still be able to receive shares, but not to initiate them." : "These groups will still be able to receive shares, but not to initiate them.",
+    "Allow username autocompletion in share dialog and allow access to the system address book" : "Allow username autocompletion in share dialog and allow access to the system address book",
     "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system.",
     "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced.",
-    "Enable all" : "Enable all",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
-    "Sync client - {os}" : "Sync client - {os}",
-    "Error while deleting the token" : "Error while deleting the token",
-    "Use the credentials below to configure your app or device." : "Use the credentials below to configure your app or device.",
-    "For security reasons this password will only be shown once." : "For security reasons this password will only be shown once.",
-    "Copied!" : "Copied!",
-    "Copy" : "Copy",
+    "{license}-licensed" : "{license}-licensed",
+    "Rating: {score}/10" : "Rating: {score}/10",
+    "Username" : "Username",
     "Execute one task with each page loaded. Use case: Single user instance." : "Execute one task with each page loaded. Use case: Single user instance.",
     "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage).",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details.",
-    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances.",
     "The cron.php needs to be executed by the system user \"{user}\"." : "The cron.php needs to be executed by the system user \"{user}\".",
     "Enable or disable profile by default for new users." : "Enable or disable profile by default for new users.",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "You are about to remove the group {group}. The users will NOT be deleted.",
-    "Please confirm the group removal " : "Please confirm the group removal ",
-    "Your profile information" : "Your profile information",
-    "Your email address" : "Your email address",
+    "You are about to remove the group \"{group}\". The users will NOT be deleted." : "You are about to remove the group \"{group}\". The users will NOT be deleted.",
     "Additional emails" : "Additional emails",
     "Enable Profile" : "Enable Profile",
-    "Your Twitter handle" : "Your Twitter handle",
+    "No users" : "No users",
+    "Loading users …" : "Loading users …",
+    "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list.",
+    "New user" : "New user",
+    "Groups (required)" : "Groups (required)",
+    "Set user groups" : "Set user groups",
+    "Administered groups" : "Administered groups",
+    "Set user as admin for …" : "Set user as admin for …",
+    "Set user quota" : "Set user quota",
+    "Add new user" : "Add new user",
+    "Set user manager" : "Set user manager",
+    "Username will be autogenerated" : "Username will be autogenerated",
+    "Username (required)" : "Username (required)",
+    "User backend" : "User backend",
+    "User actions" : "User actions",
+    "Loading user …" : "Loading user …",
     "You do not have permissions to see the details of this user" : "You do not have permissions to see the details of this user",
-    "Edit display name" : "Edit display name",
-    "Add new password" : "Add new password",
-    "Add new email address" : "Add new email address",
+    "Add user to group" : "Add user to group",
     "Set user as admin for" : "Set user as admin for",
     "Select user quota" : "Select user quota",
-    "Select manager" : "Select manager",
-    "Toggle user actions menu" : "Toggle user actions menu",
     "Delete user" : "Delete user",
     "Wipe all devices" : "Wipe all devices",
     "Disable user" : "Disable user",
     "Enable user" : "Enable user",
-    "Edit User" : "Edit User",
-    "User's table" : "User's table",
-    "Will be autogenerated" : "Will be autogenerated",
-    "Select user manager" : "Select user manager",
-    "Add a new user" : "Add a new user",
-    "No users in here" : "No users in here",
+    "Failed to update user manager" : "Failed to update user manager",
+    "Toggle user actions menu" : "Toggle user actions menu",
+    "User management settings" : "User management settings",
+    "Show user backend" : "Show user backend",
+    "Send welcome email to new users" : "Send welcome email to new users",
     "Name your device" : "Name your device",
     "Server error while trying to add WebAuthn device" : "Server error while trying to add WebAuthn device",
-    "{license}-licensed" : "{license}-licensed",
     "by {author}\n{license}" : "by {author}\n{license}",
-    "Enter group name" : "Enter group name",
-    "Add group" : "Add group",
+    "User management" : "User management",
     "Active users" : "Active users",
     "Disabled users" : "Disabled users",
-    "Default quota:" : "Default quota:",
-    "Show Languages" : "Show Languages",
-    "Show user backend" : "Show user backend",
-    "Send email to new user" : "Send email to new user",
-    "Not saved" : "Not saved",
-    "Twitter" : "Twitter",
+    "Creating group …" : "Creating group …",
+    "User group: {group}" : "User group: {group}",
     "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Not available as federation has been disabled for your account, contact your system administrator if you have any questions",
     "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions",
     "Show to logged in users only" : "Show to logged in users only",
-    "Enable untested app" : "Enable untested app",
-    "SMTP Username" : "SMTP Username",
-    "Expire after" : "Expire after",
-    "day(s)" : "day(s)",
-    "Exclude groups from password requirements:" : "Exclude groups from password requirements:",
-    "Set default expiration date" : "Set default expiration date",
-    "Exclude groups from creating link shares:" : "Exclude groups from creating link shares:",
-    "Exclude groups from sharing" : "Exclude groups from sharing",
-    "These groups will still be able to receive shares, but not to initiate them." : "These groups will still be able to receive shares, but not to initiate them.",
-    "Old user imported certificates" : "Old user imported certificates",
-    "You are currently running PHP %s. PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "You are currently running PHP %s. PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible.",
-    "Rating: {score}/10" : "Rating: {score}/10",
-    "You are about to remove the group \"{group}\". The users will NOT be deleted." : "You are about to remove the group \"{group}\". The users will NOT be deleted.",
-    "No users" : "No users",
-    "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list.",
-    "Loading user …" : "Loading user …",
-    "Failed to update user manager" : "Failed to update user manager",
-    "User management settings" : "User management settings",
-    "Send welcome email to new users" : "Send welcome email to new users",
-    "User management" : "User management",
-    "Creating group …" : "Creating group …",
-    "User group: {group}" : "User group: {group}",
-    "Nextcloud help resources" : "Nextcloud help resources"
+    "Nextcloud help resources" : "Nextcloud help resources",
+    "SMTP Username" : "SMTP Username"
 },
 "nplurals=2; plural=(n!=1);");
