@@ -1,8 +1,6 @@
 OC.L10N.register(
     "text",
     {
-    "New text file" : "새 텍스트 파일",
-    "Create new text file" : "새 텍스트 파일 만들기",
     "The file was uploaded" : "파일을 업로드함",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "업로드한 파일의 크기가 php.ini의 upload_max_filesize를 초과함",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "업로드한 파일의 크기가 HTML 폼에 지정한 MAX_FILE_SIZE를 초과함",
@@ -13,8 +11,12 @@ OC.L10N.register(
     "A PHP extension stopped the file upload" : "PHP 확장 기능에서 파일 업로드를 차단함",
     "No file uploaded or file size exceeds maximum of %s" : "파일이 업로드 되지 않았거나, 크기가 %s를 초과함",
     "text document" : "텍스트 문서",
+    "New text file" : "새 텍스트 파일",
+    "Create new text file" : "새 텍스트 파일 만들기",
     "This file cannot be displayed as download is disabled by the share" : "공유에서 다운로드가 비활성화 되었으므로 이 파일을 볼 수 없습니다.",
+    "File not found" : "파일을 찾을 수 없음",
     "Text" : "텍스트",
+    "Nextcloud Assistant" : "Nextcloud 어시스턴트",
     "Translate" : "번역:",
     "Use current version" : "최근 버젼을 사용하십시오.",
     "Use the saved version" : "이전 버전 사용하기",
@@ -33,11 +35,13 @@ OC.L10N.register(
     "Saved" : "저장됨",
     "The document has been changed outside of the editor. The changes cannot be applied." : "문서가 에디터 밖에서 변경되었습니다. 변경사항이 적용되지 않습니다.",
     "Unsaved changes" : "저장하지 않은 변경 사항",
-    "Formatting help" : "서식 도움말",
     "Keyboard shortcuts" : "키보드 단축키",
+    "Enter" : "Enter",
     "Backspace" : "백스페이스",
+    "Shift" : "쉬프트",
     "Bold" : "굵게",
     "Bold text" : "굵은 텍스트",
+    "Ctrl" : "Ctrl",
     "Italic" : "Italic체",
     "Italicized text" : "기울임꼴 텍스트",
     "Strikethrough" : "취소선",
@@ -49,11 +53,18 @@ OC.L10N.register(
     "Heading 6" : "제목 6",
     "Heading level 6" : "제목 단계 6",
     "Quoted text" : "인용문",
+    "Link" : "링크",
+    "Smart picker" : "스마트 피커",
+    "Action" : "동작",
+    "Undo" : "실행 취소",
+    "Redo" : "다시 실행",
     "Edit link" : "링크 수정",
     "Save changes" : "설정 저장",
     "Cancel" : "취소",
     "URL" : "URL",
     "Cannot copy, please copy the link manually" : "복사할 수 없습니다, 링크를 수동으로 복사하세요.",
+    "Copy link to clipboard" : "링크를 클립보드에 복사",
+    "Formatting help" : "서식 도움말",
     "Open the Smart Picker" : "스마트 피커 열기",
     "Select file or folder to link to" : "링크할 파일이나 폴더 선택",
     "_%n word_::_%n words_" : ["%n개 단어"],
@@ -68,10 +79,9 @@ OC.L10N.register(
     "Edit" : "편집",
     "Copy code block" : "코드 블록 복사",
     "Source code" : "소스 코드",
+    "Show folder description" : "폴더 설명 보이기",
     "Hide outline" : "개요 숨기기",
     "Show outline" : "개요 보이기",
-    "Undo" : "실행 취소",
-    "Redo" : "다시 실행",
     "Headings" : "제목",
     "Heading 2" : "제목 2",
     "Heading 3" : "제목 3",
@@ -80,9 +90,10 @@ OC.L10N.register(
     "Info" : "정보",
     "Success" : "성공",
     "Warning" : "경고",
+    "Details" : "세부사항",
     "Command" : "명령",
     "Control" : "제어:",
     "Formatting" : "서식",
-    "Smart picker" : "스마트 피커"
+    "Add folder description" : "폴더 설명 추가"
 },
 "nplurals=1; plural=0;");
