@@ -35,20 +35,16 @@ OC.L10N.register(
     "_%n minute ago_::_%n minutes ago_" : ["Hace %n minuto","Hace %n minutos","Hace %n minutos"],
     "seconds ago" : "hace segundos",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "El módulo con ID: %sno existe. Favor de habilitarlo en sus configuraciones de aplicación o contacte a su administrador.  ",
-    "File name is a reserved word" : "Nombre de archivo es una palabra reservada",
-    "File name contains at least one invalid character" : "El nombre del archivo contiene al menos un caracter inválido",
-    "File name is too long" : "El nombre del archivo es demasiado largo",
     "Dot files are not allowed" : "Los archivos Dot no están permitidos",
+    "Filename contains at least one invalid character" : "Nombre de archivo contiene al menos un carácter no válido",
     "Empty filename is not allowed" : "El uso de nombres de archivo vacíos no está permitido",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "La aplicación \"%s\" no puede ser instalada porque el archivo appinfo no se puede leer. ",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "La aplicación \"%s\" no puede ser instalada porque no es compatible con esta versión del servidor. ",
     "__language_name__" : "Español (Argentina)",
     "This is an automatically sent email, please do not reply." : "Este es un correo enviado automáticamente, favor de no contestarlo. ",
-    "Help" : "Ayuda",
     "Apps" : "Aplicaciones",
     "Settings" : "Ajustes",
     "Log out" : "Cerrar sesión",
-    "Users" : "Usuarios",
     "Email" : "Correo electrónico",
     "Phone" : "Teléfono fijo",
     "Twitter" : "Twitter",
@@ -56,27 +52,23 @@ OC.L10N.register(
     "Address" : "Dirección",
     "Profile picture" : "Foto de perfil",
     "About" : "Acerca de",
-    "Unknown user" : "Ususario desconocido",
     "Additional settings" : "Configuraciones adicionales",
     "You need to enter details of an existing account." : "Necesita ingresar los detalles de una cuenta existente.",
     "Oracle connection could not be established" : "No fue posible establecer la conexión a Oracle",
-    "Oracle username and/or password not valid" : "El nombre de usuario y/o contraseña de Oracle inválidos",
-    "PostgreSQL username and/or password not valid" : "El nombre de usuario y/o contraseña de PostgreSQL inválidos",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "OS X de Mac no está soportado y %s no funcionará correctamente en esta plataforma ¡Uselo bajo su propio riesgo!",
     "For the best results, please consider using a GNU/Linux server instead." : "Para mejores resultados, favor de cosiderar usar en su lugar un servidor GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Al parecer esta instancia %s está corriendo en un ambiente PHP de 32-bits y el open_basedir ha sido configurado en el archivo php.ini. Esto generará problemas con archivos de más de 4GB de tamaño y es altamente desalentado. ",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Favor de eliminar el ajuste open_basedir de su archivo php.ini o cambie a PHP de 64 bits. ",
-    "Set an admin username." : "Configurar un nombre de usuario del administrador",
     "Set an admin password." : "Establecer la contraseña del administrador.",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El backend %s que comparte debe implementar la interface OCP\\Share_Backend",
     "Sharing backend %s not found" : "No fue encontrado el Backend que comparte %s ",
     "Sharing backend for %s not found" : "No fue encontrado el Backend que comparte para %s",
+    "Click the button below to open it." : "Haga click en el botón de abajo para abrirlo.",
     "Open »%s«" : "Abrir »%s«",
+    "Unknown share type" : "Tipo de elemento compartido desconocido",
     "You are not allowed to share %s" : "No tiene permitido compartir %s",
     "Cannot increase permissions of %s" : "No se pueden incrementar los permisos de %s",
     "Expiration date is in the past" : "La fecha de expiración ya ha pasado",
-    "Sharing %s failed, because this item is already shared with user %s" : "Se presento una falla al compartir %s, porque este elemento ya ha sido compartido con el usuario %s",
-    "Click the button below to open it." : "Haga click en el botón de abajo para abrirlo.",
     "Could not find category \"%s\"" : "No fue posible encontrar la categoria \"%s\"",
     "Sunday" : "Domingo",
     "Monday" : "Lunes",
@@ -124,11 +116,6 @@ OC.L10N.register(
     "Nov." : "Nov.",
     "Dec." : "Dic.",
     "A valid password must be provided" : "Se debe proporcionar una contraseña válida",
-    "The username is already being used" : "Ese nombre de usuario ya está en uso",
-    "A valid username must be provided" : "Se debe proporcionar un nombre de usuario válido",
-    "Username contains whitespace at the beginning or at the end" : "El nombre del usuario contiene un espacio en blanco al inicio o al final",
-    "Username must not consist of dots only" : "El nombre de usuario no debe consistir de solo puntos. ",
-    "User disabled" : "Usuario deshabilitado",
     "Login canceled by app" : "Inicio de sesión cancelado por la aplicación",
     "a safe home for all your data" : "un lugar seguro para todos sus datos",
     "File is currently busy, please try again later" : "El archivo se encuentra actualmente en uso, favor de intentarlo más tarde. ",
@@ -144,16 +131,30 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Esto ha sido causado probablemente por un acelerador de caché como Zend OPcache o eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "¿Los módulos de PHP han sido instalados, pero se siguen enlistando como faltantes?",
     "Please ask your server administrator to restart the web server." : "Favor de solicitar al administrador reiniciar el servidor web. ",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Favor de cambiar los permisos a 0770 para que el directorio no pueda ser enlistado por otros usuarios. ",
     "Could not obtain lock type %d on \"%s\"." : "No fue posible obtener el tipo de bloqueo %d en \"%s\". ",
     "Storage unauthorized. %s" : "Almacenamiento no autorizado. %s",
     "Storage incomplete configuration. %s" : "Configuración incompleta del almacenamiento. %s",
     "Storage connection error. %s" : "Se presentó un error con la conexión al almacenamiento. %s",
     "Storage is temporarily not available" : "El almacenamieto se encuentra temporalmente no disponible",
     "Storage connection timeout. %s" : "Se agotó el tiempo de conexión del almacenamiento. %s",
-    "Full name" : "Nombre completo",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Sólo se permiten los siguientes caracteres en el nombre de usuario: \"a-z\", \"A-Z\", \"0-9\" y \"_.@-'\"",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Se requiere de por lo menos libxml2 2.7.0. Actualmente %s esta instalado. ",
-    "To fix this issue update your libxml2 version and restart your web server." : "Para corregir este tema, favor de actualizar la versión de su libxml2 y reinicie su servidor web. "
+    "Summary" : "Resumen",
+    "Translate" : "Traducir",
+    "Result" : "Resultado",
+    "File name is a reserved word" : "Nombre de archivo es una palabra reservada",
+    "File name contains at least one invalid character" : "El nombre del archivo contiene al menos un caracter inválido",
+    "File name is too long" : "El nombre del archivo es demasiado largo",
+    "Help" : "Ayuda",
+    "Users" : "Usuarios",
+    "Unknown user" : "Ususario desconocido",
+    "Oracle username and/or password not valid" : "El nombre de usuario y/o contraseña de Oracle inválidos",
+    "PostgreSQL username and/or password not valid" : "El nombre de usuario y/o contraseña de PostgreSQL inválidos",
+    "Set an admin username." : "Configurar un nombre de usuario del administrador",
+    "Sharing %s failed, because this item is already shared with user %s" : "Se presento una falla al compartir %s, porque este elemento ya ha sido compartido con el usuario %s",
+    "The username is already being used" : "Ese nombre de usuario ya está en uso",
+    "A valid username must be provided" : "Se debe proporcionar un nombre de usuario válido",
+    "Username contains whitespace at the beginning or at the end" : "El nombre del usuario contiene un espacio en blanco al inicio o al final",
+    "Username must not consist of dots only" : "El nombre de usuario no debe consistir de solo puntos. ",
+    "User disabled" : "Usuario deshabilitado",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Favor de cambiar los permisos a 0770 para que el directorio no pueda ser enlistado por otros usuarios. "
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
