@@ -3,11 +3,9 @@ OC.L10N.register(
     {
     "Cannot write into \"config\" directory!" : "לא ניתן לכתוב לתיקיית „config”!",
     "See %s" : "יש לעיין ב־%s",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "הקבצים של היישומון %1$s לא מוקמו במקום הנכון. נא לוודא שזו גרסה שהשרת תומך בה.",
     "Sample configuration detected" : "התגלתה דוגמת תצורה",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "התגלה שדוגמת התצורה הועתקה. דבר זה עלול לשבור את ההתקנה ולא נתמך.יש לקרוא את מסמכי התיעוד לפני שמבצעים שינויים ב- config.php",
     "Other activities" : "פעילויות אחרות",
-    "Education Edition" : "מהדורה חינוכית",
     "Enterprise bundle" : "מהדורה מסחרית",
     "Groupware bundle" : "מהדורה קבוצתית",
     "Social sharing bundle" : "מאגד שיתוף חברתי",
@@ -22,11 +20,11 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "קיימת תמיכה בפלטפורמות הבאות: %s",
     "Server version %s or higher is required." : "נדרשת גרסה שרת %s ומעלה.",
     "Server version %s or lower is required." : "נדרשת גרסה שרת %s ומטה.",
-    "Logged in user must be an admin" : "על המשתמש שנכנס להיות מנהל",
     "Authentication" : "אימות",
     "Unknown filetype" : "סוג קובץ לא מוכר",
     "Invalid image" : "תמונה לא חוקית",
     "Avatar image is not square" : "התמונה המייצגת אינה מרובעת",
+    "Files" : "קבצים",
     "today" : "היום",
     "tomorrow" : "מחר",
     "yesterday" : "אתמול",
@@ -34,34 +32,31 @@ OC.L10N.register(
     "_%n day ago_::_%n days ago_" : ["לפני %n יום","לפני %n ימים","לפני %n ימים","לפני %n ימים"],
     "next month" : "בחודש הבא",
     "last month" : "חודש שעבר",
-    "_in %n month_::_in %n months_" : ["בעוד חודש","בעוד חודשיים","בעוד %n חודשים","בעוד %n חודשים"],
-    "_%n month ago_::_%n months ago_" : ["לפני חודש","לפני חודשיים","לפני %n חודשים","לפני %n חודשים"],
+    "_in %n month_::_in %n months_" : ["בעוד חודש","בעוד חודשיים","בעוד %n חודשים"],
+    "_%n month ago_::_%n months ago_" : ["לפני חודש","לפני חודשיים","לפני %n חודשים"],
     "next year" : "בשנה הבאה",
     "last year" : "שנה שעברה",
     "_in %n year_::_in %n years_" : ["בעוד שנה","בעוד שנתיים","בעוד %n שנים","בעוד %n שנים"],
     "_%n year ago_::_%n years ago_" : ["לפני %n שנה","לפני %n שנים","לפני %n שנים","לפני %n שנים"],
     "_in %n hour_::_in %n hours_" : ["בעוד שעה","בעוד שעתיים","בעוד %n שעות","בעוד %n שעות"],
-    "_%n hour ago_::_%n hours ago_" : ["לפני שעה","לפני שעתיים","לפני %n שעות","לפני %n שעות"],
+    "_%n hour ago_::_%n hours ago_" : ["לפני שעה","לפני שעתיים","לפני %n שעות"],
     "_in %n minute_::_in %n minutes_" : ["בעוד דקה","בעוד 2 דקות","בעוד %n דקות","בעוד %n דקות"],
     "_%n minute ago_::_%n minutes ago_" : ["לפני דקה","לפני 2 דקות","לפני %n דקות","לפני %n דקות"],
     "in a few seconds" : "בעוד מספר שניות",
     "seconds ago" : "לפני מספר שניות",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "המודול עם המזהה: %s לא קיים. נא להפעיל אותו בהגדרות היישומונים שלך או ליצור קשר עם מנהל המערכת.",
-    "File already exists" : "הקובץ כבר קיים",
-    "File name is a reserved word" : "שם קובץ הוא מילה שמורה",
-    "File name contains at least one invalid character" : "שם הקובץ כולל לפחות תו אחד לא חוקי",
-    "File name is too long" : "שם קובץ ארוך מדי",
     "Dot files are not allowed" : "אסור ששמות קבצים יתחילו בנקודה",
+    "File already exists" : "הקובץ כבר קיים",
+    "Filename contains at least one invalid character" : "שם הקובץ מכיל לפחות תו אחד שגוי",
     "Empty filename is not allowed" : "שם קובץ ריק אינו מאושר",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "יישום \"%s\" לא ניתן להתקנה כיוון שקובץ appinfo לא ניתן לקריאה.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "לא ניתן להתקין את היישומון „%s” כיוון שאין לו תמיכה בגרסה זו של השרת.",
     "__language_name__" : "עברית",
     "This is an automatically sent email, please do not reply." : "זו הודעת דוא״ל שנשלחה אוטומטית, נא לא להגיב.",
-    "Help" : "עזרה",
+    "Appearance and accessibility" : "תצוגה ונגישות",
     "Apps" : "יישומים",
     "Settings" : "הגדרות",
     "Log out" : "התנתק",
-    "Users" : "משתמשים",
     "Email" : "דוא״ל",
     "Phone" : "טלפון",
     "Twitter" : "טוויטר",
@@ -69,39 +64,29 @@ OC.L10N.register(
     "Address" : "כתובת",
     "Profile picture" : "תמונת פרופיל",
     "About" : "על אודות",
-    "Full name" : "שם מלא",
-    "Unknown user" : "משתמש לא ידוע",
     "Additional settings" : "הגדרות נוספות",
-    "%s enter the database username and name." : "%s יש להכניס את שם המשתמש ושם מסד הנתונים.",
-    "%s enter the database username." : "%s נכנס למסד נתוני שמות המשתמשים.",
-    "%s enter the database name." : "%s נכנס למסד נתוני השמות.",
-    "%s you may not use dots in the database name" : "%s לא ניתן להשתמש בנקודות בשם מסד הנתונים",
-    "MySQL username and/or password not valid" : "שם המשתמש ו/או הססמה של MySQL אינם תקינים",
     "You need to enter details of an existing account." : "עליך להקליד פרטים של חשבון קיים.",
     "Oracle connection could not be established" : "לא ניתן היה ליצור חיבור Oracle",
-    "Oracle username and/or password not valid" : "שם משתמש ו/או סיסמת Oracle אינם תקפים",
-    "PostgreSQL username and/or password not valid" : "שם משתמש ו/או סיסמת PostgreSQL אינם תקפים",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X אינו נתמך ו- %s לא יעבוד כשורה בפלטפורמה זו. ניתן לקחת סיכון ולהשתמש באחריותך! ",
     "For the best results, please consider using a GNU/Linux server instead." : "לתוצאות הכי טובות, יש לשקול שימוש בשרת GNU/Linux במקום.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "נראה ש- %s עובד על בסיס סביבת 32-bit PHP ושה- open_basedir הוגדר בקובץ php.ini. מצב זה יוביל לבעיות עם קבצים הגדולים מ- 4 GB ואינו מומלץ לחלוטין.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "יש להסיר את הגדרת open_basedir מתוך קובץ php.ini או להחליף לסביבת 64-bit PHP.",
-    "Set an admin username." : "קביעת שם משתמש מנהל",
     "Set an admin password." : "קביעת סיסמת מנהל",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "צד אחורי לשיתוף %s חייב ליישם את ממשק OCP\\Share_Backend",
     "Sharing backend %s not found" : "צד אחורי לשיתוף %s לא נמצא",
     "Sharing backend for %s not found" : "צד אחורי לשיתוף של %s לא נמצא",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s שיתף » %2$s« איתך, ורוצה להוסיף:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$sשיתף »%2$s« איתך, ורוצה להוסיף:",
-    "»%s« added a note to a file shared with you" : "התווספה הערה על קובץ ששותף את על ידי „%s”",
-    "Open »%s«" : "פתיחת „%s”",
-    "%1$s via %2$s" : "%1$s דרך %2$s",
-    "You are not allowed to share %s" : "אינך רשאי/ת לשתף %s",
-    "Cannot increase permissions of %s" : "לא ניתן להוסיף על ההרשאות של %s",
-    "Expiration date is in the past" : "תאריך תפוגה הנו בעבר",
-    "Sharing %s failed, because this item is already shared with user %s" : "השיתוף %s נכשל, כיוון שהפריט כבר משותף עם משתמש %s",
     "%1$s shared »%2$s« with you" : "%2$s שותף אתך על ידי %1$s",
     "%1$s shared »%2$s« with you." : "„%2$s” שותף אתך על ידי %1$s.",
     "Click the button below to open it." : "יש ללחוץ על הכפתור להלן כדי לפתוח אותו.",
+    "Open »%s«" : "פתיחת „%s”",
+    "%1$s via %2$s" : "%1$s דרך %2$s",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s שיתף » %2$s« איתך, ורוצה להוסיף:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$sשיתף »%2$s« איתך, ורוצה להוסיף:",
+    "»%s« added a note to a file shared with you" : "התווספה הערה על קובץ ששותף את על ידי „%s”",
+    "Unknown share type" : "סוג שיתוף אינו מוכר",
+    "You are not allowed to share %s" : "אינך רשאי/ת לשתף %s",
+    "Cannot increase permissions of %s" : "לא ניתן להוסיף על ההרשאות של %s",
+    "Expiration date is in the past" : "תאריך תפוגה הנו בעבר",
     "The requested share does not exist anymore" : "השיתוף המבוקש אינו קיים עוד",
     "Could not find category \"%s\"" : "לא ניתן למצוא את הקטגוריה „%s“",
     "Sunday" : "יום ראשון",
@@ -149,16 +134,7 @@ OC.L10N.register(
     "Oct." : "אוק׳",
     "Nov." : "נוב׳",
     "Dec." : "דצמ׳",
-    "The user limit has been reached and the user was not created." : "הגעת למגבלת המשתמשים והמשתמש לא נוצר.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "רק התווים הבאים מאושרים לשם משתמש: \"a-z\", \"A-Z\", \"0-9\", וגם \"_.@-'\"",
-    "A valid username must be provided" : "יש לספק שם משתמש תקני",
-    "Username contains whitespace at the beginning or at the end" : "שם המשתמש מכיל רווח בתחילתו או בסופו",
-    "Username must not consist of dots only" : "שם המשתמש לא יכול להיות מורכב מנקודות בלבד",
-    "Username is invalid because files already exist for this user" : "שם המשתמש שגוי כיוון שכבר קיימים קבצים למשתמש הזה",
     "A valid password must be provided" : "יש לספק ססמה תקנית",
-    "The username is already being used" : "השם משתמש כבר בשימוש",
-    "Could not create user" : "לא ניתן ליצור משתמש",
-    "User disabled" : "משתמש מנוטרל",
     "Login canceled by app" : "התחברות בוטלה על ידי יישום",
     "a safe home for all your data" : "בית בטוח עבור כל המידע שלך",
     "File is currently busy, please try again later" : "הקובץ בשימוש כרגע, יש לנסות שוב מאוחר יותר",
@@ -171,14 +147,10 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "יש לבקש ממנהל השרת שלך להתקין את המודול.",
     "PHP setting \"%s\" is not set to \"%s\"." : "הגדרות PHP \"%s\" אינם מוגדרות ל- \"%s\"",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "התאמת ההגדרה הזו ב־php.ini יאפשר ל־Nextcloud לפעול שוב",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 נדרש לכל הפחות. כרגע %s מותקן.",
-    "To fix this issue update your libxml2 version and restart your web server." : "לתיקון הבעיה יש לעדכן את גרסת ה- libxml2 שלך ולהפעיל מחדש את שרת האינטרנט שלך.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ככל הנראה מוגדר ל- strip inline doc blocks. זה יגרום למספר יישומי ליבה לא להיות נגישים.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "זה ככל הנראה נגרם על ידי מאיץ/מטמון כמו Zend OPcache או eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "מודולי PHP הותקנו, אך עדיין רשומים כחסרים?",
     "Please ask your server administrator to restart the web server." : "יש לבקש ממנהל השרת שלך להפעיל מחדש את שרת האינטרנט.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "יש לשנות את ההרשאות ל- 0770 כך שהתיקייה לא תרשם על ידי משתמשים אחרים.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "נא לוודא שיש קובץ בשם „‎.ocdata” בבסיס תיקיית הנתונים שלך.",
     "Action \"%s\" not supported or implemented." : "הפעולה „%s” אינה נתמכת או שאינה מוטמעת.",
     "Authentication failed, wrong token or provider ID given" : "האימות נכשל, האסימון או מזהה הספק שסופקו שגויים",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "חסרים משתנים להשלמת הבקשה. המשתנים החסרים: „%s”",
@@ -188,22 +160,30 @@ OC.L10N.register(
     "Storage connection error. %s" : "שגיאת חיבור אחסון. %s",
     "Storage is temporarily not available" : "האחסון אינו זמין כרגע",
     "Storage connection timeout. %s" : "פסק זמן חיבור אחסון. %s",
-    "This can usually be fixed by giving the webserver write access to the config directory." : "בדרך כלל ניתן לתקן זאת על ידי מתן גישת כתיבה לשרת לתיקיית ההגדרות (config).",
-    "Cannot write into \"config\" directory" : "לא ניתן לכתוב לתיקיית \"config\"!",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "בדרך כלל ניתן לתקן זאת על ידי הענקת גישה לשרת לכתוב לתיקיית ההגדרות. נא לעיין ב־%s",
-    "Cannot write into \"apps\" directory" : "לא ניתן לכתוב לתיקיית \"apps\"",
-    "Cannot create \"data\" directory" : "לא ניתן ליצור תיקיית „data”",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "בדרך כלל ניתן לתקן זאת על ידי הענקת גישה לשרת לכתוב לתיקיית הבסיס. נא לעיין ב־%s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "בדרך כלל ניתן לתקן הרשאות על ידי מתן גישה לשרת שלך אל תיקיית העל. נא לעיין ב־%s.",
-    "Setting locale to %s failed" : "הגדרת שפה ל- %s נכשלה",
-    "Please install one of these locales on your system and restart your webserver." : "יש להתקין אחת מהשפות על המערכת שלך ולהפעיל מחדש את שרת האינטרנט.",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload מוגדר ל- \"%s\" במקום הערך המצופה \"0\"",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "לתיקון בעיה זו יש להגדיר <code>mbstring.func_overload</code> כ- <code>0</code> iבקובץ ה- php.ini שלך",
-    "PostgreSQL >= 9 required" : "נדרש PostgreSQL >= 9",
-    "Please upgrade your database version" : "יש לשדרג את גרסת מסד הנתונים שלך",
-    "Your data directory is readable by other users" : "תיקיית הנתונים שלך ניתנת לקריאה על ידי משתמשים אחרים",
-    "Your data directory must be an absolute path" : "תיקיית הנתונים שלך חייבת להיות במבנה של נתיב מלא (מיקום מוחלט)",
-    "Check the value of \"datadirectory\" in your configuration" : "יש לבדוק את הערך \"datadirectory\" בהגדרות התצורה שלך",
-    "Your data directory is invalid" : "תיקיית הנתונים שלך שגויה"
+    "Summary" : "תקציר",
+    "Translate" : "תרגום",
+    "Result" : "תוצאה",
+    "Education Edition" : "מהדורה חינוכית",
+    "Logged in user must be an admin" : "על המשתמש שנכנס להיות מנהל",
+    "File name is a reserved word" : "שם קובץ הוא מילה שמורה",
+    "File name contains at least one invalid character" : "שם הקובץ כולל לפחות תו אחד לא חוקי",
+    "File name is too long" : "שם קובץ ארוך מדי",
+    "Help" : "עזרה",
+    "Users" : "משתמשים",
+    "Unknown user" : "משתמש לא ידוע",
+    "MySQL username and/or password not valid" : "שם המשתמש ו/או הססמה של MySQL אינם תקינים",
+    "Oracle username and/or password not valid" : "שם משתמש ו/או סיסמת Oracle אינם תקפים",
+    "PostgreSQL username and/or password not valid" : "שם משתמש ו/או סיסמת PostgreSQL אינם תקפים",
+    "Set an admin username." : "קביעת שם משתמש מנהל",
+    "Sharing %s failed, because this item is already shared with user %s" : "השיתוף %s נכשל, כיוון שהפריט כבר משותף עם משתמש %s",
+    "The username is already being used" : "השם משתמש כבר בשימוש",
+    "Could not create user" : "לא ניתן ליצור משתמש",
+    "A valid username must be provided" : "יש לספק שם משתמש תקני",
+    "Username contains whitespace at the beginning or at the end" : "שם המשתמש מכיל רווח בתחילתו או בסופו",
+    "Username must not consist of dots only" : "שם המשתמש לא יכול להיות מורכב מנקודות בלבד",
+    "Username is invalid because files already exist for this user" : "שם המשתמש שגוי כיוון שכבר קיימים קבצים למשתמש הזה",
+    "User disabled" : "משתמש מנוטרל",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "יש לשנות את ההרשאות ל- 0770 כך שהתיקייה לא תרשם על ידי משתמשים אחרים.",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "נא לוודא שיש קובץ בשם „‎.ocdata” בבסיס תיקיית הנתונים שלך."
 },
-"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
+"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
