@@ -5,10 +5,9 @@ OC.L10N.register(
     "This can usually be fixed by giving the web server write access to the config directory." : "これは通常、Webサーバーにconfigディレクトリへの書き込み権限を与えることで解決できます。",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "しかし、config.phpファイルを読み取り専用にしたい場合は、オプションの \"config_is_read_only\"をtrueに設定してください。",
     "See %s" : "%s を閲覧",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "アプリ %1$s のファイルが正しく置き換えられませんでした。サーバーと互換性のあるバージョンであることを確認してください。",
+    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "アプリケーション%1$sが存在しないか、このサーバと互換性のないバージョンがあります。apps ディレクトリを確認してください。",
     "Sample configuration detected" : "サンプル設定が見つかりました。",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "サンプル設定がコピーされてそのままです。このままではインストールが失敗し、サポート対象外になります。config.phpを変更する前にドキュメントを確認してください。",
-    "404" : "404",
     "The page could not be found on the server." : "ページがサーバー上に見つかりませんでした。",
     "%s email verification" : "%sメールによる確認",
     "Email verification" : "メールによる確認",
@@ -20,10 +19,11 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s と %2$s、%3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s と %2$s、%3$s、%4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s と %2$s、%3$s、%4$s、%5$s",
-    "Education Edition" : "教育向けエディション",
+    "Education bundle" : "教育向けバンドル",
     "Enterprise bundle" : "エンタープライズ バンドル",
     "Groupware bundle" : "グループウェア バンドル",
     "Hub bundle" : "Hubバンドル",
+    "Public sector bundle" : "公共部門バンドル",
     "Social sharing bundle" : "SNS バンドル",
     "PHP %s or higher is required." : "PHP %s 以上が必要です。",
     "PHP with a version lower than %s is required." : "%s 以前のバージョンのPHPが必要です。",
@@ -37,9 +37,10 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "次のプラットフォームをサポートしています: %s",
     "Server version %s or higher is required." : "サーバーの %s よりも高いバージョンが必要です。",
     "Server version %s or lower is required." : "サーバーの %s よりも低いバージョンが必要です。",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "この設定にアクセスするには、ログインしたユーザーが管理者、サブ管理者、または特別な権利が必要です。",
-    "Logged in user must be an admin or sub admin" : "ログインユーザーは管理者またはサブ管理者である必要があります",
-    "Logged in user must be an admin" : "ログインユーザーは管理者である必要があります",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "この設定にアクセスするには、ログインしたアカウントが管理者、サブ管理者、または特別な権利を持っている必要があります。",
+    "Your current IP address doesn’t allow you to perform admin actions" : "現在のIPアドレスでは管理アクションを実行できません",
+    "Logged in account must be an admin or sub admin" : "ログインアカウントは管理者またはサブ管理者である必要があります",
+    "Logged in account must be an admin" : "ログインアカウントは管理者である必要があります",
     "Wiping of device %s has started" : "端末%sのワイプを開始しました。",
     "Wiping of device »%s« has started" : "端末»%s«のワイプを開始しました。",
     "»%s« started remote wipe" : "»%s«がリモートワイプを開始しました",
@@ -80,27 +81,34 @@ OC.L10N.register(
     "seconds ago" : "数秒前",
     "Empty file" : "空白のファイル",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "ID: %sのモジュールは存在しません。アプリ設定で有効にするか、管理者に問い合わせてください。",
+    "Dot files are not allowed" : "隠しファイルは許可されていません",
+    "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\"は禁止されているファイル名またはフォルダー名です。",
+    "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\"は、ファイル名やフォルダー名には使用できない接頭辞です。",
+    "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\"はファイル名やフォルダー名の中に入れることはできません。",
+    "\"%1$s\" is a forbidden file type." : "\"%1$s\"は禁止されているファイルタイプです。",
+    "Filenames must not end with \"%1$s\"." : "ファイル名は \"%1$s\"で終了できません。",
+    "Invalid parent path" : "無効な親パス",
     "File already exists" : "ファイルが既に存在します",
     "Invalid path" : "パスが無効",
     "Failed to create file from template" : "テンプレートからファイルを作成できませんでした",
     "Templates" : "テンプレート",
-    "File name is a reserved word" : "ファイル名が予約された単語です",
-    "File name contains at least one invalid character" : "ファイル名に1文字以上の無効な文字が含まれています",
-    "File name is too long" : "ファイル名が長すぎます",
-    "Dot files are not allowed" : "隠しファイルは許可されていません",
+    "Path contains invalid segments" : "パスに無効なセグメントが含まれています",
+    "Filename is a reserved word" : "ファイル名が予約された単語です",
+    "Filename contains at least one invalid character" : "ファイル名に使用できない文字が含まれています",
+    "Filename is too long" : "ファイル名が長すぎます",
     "Empty filename is not allowed" : "空のファイル名は許可されていません",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "appinfoファイルが読み込めないため、アプリ名 \"%s\"  がインストールできません。",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "\"%s\" アプリは、このバージョンのサーバーと互換性がないためインストールされませんでした。",
-    "__language_name__" : "Japanese (日本語)",
+    "__language_name__" : "日本語 (Japanese)",
     "This is an automatically sent email, please do not reply." : "これは自動的に生成されたメールです。返信しないでください。",
-    "Help" : "ヘルプ",
+    "Help & privacy" : "ヘルプとプライバシー",
     "Appearance and accessibility" : "外観とアクセシビリティ",
     "Apps" : "アプリ",
     "Personal settings" : "個人設定",
     "Administration settings" : "管理者設定",
     "Settings" : "設定",
     "Log out" : "ログアウト",
-    "Users" : "ユーザー",
+    "Accounts" : "アカウント",
     "Email" : "メール",
     "Mail %s" : "メール %s",
     "Fediverse" : "フェディバース",
@@ -114,50 +122,86 @@ OC.L10N.register(
     "Address" : "アドレス",
     "Profile picture" : "プロフィールの写真",
     "About" : "詳細",
-    "Full name" : "フルネーム",
+    "Display name" : "表示名",
     "Headline" : "見出し",
     "Organisation" : "組織",
     "Role" : "ロール",
-    "Unknown user" : "不明なユーザー",
+    "Unknown account" : "不明なアカウント",
     "Additional settings" : "追加設定",
-    "Enter the database username and name for %s" : "%sのデータベース名とユーザー名を入力してください",
-    "Enter the database username for %s" : "%sのデータベースのユーザー名を指定してください",
+    "Enter the database Login and name for %s" : "%s のデータベース名とログイン名を入力してください",
+    "Enter the database Login for %s" : "%sのデータベースログイン名を入力してください",
     "Enter the database name for %s" : "%sのデータベース名を指定してください",
     "You cannot use dots in the database name %s" : "データベース名%sにドットを入れることはできません",
-    "MySQL username and/or password not valid" : "MySQLのユーザー名またはパスワードが有効ではありません",
+    "MySQL Login and/or password not valid" : "MySQLのログイン名またはパスワードが有効ではありません",
     "You need to enter details of an existing account." : "既存のアカウントの詳細を入力してください。",
     "Oracle connection could not be established" : "Oracleへの接続が確立できませんでした。",
-    "Oracle username and/or password not valid" : "Oracleのユーザー名またはパスワードが有効ではありません",
-    "PostgreSQL username and/or password not valid" : "PostgreSQLのユーザー名またはパスワードが有効ではありません",
+    "Oracle Login and/or password not valid" : "Oracleのログイン名またはパスワードが有効ではありません",
+    "PostgreSQL Login and/or password not valid" : "PostgreSQLのログイン名またはパスワードが有効ではありません",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X では、サポートされていません。このOSでは、%sは正常に動作しないかもしれません。ご自身の責任においてご利用ください。",
     "For the best results, please consider using a GNU/Linux server instead." : "最も良い方法としては、代わりにGNU/Linuxサーバーを利用することをご検討ください。",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "このインスタンス %s は、32bit PHP 環境で動作しており、php.ini に open_basedir が設定されているようです。4GB以上のファイルで問題が発生するため、この設定を利用しないことをお勧めします。",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "php.ini から open_basedir 設定を削除するか、64bit PHPに切り替えてください。",
-    "Set an admin username." : "管理者のユーザー名を設定",
+    "Set an admin Login." : "管理者ログインを設定します。",
     "Set an admin password." : "管理者のパスワードを設定",
     "Cannot create or write into the data directory %s" : " データディレクトリ%sに作成、書き込みができません",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "%s のバックエンドの共有には、OCP\\Share_Backend インターフェースを実装しなければなりません。",
     "Sharing backend %s not found" : "共有バックエンド %s が見つかりません",
     "Sharing backend for %s not found" : "%s のための共有バックエンドが見つかりません",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s さんが »%2$s« にノートを追加しました。",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s shared »%2$s« with you and wants to add",
-    "»%s« added a note to a file shared with you" : "»%s« があなたと共有しているファイルにノートを追加しました。 ",
-    "Open »%s«" : "»%s«を開く",
-    "%1$s via %2$s" : "%1$s via %2$s",
-    "You are not allowed to share %s" : "%s を共有することを許可されていません。",
-    "Cannot increase permissions of %s" : "%sの権限を追加できません ",
-    "Files cannot be shared with delete permissions" : "削除権限付きでファイルを共有できません",
-    "Files cannot be shared with create permissions" : "作成権限付きでファイルを共有できません",
-    "Expiration date is in the past" : "有効期限が切れています",
-    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["%s 日以上先の有効期限は設定できません "],
-    "Sharing is only allowed with group members" : "共有はグループメンバーにのみ許可されます",
-    "Sharing %s failed, because this item is already shared with user %s" : "このアイテム%sはすでにユーザー%sと共有されているため、共有に失敗しました",
     "%1$s shared »%2$s« with you" : "%1$s は »%2$s« をあなたと共有しました",
     "%1$s shared »%2$s« with you." : "%1$sが あなたと »%2$s« を共有しました。",
     "Click the button below to open it." : "開くには下のボタンをクリック",
+    "Open »%s«" : "»%s«を開く",
+    "%1$s via %2$s" : "%1$s via %2$s",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s さんが »%2$s« にノートを追加しました。",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s shared »%2$s« with you and wants to add",
+    "»%s« added a note to a file shared with you" : "»%s« があなたと共有しているファイルにノートを追加しました。 ",
+    "Passwords are enforced for link and mail shares" : "リンクとメールの共有にパスワードが強制されます",
+    "SharedWith is not a valid user" : "SharedWithは有効なユーザーではありません",
+    "SharedWith is not a valid group" : "SharedWithは有効なグループではありません",
+    "SharedWith should be empty" : "SharedWithは空でなければなりません",
+    "SharedWith should not be empty" : "SharedWithは空にできません",
+    "SharedWith is not a valid circle" : "SharedWithは有効なサークルではありません",
+    "Unknown share type" : "不明な共有タイプ",
+    "SharedBy should be set" : "SharedByを設定する必要があります",
+    "Cannot share with yourself" : "自分自身とは共有できません",
+    "Path should be set" : "パスを設定する必要があります",
+    "Path should be either a file or a folder" : "パスは、ファイルまたはフォルダーのいずれかでなければなりません",
+    "You cannot share your root folder" : "ルートルートフォルダーを共有することはできません",
+    "You are not allowed to share %s" : "%s を共有することを許可されていません。",
+    "A share requires permissions" : "共有には権限が必要です",
+    "Cannot increase permissions of %s" : "%sの権限を追加できません ",
+    "Shares need at least read permissions" : "共有には少なくとも読み取り権限が必要です",
+    "Files cannot be shared with delete permissions" : "削除権限付きでファイルを共有できません",
+    "Files cannot be shared with create permissions" : "作成権限付きでファイルを共有できません",
+    "Expiration date is in the past" : "有効期限が切れています",
+    "Expiration date is enforced" : "有効期限は強制されています",
+    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["%n 日以上先の有効期限は設定できません "],
+    "Sharing is only allowed with group members" : "共有はグループメンバーにのみ許可されます",
+    "Sharing %s failed, because this item is already shared with the account %s" : "このアイテム %s はすでにアカウント %s と共有されているため、共有に失敗しました",
+    "Group sharing is now allowed" : "グループ共有が許可されました",
+    "Sharing is only allowed within your own groups" : "共有は自分のグループ内でのみ許可されています",
+    "Path is already shared with this group" : "パスはすでにこのグループで共有されています",
+    "Link sharing is not allowed" : "リンクの共有は許可されていません",
+    "Public upload is not allowed" : "公開アップロードは許可されていません",
+    "Path contains files shared with you" : "パスにはあなたと共有するファイルが含まれています",
+    "Sharing is disabled" : "共有は無効になっています",
+    "Sharing is disabled for you" : "共有は無効になっています",
+    "Cannot share with the share owner" : "共有所有者と共有できません",
+    "Cannot change share type" : "共有タイプを変更できません",
+    "Can only update recipient on user shares" : "ユーザー共有の受信者のみ更新可能",
+    "Cannot enable sending the password by Talk with an empty password" : "空のパスワードでTalkによるパスワード送信を有効にできません",
+    "Cannot enable sending the password by Talk without setting a new password" : "新しいパスワードを設定しないとTalkでパスワードを送信できません",
+    "Cannot disable sending the password by Talk without setting a new password" : "新しいパスワードを設定しないとTalkによるパスワード送信を無効にできません",
+    "Share provider does not support accepting" : "共有プロバイダは受け入れをサポートしていません",
+    "Cannot change target of link share" : "リンク共有のターゲットを変更できません",
+    "Invalid recipient" : "無効な受信者",
+    "Group \"%s\" does not exist" : "グループ \"%s\" は存在しません",
     "The requested share does not exist anymore" : "この共有はもう存在しません。",
+    "The requested share comes from a disabled user" : "要求された共有は無効化されたユーザーからのものです。",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "登録可能なユーザー数の上限に達したため、ユーザーは作成されませんでした。詳細については通知をご確認ください。",
     "Could not find category \"%s\"" : "カテゴリ \"%s\" が見つかりませんでした",
+    "Input text" : "テキストを入力",
+    "The input text" : "入力テキスト",
     "Sunday" : "日曜日",
     "Monday" : "月曜日",
     "Tuesday" : "火曜日",
@@ -204,14 +248,14 @@ OC.L10N.register(
     "Nov." : "11月",
     "Dec." : "12月",
     "A valid password must be provided" : "有効なパスワードを指定する必要があります",
-    "The username is already being used" : "このユーザー名はすでに使われています",
-    "Could not create user" : "ユーザーを作成できませんでした",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "ユーザー名で利用できる文字列： \"a-z\", \"A-Z\", \"0-9\", スペース, \"_.@-\"",
-    "A valid username must be provided" : "有効なユーザー名を指定する必要があります",
-    "Username contains whitespace at the beginning or at the end" : "ユーザー名の最初か最後に空白が含まれています",
-    "Username must not consist of dots only" : "ユーザー名に、ドットのみはつけられません",
-    "Username is invalid because files already exist for this user" : "このユーザーのファイルが既に存在するため、このユーザー名は使用できません",
-    "User disabled" : "ユーザーは無効です",
+    "The Login is already being used" : "ログイン名は既に使用されています",
+    "Could not create account" : "アカウントを作成できませんでした",
+    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "ログイン名で利用できる文字列： \"a-z\", \"A-Z\", \"0-9\", スペース, \"_.@-'\"",
+    "A valid Login must be provided" : "ログイン名を提供する必要があります",
+    "Login contains whitespace at the beginning or at the end" : "ログイン名の最初か最後に空白が含まれています",
+    "Login must not consist of dots only" : "ログイン名はドットのみで構成されてはいけません",
+    "Login is invalid because files already exist for this user" : "このユーザのファイルが既に存在するため、このログイン名は使用できません",
+    "Account disabled" : "アカウントは無効",
     "Login canceled by app" : "アプリによりログインが中止されました",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "次の依存関係を満たしていないため、アプリ \"%1$s\" をインストールできません: %2$s",
     "a safe home for all your data" : "すべてのデータを安全に保管します",
@@ -238,22 +282,18 @@ OC.L10N.register(
     "Adjusting this setting in php.ini will make Nextcloud run again" : "php.ini のこの設定を調整して、再度 Nextcloudを起動してください。",
     "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code>の値は <code>0</code>であるべきですが、<code>%s</code> に設定されています。",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "この問題を修正するには、php.ini ファイルの <code>mbstring.func_overload</code> を <code>0</code> に設定してください。",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 バージョン 2.7.0 が最低必要です。現在 %s がインストールされています。",
-    "To fix this issue update your libxml2 version and restart your web server." : "この問題を解決するには、libxml2 を更新して、Webサーバーを再起動してください。",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHPでインラインドキュメントブロックを取り除く設定になっています。これによりコアアプリで利用できないものがいくつかあります。",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "これは、Zend OPcacheやeAccelerator 等のキャッシュ/アクセラレーターが原因かもしれません。",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP モジュールはインストールされていますが、まだ一覧に表示されていますか？",
     "Please ask your server administrator to restart the web server." : "サーバー管理者にWebサーバーを再起動するよう依頼してください。",
     "The required %s config variable is not configured in the config.php file." : "必要な %s 構成変数が config.php ファイルに設定されていません。",
     "Please ask your server administrator to check the Nextcloud configuration." : "サーバー管理者にNextcloud構成を確認するように依頼してください。",
-    "PostgreSQL >= 9 required." : "PostgreSQL 9以上が必要です",
-    "Please upgrade your database version." : "新しいバージョンのデータベースにアップグレードしてください。",
-    "Your data directory is readable by other users." : "データディレクトリは他のユーザーからも読み取ることができます",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "ディレクトリが他のユーザーから見えないように、パーミッションを 0770 に変更してください。",
+    "Your data directory is readable by other people." : "あなたのデータディレクトリは他の人が読み取ることができます",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "ディレクトリが他人から見えないように、パーミッションを 0770 に変更してください。",
     "Your data directory must be an absolute path." : "データディレクトリは、絶対パスにする必要があります",
     "Check the value of \"datadirectory\" in your configuration." : "設定ファイル内の \"datadirectory\" の値を確認してください。",
     "Your data directory is invalid." : "データディレクトリが無効です",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "データディレクトリの直下に \".ocdata\" ファイルがあるのを確認してください。",
+    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "データディレクトリのルートに\"%1$s\"というファイルがあることを確認します。内容は次のようになります:\"%2$s\"",
     "Action \"%s\" not supported or implemented." : "アクション「%s」は対応していないか、実装されていません。",
     "Authentication failed, wrong token or provider ID given" : "認証できませんでした。トークンまたはプロバイダーIDが間違っています",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "要求を完了するためのパラメータがありません。欠落したパラメータ:「%s」",
@@ -265,11 +305,119 @@ OC.L10N.register(
     "Storage connection error. %s" : "ストレージへの接続エラー｡ %s",
     "Storage is temporarily not available" : "ストレージは一時的に利用できません",
     "Storage connection timeout. %s" : "ストレージへの接続がタイムアウト。 %s",
-    "%s enter the database username and name." : "%s データベース名とデータベースのユーザー名を入力してください。",
-    "%s enter the database username." : "%s のデータベースのユーザー名を入力してください。",
-    "%s enter the database name." : "%s のデータベース名を入力してください。",
-    "%s you may not use dots in the database name" : "%s ではデータベース名にドットを利用できないかもしれません。",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "ユーザー制限に達したため、ユーザーは作成されませんでした。詳細については、通知を確認してください。",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "ユーザー名で利用できる文字列： \"a-z\", \"A-Z\", \"0-9\", \"_.@-\""
+    "Transcribe audio" : "音声の書き起こし",
+    "Transcribe the things said in an audio" : "音声で言ったことを書き起こす",
+    "Audio input" : "音声入力",
+    "The audio to transcribe" : "文字起こしする音声",
+    "Transcription" : "書き起こし",
+    "The transcribed text" : "書き起こされたテキスト",
+    "Context write" : "コンテキストを書く",
+    "Writes text in a given style based on the provided source material." : "提供されたソース資料に基づいて、指定されたスタイルでテキストを作成します。",
+    "Writing style" : "文体",
+    "Demonstrate a writing style that you would like to immitate" : "真似したい文章の書き方を示す",
+    "Source material" : "素材",
+    "The content that would like to be rewritten in the new writing style" : "新しい書き方で書き直したい内容",
+    "Generated text" : "生成されたテキスト",
+    "The generated text with content from the source material in the given style" : "指定されたスタイルのソースマテリアルのコンテンツを含む生成テキスト",
+    "Emoji generator" : "絵文字ジェネレーター",
+    "Takes text and generates a representative emoji for it." : "テキストを受け取り、それを表す絵文字を生成します。",
+    "The text to generate an emoji for" : "絵文字を生成するテキスト",
+    "Generated emoji" : "生成された絵文字",
+    "The generated emoji based on the input text" : "入力テキストに基づいて生成された絵文字",
+    "Generate image" : "画像生成",
+    "Generate an image from a text prompt" : "テキストプロンプトから画像を生成する",
+    "Prompt" : "プロンプト",
+    "Describe the image you want to generate" : "生成する画像を記述します",
+    "Number of images" : "画像の枚数",
+    "How many images to generate" : "生成する画像の数",
+    "Output images" : "出力画像",
+    "The generated images" : "生成された画像",
+    "Free text to text prompt" : "フリーテキストからテキストへのプロンプト",
+    "Runs an arbitrary prompt through a language model that returns a reply" : "応答を返す言語モデルを通じて任意のプロンプトを実行します",
+    "Describe a task that you want the assistant to do or ask a question" : "アシスタントに実行してほしいタスクまたは質問を記述します",
+    "Generated reply" : "生成された返信",
+    "The generated text from the assistant" : "アシスタントから生成されたテキスト",
+    "Chat" : "チャット",
+    "Chat with the assistant" : "アシスタントとチャット",
+    "System prompt" : "システムプロンプト",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "会話中にアシスタントが従うべきルールと前提条件を定義します。",
+    "Chat message" : "チャットメッセージ",
+    "Chat history" : "チャット履歴",
+    "The history of chat messages before the current message, starting with a message by the user" : "ユーザーのメッセージから始まる、現在のメッセージより前のチャットメッセージの履歴",
+    "Response message" : "応答メッセージ",
+    "The generated response as part of the conversation" : "会話の一部として生成された応答",
+    "Formalize text" : "テキストの形式化",
+    "Takes a text and makes it sound more formal" : "テキストを使用して、よりフォーマルに聞こえるようにします",
+    "Write a text that you want the assistant to formalize" : "アシスタントに形式化してもらいたいテキストを入力します",
+    "Formalized text" : "形式化されたテキスト",
+    "The formalized text" : "形式化されたテキスト",
+    "Generate a headline" : "見出しの生成",
+    "Generates a possible headline for a text." : "テキストの見出しの候補を生成",
+    "Original text" : "原文",
+    "The original text to generate a headline for" : "見出しを生成する元のテキスト",
+    "The generated headline" : "生成された見出し",
+    "Reformulate text" : "テキストを書き直す",
+    "Takes a text and reformulates it" : "テキストを受け取り、それを書き直す",
+    "Write a text that you want the assistant to reformulate" : "アシスタントに書き直してもらいたいテキストを入力します",
+    "Reformulated text" : "書き直されたテキスト",
+    "The reformulated text, written by the assistant" : "アシスタントによって書かれた、書き直されたテキスト",
+    "Simplify text" : "テキストの簡略化",
+    "Takes a text and simplifies it" : "テキストを受け取って簡略化する",
+    "Write a text that you want the assistant to simplify" : "アシスタントに簡略化してほしい文章を書く",
+    "Simplified text" : "簡略化されたテキスト",
+    "The simplified text" : "簡略化されたテキスト",
+    "Summarize" : "要約する",
+    "Summarizes a text" : "テキストを要約します",
+    "The original text to summarize" : "要約する元のテキスト",
+    "Summary" : "要約",
+    "The generated summary" : "生成された要約",
+    "Extract topics" : "トピックの抽出",
+    "Extracts topics from a text and outputs them separated by commas" : "テキストからトピックを抽出し、カンマ区切りで出力します",
+    "The original text to extract topics from" : "トピックを抽出する元のテキスト",
+    "Topics" : "トピック",
+    "The list of extracted topics" : "抽出されたトピックのリスト",
+    "Translate" : "翻訳",
+    "Translate text from one language to another" : "テキストをある言語から別の言語に翻訳する",
+    "Origin text" : "原文",
+    "The text to translate" : "翻訳するテキスト",
+    "Origin language" : "元の言語",
+    "The language of the origin text" : "元のテキストの言語",
+    "Target language" : "訳文の言語",
+    "The desired language to translate the origin text in" : "元のテキストを翻訳する言語",
+    "Result" : "結果",
+    "The translated text" : "翻訳されたテキスト",
+    "Free prompt" : "任意のプロンプト",
+    "Runs an arbitrary prompt through the language model." : "言語モデルを通じて任意のプロンプトを実行",
+    "Generate headline" : "見出しの生成",
+    "Summarizes text by reducing its length without losing key information." : "重要な情報を失わずにテキストの長さを要約して短縮する。",
+    "Extracts topics from a text and outputs them separated by commas." : "テキストからトピックを抽出し、カンマ区切りで出力します。",
+    "Education Edition" : "教育向けエディション",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "この設定にアクセスするには、ログインしたユーザーが管理者、サブ管理者、または特別な権利が必要です。",
+    "Logged in user must be an admin or sub admin" : "ログインユーザーは管理者またはサブ管理者である必要があります",
+    "Logged in user must be an admin" : "ログインユーザーは管理者である必要があります",
+    "File name is a reserved word" : "ファイル名が予約された単語です",
+    "File name contains at least one invalid character" : "ファイル名に1文字以上の無効な文字が含まれています",
+    "File name is too long" : "ファイル名が長すぎます",
+    "Help" : "ヘルプ",
+    "Users" : "ユーザー",
+    "Unknown user" : "不明なユーザー",
+    "Enter the database username and name for %s" : "%sのデータベース名とユーザー名を入力してください",
+    "Enter the database username for %s" : "%sのデータベースのユーザー名を指定してください",
+    "MySQL username and/or password not valid" : "MySQLのユーザー名またはパスワードが有効ではありません",
+    "Oracle username and/or password not valid" : "Oracleのユーザー名またはパスワードが有効ではありません",
+    "PostgreSQL username and/or password not valid" : "PostgreSQLのユーザー名またはパスワードが有効ではありません",
+    "Set an admin username." : "管理者のユーザー名を設定",
+    "Sharing %s failed, because this item is already shared with user %s" : "このアイテム%sはすでにユーザー%sと共有されているため、共有に失敗しました",
+    "The username is already being used" : "このユーザー名はすでに使われています",
+    "Could not create user" : "ユーザーを作成できませんでした",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "ユーザー名で利用できる文字列： \"a-z\", \"A-Z\", \"0-9\", スペース, \"_.@-\"",
+    "A valid username must be provided" : "有効なユーザー名を指定する必要があります",
+    "Username contains whitespace at the beginning or at the end" : "ユーザー名の最初か最後に空白が含まれています",
+    "Username must not consist of dots only" : "ユーザー名に、ドットのみはつけられません",
+    "Username is invalid because files already exist for this user" : "このユーザーのファイルが既に存在するため、このユーザー名は使用できません",
+    "User disabled" : "ユーザーは無効です",
+    "Your data directory is readable by other users." : "データディレクトリは他のユーザーからも読み取ることができます",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "ディレクトリが他のユーザーから見えないように、パーミッションを 0770 に変更してください。",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "データディレクトリの直下に \".ocdata\" ファイルがあるのを確認してください。"
 },
 "nplurals=1; plural=0;");
