@@ -19,7 +19,7 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s та %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s та %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s та %5$s",
-    "Education Edition" : "Для навчання",
+    "Education bundle" : "Освіта",
     "Enterprise bundle" : "Для бізнесу",
     "Groupware bundle" : "Для робочих груп",
     "Hub bundle" : "Основні застосунки",
@@ -80,26 +80,25 @@ OC.L10N.register(
     "seconds ago" : "кілька секунд тому",
     "Empty file" : "Порожній файл",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Модуль з ID: %s не існує. Будь ласка, увімкніть це в налаштуваннях застосунку або зверніться до адміністратора.",
+    "Dot files are not allowed" : "Файли які починаються з крапки не допустимі",
     "File already exists" : "Файл вже існує",
     "Invalid path" : "Недійсний шлях",
     "Failed to create file from template" : "Не вдалося створити файл із шаблону",
     "Templates" : "Шаблони",
-    "File name is a reserved word" : "Ім’я файлу є зарезервованим словом",
-    "File name contains at least one invalid character" : "Ім’я файлу містить принаймні один некоректний символ",
-    "File name is too long" : "Ім’я файлу занадто довге",
-    "Dot files are not allowed" : "Файли які починаються з крапки не допустимі",
+    "Filename contains at least one invalid character" : "У назві файлу міститься щонайменше один неправильний символ",
     "Empty filename is not allowed" : "Порожні імена файлів не допускаються",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "Застосунок \"%s\" не може бути встановлений через те, що файл appinfo не може бути прочитано.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Застосунок \"%s\" неможливо встановити, оскільки він не сумісний з цією версією сервера.",
     "__language_name__" : "Українська",
     "This is an automatically sent email, please do not reply." : "Це автоматично надісланий електронний лист, будь ласка, не відповідайте на нього.",
+    "Help & privacy" : "Допомога та приватність",
     "Appearance and accessibility" : "Тема та вигляд",
     "Apps" : "Застосунки",
     "Personal settings" : "Мої налаштування",
     "Administration settings" : "Адміністрування",
     "Settings" : "Налаштування",
     "Log out" : "Вихід",
-    "Users" : "Користувачі",
+    "Accounts" : "Облікові записи",
     "Email" : "Електронна пошта",
     "Mail %s" : "Пошта %s",
     "Fediverse" : "Fediverse",
@@ -138,11 +137,15 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Бекенд спільного доступу %s повинен реалізовувати інтерфейс OCP\\Share_Backend",
     "Sharing backend %s not found" : "Бекенд спільного доступу %s не знайдено",
     "Sharing backend for %s not found" : "Бекенд спільного доступу для %s не знайдено",
+    "%1$s shared »%2$s« with you" : "%1$s надав(-ла) доступ до \"%2$s\"",
+    "%1$s shared »%2$s« with you." : "%1$s надав(-ла) доступ до \"%2$s\".",
+    "Click the button below to open it." : "Щоб відкрити файл, натисніть кнопку нижче.",
+    "Open »%s«" : "Відкрити %s",
+    "%1$s via %2$s" : "%1$s через %2$s",
     "%1$s shared »%2$s« with you and wants to add:" : "%1$s надав(-ла) доступ до \"%2$s\" та хоче додати:",
     "%1$s shared »%2$s« with you and wants to add" : "%1$s надав(-ла) доступ до \"%2$s\" та хоче додати",
     "»%s« added a note to a file shared with you" : "\"%s\" додано примітку до файлу у спільному доступі",
-    "Open »%s«" : "Відкрити %s",
-    "%1$s via %2$s" : "%1$s через %2$s",
+    "Unknown share type" : "Невідомий тип спільного ресурсу",
     "You are not allowed to share %s" : "Вам заборонено поширювати %s",
     "Cannot increase permissions of %s" : "Не вдалося підвищити дозволи для %s",
     "Files cannot be shared with delete permissions" : "Не можна надавати у спільний доступ файли з дозволами на вилучення",
@@ -151,9 +154,6 @@ OC.L10N.register(
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Неможливо встановити дату закінчення більше ніж %n день у майбутньому","Неможливо встановити дату закінчення більше ніж %n днів у майбутньому","Неможливо встановити дату закінчення більше ніж %n днів у майбутньому","Неможливо встановити дату закінчення більше ніж %n днів у майбутньому"],
     "Sharing is only allowed with group members" : "Спільний доступ дозволений лише для учасників групи",
     "Sharing %s failed, because this item is already shared with the account %s" : "Не вдалося надати у спільний доступ%s, оскільки цей ресурс вже у спільному доступі з обліковим записом %s",
-    "%1$s shared »%2$s« with you" : "%1$s надав(-ла) доступ до \"%2$s\"",
-    "%1$s shared »%2$s« with you." : "%1$s надав(-ла) доступ до \"%2$s\".",
-    "Click the button below to open it." : "Щоб відкрити файл, натисніть кнопку нижче.",
     "The requested share does not exist anymore" : "Запитуваний спільний ресурс більше недоступний",
     "The requested share comes from a disabled user" : "Отримано запит на спільний доступ від неактивного користувача",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Користувача не створено, оскільки досягнуто обмеження на кількість користувачів. Перевірте сповіщення для докладної інформації.",
@@ -249,9 +249,8 @@ OC.L10N.register(
     "Your data directory must be an absolute path." : "Ваш каталог даних має бути абсолютним шляхом.",
     "Check the value of \"datadirectory\" in your configuration." : "Перевірте значення «каталогу даних» у вашій конфігурації.",
     "Your data directory is invalid." : "Ваш каталог даних недійсний.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Переконайтеся, що в корені каталогу даних є файл під назвою \".ocdata\".",
     "Action \"%s\" not supported or implemented." : "Дія \"%s\" не підтримується або не реалізована.",
-    "Authentication failed, wrong token or provider ID given" : "Помилка авторизації, надано неправильний маркер або ідентифікатор постачальника",
+    "Authentication failed, wrong token or provider ID given" : "Помилка авторизації, надано неправильний токен або ідентифікатор постачальника",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Немає параметрів для виконання запиту. Відсутні параметри: \"%s\"",
     "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "Ідентифікатор \"%1$s\" уже використовується постачальником об'єднаних хмар \"%2$s\"",
     "Cloud Federation Provider with ID: \"%s\" does not exist." : "Постачальник Cloud Federation з ідентифікатором \"%s\" не існує.",
@@ -261,19 +260,28 @@ OC.L10N.register(
     "Storage connection error. %s" : "Помилка з'єднання зі сховищем. %s",
     "Storage is temporarily not available" : "Сховище тимчасово недоступне",
     "Storage connection timeout. %s" : "Час під'єднання до сховища вичерпався. %s",
+    "Chat" : "Чат",
+    "Generates a possible headline for a text." : "Створює ймовірний заголовок тексту.",
+    "Summarize" : "Підсумок",
+    "Summary" : "Загалом",
+    "Extract topics" : "Виділити теми",
+    "Translate" : "Перекласти",
+    "Target language" : "Цільова мова",
+    "Result" : "Результат",
     "Free prompt" : "Вільне запрошення",
     "Runs an arbitrary prompt through the language model." : "Виконує довільне запрошення через мовну модель.",
     "Generate headline" : "Створити заголовок",
-    "Generates a possible headline for a text." : "Створює ймовірний заголовок тексту.",
-    "Summarize" : "Підсумок",
     "Summarizes text by reducing its length without losing key information." : "Викокремлює головне у тексті шляхом зменшення довжини тексту без втрати ключової інформації.",
-    "Extract topics" : "Виділити теми",
     "Extracts topics from a text and outputs them separated by commas." : "Виділяє теми, які висвітлює текст, зводить їх у перелік, що розділено комами.",
-    "404" : "404",
+    "Education Edition" : "Для навчання",
     "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Користувач, який увійшов у систему, має бути адміністратором, підадміністратором або мати спеціальні права доступу до цього налаштування",
     "Logged in user must be an admin or sub admin" : "Увійшовши в систему користувач повинен бути адміністратором або підадміністратором",
     "Logged in user must be an admin" : "Зареєстрований користувач має бути адміністратором",
+    "File name is a reserved word" : "Ім’я файлу є зарезервованим словом",
+    "File name contains at least one invalid character" : "Ім’я файлу містить принаймні один некоректний символ",
+    "File name is too long" : "Ім’я файлу занадто довге",
     "Help" : "Допомога",
+    "Users" : "Користувачі",
     "Unknown user" : "Невідомий користувач",
     "Enter the database username and name for %s" : "Введіть ім’я користувача та назву бази даних %s",
     "Enter the database username for %s" : "Введіть ім’я користувача бази даних для %s",
@@ -290,9 +298,8 @@ OC.L10N.register(
     "Username must not consist of dots only" : "Ім'я користувача не повинно складатися лише з крапок",
     "Username is invalid because files already exist for this user" : "Ім'я користувача недійсне, оскільки файли для цього користувача вже існують",
     "User disabled" : "Користувач виключений",
-    "PostgreSQL >= 9 required." : "Необхідно PostgreSQL >= 9.",
-    "Please upgrade your database version." : "Оновіть версію бази даних.",
     "Your data directory is readable by other users." : "Ваш каталог даних доступний для читання іншим користувачам.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Змініть права доступу на 0770, щоб інші користувачі не могли отримати список файлів цього каталогу."
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Змініть права доступу на 0770, щоб інші користувачі не могли отримати список файлів цього каталогу.",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Переконайтеся, що в корені каталогу даних є файл під назвою \".ocdata\"."
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
