@@ -1,14 +1,13 @@
 OC.L10N.register(
     "lib",
     {
-    "Cannot write into \"config\" directory!" : "無法寫入 \"config\" 目錄！",
+    "Cannot write into \"config\" directory!" : "無法寫入「config」目錄！",
     "This can usually be fixed by giving the web server write access to the config directory." : "允許網頁伺服器寫入 config 目錄通常可以解決這個問題。",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "但如果您比較希望保留 config.php 的唯讀狀態，請在該設定檔中將 \"config_is_read_only\" 設定為 true。",
     "See %s" : "見 %s",
     "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "應用程式 %1$s 不存在或有與此伺服器不相容的版本。請檢查應用程式目錄。",
     "Sample configuration detected" : "您目前正在使用範例設定",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "您似乎直接複製了範例設定來使用，這樣的安裝很可能會無法運作，請閱讀說明文件後對 config.php 進行適當的修改",
-    "404" : "404",
     "The page could not be found on the server." : "無法在伺服器上找到此頁面。",
     "%s email verification" : "%s 電子郵件驗證",
     "Email verification" : "電子郵件驗證",
@@ -20,11 +19,12 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s 和 %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s、%2$s、%3$s 和 %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s、%2$s、%3$s、%4$s 和 %5$s",
-    "Education Edition" : "教育版",
+    "Education bundle" : "教育組合包",
     "Enterprise bundle" : "企業組合包",
     "Groupware bundle" : "協作組合包",
     "Hub bundle" : "Hub 套裝",
-    "Social sharing bundle" : "社交網絡組合包",
+    "Public sector bundle" : "公部門組合包",
+    "Social sharing bundle" : "社交分享組合包",
     "PHP %s or higher is required." : "需要 PHP %s 或更高版本",
     "PHP with a version lower than %s is required." : "需要 PHP 版本低於 %s ",
     "%sbit or higher PHP required." : "%s 或需要更高階版本的php",
@@ -37,9 +37,10 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "支援下列平台：%s",
     "Server version %s or higher is required." : "需要伺服器版本 %s 或更高",
     "Server version %s or lower is required." : "需要伺服器版本 %s 或更低",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "登入使用者必須為管理員、子管理員或有可存取此設定的特殊權限的使用者",
-    "Logged in user must be an admin or sub admin" : "登入的使用者必須要是管理員或是子管理員",
-    "Logged in user must be an admin" : "登入的使用者必須有管理員權限",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "登入帳號必須為管理員、子管理員或有可存取此設定的特殊權限的使用者",
+    "Your current IP address doesn’t allow you to perform admin actions" : "您目前的 IP 位置不允許您執行管理動作",
+    "Logged in account must be an admin or sub admin" : "登入的帳號必須要是管理員或是子管理員",
+    "Logged in account must be an admin" : "登入的帳號必須有管理員權限",
     "Wiping of device %s has started" : "已開始抹除裝置 %s ",
     "Wiping of device »%s« has started" : "已開始抹除裝置「%s」",
     "»%s« started remote wipe" : "「%s」開始遠端抹除",
@@ -80,27 +81,34 @@ OC.L10N.register(
     "seconds ago" : "幾秒前",
     "Empty file" : "空檔案",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "名為 %s 的模組不存在，請在應用程式設定中啟用，或是聯絡系統管理員",
+    "Dot files are not allowed" : "不允許小數點開頭的檔案",
+    "\"%1$s\" is a forbidden file or folder name." : "「%1$s」是禁止的檔案或資料夾名稱。",
+    "\"%1$s\" is a forbidden prefix for file or folder names." : "「%1$s」是禁止的檔案或資料夾名稱前綴。",
+    "\"%1$s\" is not allowed inside a file or folder name." : "「%1$s」不允許出現在檔案或資料夾名稱中。",
+    "\"%1$s\" is a forbidden file type." : "「%1$s」是禁止的檔案類型。",
+    "Filenames must not end with \"%1$s\"." : "檔案名稱不能以「%1$s」結尾。",
+    "Invalid parent path" : "無效的上層路徑",
     "File already exists" : "檔案已存在",
     "Invalid path" : "無效的路徑",
     "Failed to create file from template" : "無法從範本建立檔案",
     "Templates" : "範本",
-    "File name is a reserved word" : "檔案名稱是保留字",
-    "File name contains at least one invalid character" : "檔案名稱含有不允許的字元",
-    "File name is too long" : "檔案名稱太長",
-    "Dot files are not allowed" : "不允許小數點開頭的檔案",
+    "Path contains invalid segments" : "路徑包含無效的部份",
+    "Filename is a reserved word" : "檔案名稱是保留字",
+    "Filename contains at least one invalid character" : "檔案名稱包含了至少一個無效的字元",
+    "Filename is too long" : "檔案名稱太長",
     "Empty filename is not allowed" : "不允許空白的檔名",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "應用程式 \"%s\" 無法安裝，因為無法讀取 appinfo 檔案。",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "應用程式 \"%s\" 無法安裝，因為該應用程式不相容於目前版本的伺服器。",
     "__language_name__" : "正體中文（臺灣）",
     "This is an automatically sent email, please do not reply." : "此為自動寄送的電子郵件，請不要回覆。",
-    "Help" : "說明",
+    "Help & privacy" : "說明與隱私",
     "Appearance and accessibility" : "外觀與無障礙存取",
     "Apps" : "應用程式",
     "Personal settings" : "個人設定",
     "Administration settings" : "管理設定",
     "Settings" : "設定",
     "Log out" : "登出",
-    "Users" : "使用者",
+    "Accounts" : "帳號",
     "Email" : "電子郵件",
     "Mail %s" : "傳送郵件給 %s",
     "Fediverse" : "Fediverse",
@@ -118,46 +126,83 @@ OC.L10N.register(
     "Headline" : "標題",
     "Organisation" : "組織",
     "Role" : "角色",
-    "Unknown user" : "未知的使用者",
+    "Unknown account" : "未知的帳號",
     "Additional settings" : "其他設定",
-    "Enter the database username and name for %s" : "輸入 %s 的資料庫名稱及使用者名稱",
-    "Enter the database username for %s" : "輸入 %s 的資料庫使用者暱稱",
+    "Enter the database Login and name for %s" : "輸入 %s 的資料庫帳號與名稱",
+    "Enter the database Login for %s" : "輸入 %s 的資料庫帳號",
     "Enter the database name for %s" : "輸入 %s 的資料庫名稱",
     "You cannot use dots in the database name %s" : "資料庫名稱 %s 不能包含小數點",
-    "MySQL username and/or password not valid" : "MySQL 使用者名稱或密碼不正確",
+    "MySQL Login and/or password not valid" : "MySQL 帳號或密碼不正確",
     "You need to enter details of an existing account." : "您必須輸入現有帳號的資訊",
     "Oracle connection could not be established" : "無法建立 Oracle 資料庫連線",
-    "Oracle username and/or password not valid" : "Oracle 用戶名和/或密碼無效",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL 用戶名和/或密碼無效",
+    "Oracle Login and/or password not valid" : "Oracle 帳號或密碼不正確",
+    "PostgreSQL Login and/or password not valid" : "PostgreSQL 帳號或密碼無效",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "不支援 Mac OS X 而且 %s 在這個平台上面無法正常運作，請自行衡量風險後使用！",
     "For the best results, please consider using a GNU/Linux server instead." : "請考慮使用 GNU/Linux 伺服器以獲得最佳體驗",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "看起來 %s 是在 32 位元的 PHP 環境運行，並且 php.ini 中被設置了 open_basedir 參數，這將讓超過 4GB 的檔案操作發生問題，強烈建議您更改設定。",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "請移除 php.ini 中的 open_basedir 設定，或是改用 64 位元的 PHP",
-    "Set an admin username." : "設定管理員帳號",
+    "Set an admin Login." : "設定管理員帳號。",
     "Set an admin password." : "設定管理員密碼",
     "Cannot create or write into the data directory %s" : "無法建立或寫入資料目錄 %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "分享後端 %s 必須實作 OCP\\Share_Backend 界面",
     "Sharing backend %s not found" : "找不到分享後端 %s",
     "Sharing backend for %s not found" : "找不到 %s 的分享後端",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s 與您分享了 %2$s ，且想要加入：",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s 與您分享了 %2$s ，且想要加入",
-    "»%s« added a note to a file shared with you" : "%s 在與您分享的檔案中加入了註解",
-    "Open »%s«" : "開啟 »%s«",
-    "%1$s via %2$s" : "%1$s 由 %2$s",
-    "You are not allowed to share %s" : "你不被允許分享 %s",
-    "Cannot increase permissions of %s" : "無法增加 %s 的權限",
-    "Files cannot be shared with delete permissions" : "無法分享具有刪除權限的檔案",
-    "Files cannot be shared with create permissions" : "無法分享具有新建權限的檔案",
-    "Expiration date is in the past" : "到期日為過去的日期",
-    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["無法設定到期日超過未來%n天"],
-    "Sharing is only allowed with group members" : "僅允許與群組成員分享",
-    "Sharing %s failed, because this item is already shared with user %s" : "分享 %s 失敗，因為此項目已與使用者 %s 分享",
     "%1$s shared »%2$s« with you" : "%1$s 與您分享了 %2$s",
     "%1$s shared »%2$s« with you." : "%1$s 與您分享了 %2$s",
     "Click the button below to open it." : "點下方連結開啟",
+    "Open »%s«" : "開啟 »%s«",
+    "%1$s via %2$s" : "%1$s 由 %2$s",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s 與您分享了 %2$s ，且想要加入：",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s 與您分享了 %2$s ，且想要加入",
+    "»%s« added a note to a file shared with you" : "%s 在與您分享的檔案中加入了註解",
+    "Passwords are enforced for link and mail shares" : "連結與郵件分享強制使用密碼",
+    "SharedWith is not a valid user" : "SharedWith 不是有效的使用者",
+    "SharedWith is not a valid group" : "SharedWith 不是有效的群組",
+    "SharedWith should be empty" : "SharedWith 應該為空",
+    "SharedWith should not be empty" : "SharedWith 不應為空",
+    "SharedWith is not a valid circle" : "SharedWith 不是有效的小圈圈",
+    "Unknown share type" : "未知的分享類型",
+    "SharedBy should be set" : "應該設定 SharedBy",
+    "Cannot share with yourself" : "無法與您自己分享",
+    "Path should be set" : "應該設定路徑",
+    "Path should be either a file or a folder" : "路徑應為檔案或資料夾",
+    "You cannot share your root folder" : "您無法分享您的根資料夾",
+    "You are not allowed to share %s" : "你不被允許分享 %s",
+    "A share requires permissions" : "分享需要權限",
+    "Cannot increase permissions of %s" : "無法增加 %s 的權限",
+    "Shares need at least read permissions" : "分享需要至少讀取的權限",
+    "Files cannot be shared with delete permissions" : "無法分享具有刪除權限的檔案",
+    "Files cannot be shared with create permissions" : "無法分享具有新建權限的檔案",
+    "Expiration date is in the past" : "到期日為過去的日期",
+    "Expiration date is enforced" : "有效日期為強制要求",
+    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["無法設定到期日超過未來%n天"],
+    "Sharing is only allowed with group members" : "僅允許與群組成員分享",
+    "Sharing %s failed, because this item is already shared with the account %s" : "分享 %s 失敗，因為此項目已與帳號 %s 分享",
+    "Group sharing is now allowed" : "現在允許群組分享",
+    "Sharing is only allowed within your own groups" : "僅允許與您自己的群組分享",
+    "Path is already shared with this group" : "路徑已與此群組分享",
+    "Link sharing is not allowed" : "不允許連結分享",
+    "Public upload is not allowed" : "不允許公開上傳",
+    "Path contains files shared with you" : "路徑包含與您分享的檔案",
+    "Sharing is disabled" : "已停用分享",
+    "Sharing is disabled for you" : "您已停用分享",
+    "Cannot share with the share owner" : "無法與分享擁有者分享",
+    "Share does not have a full ID" : "分享並無完整 ID",
+    "Cannot change share type" : "無法變更分享類型",
+    "Can only update recipient on user shares" : "僅能更新使用者分享的收件者",
+    "Cannot enable sending the password by Talk with an empty password" : "若密碼為空，則無法啟用透過 Talk 傳送密碼",
+    "Cannot enable sending the password by Talk without setting a new password" : "若未設定新密碼，則無法啟用透過 Talk 傳送密碼",
+    "Cannot disable sending the password by Talk without setting a new password" : "若未設定新密碼，則無法停用透過 Talk 傳送密碼",
+    "Share provider does not support accepting" : "分享提供者不支援接受",
+    "Cannot change target of link share" : "無法變更連結分享的目標",
+    "Invalid recipient" : "無效的接收者",
+    "Group \"%s\" does not exist" : "群組「%s」不存在",
     "The requested share does not exist anymore" : "該分享已經不存在",
+    "The requested share comes from a disabled user" : "請求的分享來自已停用的使用者",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "未建立使用者，因為已達使用者上限。請檢查您的通知以取得更多資訊。",
     "Could not find category \"%s\"" : "找不到分類：\"%s\"",
+    "Input text" : "輸入文字",
+    "The input text" : "輸入文字",
     "Sunday" : "週日",
     "Monday" : "週一",
     "Tuesday" : "週二",
@@ -204,14 +249,14 @@ OC.L10N.register(
     "Nov." : "十一月",
     "Dec." : "十二月",
     "A valid password must be provided" : "須提供有效的密碼",
-    "The username is already being used" : "這個使用者名稱已經有人使用了",
-    "Could not create user" : "無法建立使用者",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "使用者名稱僅允許以下字元：\"a-z\"、\"A-Z\"、\"0-9\"、空格與 \"_.@-'\"",
-    "A valid username must be provided" : "必須提供一個有效的用戶名",
-    "Username contains whitespace at the beginning or at the end" : "用戶名的開頭或結尾有空白",
-    "Username must not consist of dots only" : "使用者名稱不能只包含小數點",
-    "Username is invalid because files already exist for this user" : "使用者名稱無效，因為使用者的檔案已經存在",
-    "User disabled" : "使用者已停用",
+    "The Login is already being used" : "這個帳號已經有人使用了",
+    "Could not create account" : "無法建立帳號",
+    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "帳號僅允許以下字元：\"a-z\"、\"A-Z\"、\"0-9\"、空格與 \"_.@-'\"",
+    "A valid Login must be provided" : "必須提供有效帳號",
+    "Login contains whitespace at the beginning or at the end" : "帳號的開頭或結尾有空白",
+    "Login must not consist of dots only" : "帳號不能只包含小數點",
+    "Login is invalid because files already exist for this user" : "帳號無效，因為使用者的檔案已經存在",
+    "Account disabled" : "帳號已停用",
     "Login canceled by app" : "應用程式取消了登入",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "應用程式 \"%1$s\" 無法被安裝，缺少下列所需元件： %2$s",
     "a safe home for all your data" : "您資料的安全屋",
@@ -244,14 +289,12 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "請聯絡您的系統管理員重新啟動網頁伺服器",
     "The required %s config variable is not configured in the config.php file." : "必要的 %s 設定變數未在 config.php 檔案中設定。",
     "Please ask your server administrator to check the Nextcloud configuration." : "請聯絡您的伺服器管理員檢查 Nextcloud 設定。",
-    "PostgreSQL >= 9 required." : "需要 PostgreSQL 版本 >= 9。",
-    "Please upgrade your database version." : "請升級您的資料庫版本。",
-    "Your data directory is readable by other users." : "您的 data 目錄可被其他使用讀取。",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "請將該目錄權限設定為 0770 ，以免其他使用者讀取目錄列表",
+    "Your data directory is readable by other people." : "您的 data 目錄可被其他使用者讀取。",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "請將該目錄權限設定為 0770 ，以免其他使用者讀取目錄列表",
     "Your data directory must be an absolute path." : "您的 data 目錄必須是絕對路徑。",
     "Check the value of \"datadirectory\" in your configuration." : "請檢查您設定檔中「datadirectory」的值。",
     "Your data directory is invalid." : "您的 data 目錄無效。",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "請確保資料目錄最上層有一個 \".ocdata\" 檔案",
+    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "請確保資料目錄最上層有一個「%1$s」檔案。其應有內容：「%2$s」",
     "Action \"%s\" not supported or implemented." : "操作 \"%s\" 並未支援，或是尚未實作",
     "Authentication failed, wrong token or provider ID given" : "認證失敗，提供了錯誤的 token 或是 provider ID",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "欠缺完成請求所需的參數： \"%s\"",
@@ -263,18 +306,119 @@ OC.L10N.register(
     "Storage connection error. %s" : "儲存空間連線錯誤。%s",
     "Storage is temporarily not available" : "儲存空間暫時無法使用",
     "Storage connection timeout. %s" : "儲存空間連線逾時。%s",
-    "Free prompt" : "免費提示詞",
-    "Generate headline" : "產生標題",
+    "Transcribe audio" : "轉錄音訊",
+    "Transcribe the things said in an audio" : "轉錄音訊中所說的話",
+    "Audio input" : "音訊輸入",
+    "The audio to transcribe" : "要轉錄的音訊",
+    "Transcription" : "轉錄",
+    "The transcribed text" : "已轉錄的文字",
+    "Context write" : "寫作情境",
+    "Writes text in a given style based on the provided source material." : "根據提供的來源資料以指定的風格編寫文字",
+    "Writing style" : "寫作風格",
+    "Demonstrate a writing style that you would like to immitate" : "展現您想模仿的寫作風格",
+    "Source material" : "來源資料",
+    "The content that would like to be rewritten in the new writing style" : "想要用新的寫作風格重寫的內容",
+    "Generated text" : "產生的文字",
+    "The generated text with content from the source material in the given style" : "產生的文字包含來自指定樣式的原始素材的內容",
+    "Emoji generator" : "表情符號產生程式",
+    "Takes text and generates a representative emoji for it." : "取得文字並為其產生代表性表情符號。",
+    "The text to generate an emoji for" : "用來產生表情符號的文字",
+    "Generated emoji" : "已產生表情符號",
+    "The generated emoji based on the input text" : "以輸入文字為基礎產生的表情符號",
+    "Generate image" : "產生影像",
+    "Generate an image from a text prompt" : "根據文字提示產生影像",
+    "Prompt" : "提示詞",
+    "Describe the image you want to generate" : "描述您想要產生的影像",
+    "Number of images" : "影像數量",
+    "How many images to generate" : "要產生多少影像",
+    "Output images" : "輸出影像",
+    "The generated images" : "產生的影像",
+    "Free text to text prompt" : "文字提示的自由文字",
+    "Runs an arbitrary prompt through a language model that returns a reply" : "透過回傳回覆的語言模型執行任意提示",
+    "Describe a task that you want the assistant to do or ask a question" : "描述您希望助理執行的任務或提出問題",
+    "Generated reply" : "已產生的回覆",
+    "The generated text from the assistant" : "從助理產生的文字",
+    "Chat" : "聊天",
+    "Chat with the assistant" : "與小幫手聊天",
+    "System prompt" : "系統提示詞",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "定義小幫手在對話期間應遵守的規則與假設。",
+    "Chat message" : "聊天訊息",
+    "Chat history" : "聊天歷史紀錄",
+    "The history of chat messages before the current message, starting with a message by the user" : "目前訊息開始之前的聊天歷史紀錄，從使用者的訊息開始",
+    "Response message" : "回應訊息",
+    "The generated response as part of the conversation" : "作為對話一部份產生的回應",
+    "Formalize text" : "正式化文字",
+    "Takes a text and makes it sound more formal" : "取得文字並使其看起來更正式",
+    "Write a text that you want the assistant to formalize" : "寫下您希望小幫手協助您正式化的文字",
+    "Formalized text" : "正式化文字",
+    "The formalized text" : "正式化文字",
+    "Generate a headline" : "產生標題",
     "Generates a possible headline for a text." : "為文字產生可能的標題。",
+    "Original text" : "原始文字",
+    "The original text to generate a headline for" : "用來產生標題的原始文字",
+    "The generated headline" : "產生的標題",
+    "Reformulate text" : "重新表述文字",
+    "Takes a text and reformulates it" : "取得文字並將其重新表述",
+    "Write a text that you want the assistant to reformulate" : "寫下您希望小幫手協助您重新表述的文字",
+    "Reformulated text" : "已重新表述的文字",
+    "The reformulated text, written by the assistant" : "已重新表述的文字，由小幫手編寫",
+    "Simplify text" : "簡化文字",
+    "Takes a text and simplifies it" : "取得文字並將其簡化",
+    "Write a text that you want the assistant to simplify" : "寫下您希望小幫手協助您簡化的文字",
+    "Simplified text" : "簡化後的文字",
+    "The simplified text" : "簡化後的文字",
     "Summarize" : "總結",
-    "Summarizes text by reducing its length without losing key information." : "透過減少文字長度來總結而不遺失關鍵資訊。",
+    "Summarizes a text" : "總結一段文字",
+    "The original text to summarize" : "要總結的原始文字",
+    "Summary" : "摘要",
+    "The generated summary" : "產生的總結",
     "Extract topics" : "擷取主題",
+    "Extracts topics from a text and outputs them separated by commas" : "從文字中擷取主題並輸出，然後用逗號分隔",
+    "The original text to extract topics from" : "用來擷取主題的原始文字",
+    "Topics" : "主題",
+    "The list of extracted topics" : "擷取的主題清單",
+    "Translate" : "翻譯",
+    "Translate text from one language to another" : "從一個語言翻譯成其他語言的文字",
+    "Origin text" : "原始文字",
+    "The text to translate" : "要翻譯的文字",
+    "Origin language" : "原始語言",
+    "The language of the origin text" : "原始文字語言",
+    "Target language" : "目標語言",
+    "The desired language to translate the origin text in" : "要翻譯原始文字成什麼語言",
+    "Result" : "結果",
+    "The translated text" : "已翻譯的文字",
+    "Free prompt" : "免費提示詞",
+    "Runs an arbitrary prompt through the language model." : "透過語言模型執行任意提示詞。",
+    "Generate headline" : "產生標題",
+    "Summarizes text by reducing its length without losing key information." : "透過減少文字長度來總結而不遺失關鍵資訊。",
     "Extracts topics from a text and outputs them separated by commas." : "從文字中擷取主題並輸出，然後用逗號分隔。",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "應用程式 %1$s 中的檔案沒有被正確取代，請確認它的版本與伺服器相容。",
-    "Full name" : "全名",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "已達使用者限制，所以未建立使用者。請檢查您的通知以取得更多資訊。",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "使用者名稱當中只能包含下列字元：\"a-z\", \"A-Z\", \"0-9\", 和 \"_.@-'\"",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 版本最低需求為 2.7.0。目前安裝版本為 %s 。",
-    "To fix this issue update your libxml2 version and restart your web server." : "修正方式為更新您的 libxml2 為 2.7.0 以上版本，再重啟網頁伺服器。"
+    "Education Edition" : "教育版",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "登入使用者必須為管理員、子管理員或有可存取此設定的特殊權限的使用者",
+    "Logged in user must be an admin or sub admin" : "登入的使用者必須要是管理員或是子管理員",
+    "Logged in user must be an admin" : "登入的使用者必須有管理員權限",
+    "File name is a reserved word" : "檔案名稱是保留字",
+    "File name contains at least one invalid character" : "檔案名稱含有不允許的字元",
+    "File name is too long" : "檔案名稱太長",
+    "Help" : "說明",
+    "Users" : "使用者",
+    "Unknown user" : "未知的使用者",
+    "Enter the database username and name for %s" : "輸入 %s 的資料庫名稱及使用者名稱",
+    "Enter the database username for %s" : "輸入 %s 的資料庫使用者暱稱",
+    "MySQL username and/or password not valid" : "MySQL 使用者名稱或密碼不正確",
+    "Oracle username and/or password not valid" : "Oracle 用戶名和/或密碼無效",
+    "PostgreSQL username and/or password not valid" : "PostgreSQL 用戶名和/或密碼無效",
+    "Set an admin username." : "設定管理員帳號",
+    "Sharing %s failed, because this item is already shared with user %s" : "分享 %s 失敗，因為此項目已與使用者 %s 分享",
+    "The username is already being used" : "這個使用者名稱已經有人使用了",
+    "Could not create user" : "無法建立使用者",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "使用者名稱僅允許以下字元：\"a-z\"、\"A-Z\"、\"0-9\"、空格與 \"_.@-'\"",
+    "A valid username must be provided" : "必須提供一個有效的用戶名",
+    "Username contains whitespace at the beginning or at the end" : "用戶名的開頭或結尾有空白",
+    "Username must not consist of dots only" : "使用者名稱不能只包含小數點",
+    "Username is invalid because files already exist for this user" : "使用者名稱無效，因為使用者的檔案已經存在",
+    "User disabled" : "使用者已停用",
+    "Your data directory is readable by other users." : "您的 data 目錄可被其他使用讀取。",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "請將該目錄權限設定為 0770 ，以免其他使用者讀取目錄列表",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "請確保資料目錄最上層有一個 \".ocdata\" 檔案"
 },
 "nplurals=1; plural=0;");
